/*
 * Simple HTTPS PUT from file
 *
 */ 
#include <stdio.h>
#include <fcntl.h>
#include <sys/stat.h>
#include <curl/curl.h>
 
int main(int argc, char **argv)
{
  CURL *curl;
  CURLcode res;
  struct curl_slist *headers = NULL;

  FILE * fd;
  struct stat file_info;

  char *file;
  char token[512];
  char url[512];
 

  if(argc < 4) {
    printf("Usage: %s <file> <token> <url>\n", argv[0]);
    return 1;
  }
 
  file= argv[1];
  sprintf(token, "mx-api-token: %s", argv[2]);
  sprintf(url, "%s", argv[3]);
 
  /* get the file size of the local file */ 
  stat(file, &file_info);
 
  /* get a FILE * of the same file, could also be made with
     fdopen() from the previous descriptor, but hey this is just
     an example! */ 
  fd = fopen(file, "rb");

  curl_global_init(CURL_GLOBAL_DEFAULT);
 
  curl = curl_easy_init();
  if(curl) {
    headers = curl_slist_append(headers, "Content-Type: application/json");
    headers = curl_slist_append(headers, token);
    curl_easy_setopt(curl, CURLOPT_URL, url);
    curl_easy_setopt(curl, CURLOPT_HTTPHEADER, headers); 

    /* enable uploading */ 
    curl_easy_setopt(curl, CURLOPT_UPLOAD, 1L);

    /* now specify which file to upload */ 
    curl_easy_setopt(curl, CURLOPT_READDATA, fd);
 
    /* provide the size of the upload, we specicially typecast the value
       to curl_off_t since we must be sure to use the correct data size */ 
    curl_easy_setopt(curl, CURLOPT_INFILESIZE_LARGE,
                     (curl_off_t)file_info.st_size);
 
    /* Skip the verification of the server's certificate. */
    curl_easy_setopt(curl, CURLOPT_SSL_VERIFYPEER, 0L);
 
    /* Skip to verify the certificate's name against host. */
    curl_easy_setopt(curl, CURLOPT_SSL_VERIFYHOST, 0L);
 
    /* Perform the request, res will get the return code */ 
    res = curl_easy_perform(curl);
    /* Check for errors */ 
    if(res != CURLE_OK)
      fprintf(stderr, "curl_easy_perform() failed: %s\n",
              curl_easy_strerror(res));
 
    /* always cleanup */ 
    curl_easy_cleanup(curl);
  }
  fclose(fd); /* close the local file */
 
  curl_global_cleanup();
 
  return 0;
}
