var openapiDoc = {
  "swagger": "2.0",
  "info": {
    "version": "2.1.0",
    "title": "ThingsPro Gateway RESTful API reference"
  },
  "basePath": "/api/v1",
  "schemes": [
    "http",
    "https"
  ],
  "produces": [
    "application/json"
  ],
  "securityDefinitions": {
    "mx-api-token": {
      "type": "apiKey",
      "name": "mx-api-token",
      "in": "header",
      "description": "ThingsPro RESTful API token, The token should be created on web console."
    }
  },
  "tags": [
    {
      "name": "cellular",
      "description": "Provides the cellular configuration interface"
    },
    {
      "name": "custom-equipment",
      "description": "Manages customized equipment tags"
    },
    {
      "name": "dhcpd",
      "description": "Handles the DHCP Server configuration"
    },
    {
      "name": "dns",
      "description": "Handles the system DNS settings"
    },
    {
      "name": "ethernet",
      "description": "Handles the Ethernet interfaces"
    },
    {
      "name": "import-export",
      "description": "Manages the import/export of configuration files"
    },
    {
      "name": "iptables",
      "description": "Manages iptables rules"
    },
    {
      "name": "logprofile",
      "description": "Handles log profile configuration"
    },
    {
      "name": "modbusslave",
      "description": "Handles Modbus Slave configuration"
    },
    {
      "name": "openvpn",
      "description": "Handles the configuration of the OpenVPN client service"
    },
    {
      "name": "program",
      "description": "Provides the user program service"
    },
    {
      "name": "remotecontrol",
      "description": "Remote control settings"
    },
    {
      "name": "route",
      "description": "Handles the routing table"
    },
    {
      "name": "serial",
      "description": "Provides the utility to set the serial mode"
    },
    {
      "name": "service",
      "description": "Manages the system service configuration"
    },
    {
      "name": "status",
      "description": "Provides system status information"
    },
    {
      "name": "time",
      "description": "Provides the system-time management function"
    },
    {
      "name": "firmware",
      "description": "Manages the firmware upgrade function"
    },
    {
      "name": "wifi",
      "description": "Provides the WiFi network(s) configuration interface"
    },
    {
      "name": "modbus",
      "description": "Handles Modbus framework configuration"
    }
  ],
  "paths": {
    "/network/cellulars": {
      "get": {
        "summary": "Cellular Interface(s)",
        "description": "The system returns information about the settings of all\n*Cellular interface(s)*.\n",
        "responses": {
          "200": {
            "description": "An array of Cellular interface(s)",
            "schema": {
              "type": "array",
              "items": {
                "$ref": "#/definitions/Cellular"
              }
            },
            "examples": {
              "application/json": [
                {
                  "id": 1,
                  "name": "wwan1",
                  "mode": "umts",
                  "signal": {
                    "csq": 14,
                    "rssi": -76,
                    "ecio": -8.5
                  },
                  "operatorName": "Chunghwa Telecom",
                  "lac": "11114",
                  "tac": "",
                  "nid": "",
                  "cellId": "1249",
                  "bid": "",
                  "iccId": "",
                  "imsi": "466977502877452",
                  "imei": "356853050370859",
                  "esn": "802202F0",
                  "pinRetryRemain": 3,
                  "status": "connected",
                  "mac": "00:00:00:00:00:00",
                  "ip": "111.70.146.125",
                  "netmask": "255.255.255.252",
                  "gateway": "111.70.146.126",
                  "dns": [
                    "168.95.1.1",
                    "168.95.192.1"
                  ],
                  "usage": {
                    "txkbyte": 40023,
                    "rxkbyte": 3493
                  },
                  "enable": true,
                  "pdpContext": {
                    "static": true,
                    "id": 1,
                    "retryTimeout": 1200,
                    "primary": {
                      "apn": "internet",
                      "type": "ipv4v6"
                    },
                    "secondary": {
                      "apn": "internet",
                      "type": "ipv4v6"
                    },
                    "list": [
                      {
                        "id": 1,
                        "apn": "internet",
                        "type": "ipv4v6"
                      }
                    ]
                  },
                  "pinCode": "0000",
                  "keepalive": {
                    "enable": true,
                    "targetHost": "8.8.8.8",
                    "intervalSec": 60,
                    "reboot": {
                      "enable": false,
                      "cycles": 1
                    }
                  }
                }
              ]
            }
          }
        },
        "tags": [
          "cellular"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      }
    },
    "/network/cellulars/{id}": {
      "parameters": [
        {
          "name": "id",
          "in": "path",
          "type": "integer",
          "required": true
        }
      ],
      "get": {
        "description": "Get settings of indicated Cellular interface.\n",
        "responses": {
          "200": {
            "description": "An Cellular interface settings.",
            "schema": {
              "$ref": "#/definitions/Cellular"
            },
            "examples": {
              "application/json": {
                "id": 1,
                "name": "wwan1",
                "mode": "umts",
                "signal": {
                  "csq": 14,
                  "rssi": -76,
                  "ecio": -8.5
                },
                "operatorName": "Chunghwa Telecom",
                "lac": "11114",
                "tac": "",
                "nid": "",
                "cellId": "1249",
                "bid": "",
                "iccId": "",
                "imsi": "466977502877452",
                "imei": "356853050370859",
                "esn": "802202F0",
                "pinRetryRemain": 3,
                "status": "connected",
                "mac": "00:00:00:00:00:00",
                "ip": "111.70.146.125",
                "netmask": "255.255.255.252",
                "gateway": "111.70.146.126",
                "dns": [
                  "168.95.1.1",
                  "168.95.192.1"
                ],
                "usage": {
                  "txkbyte": 40023,
                  "rxkbyte": 3493
                },
                "enable": true,
                "pdpContext": {
                  "static": true,
                  "id": 1,
                  "retryTimeout": 1200,
                  "primary": {
                    "apn": "internet",
                    "type": "ipv4v6"
                  },
                  "secondary": {
                    "apn": "internet",
                    "type": "ipv4v6"
                  },
                  "list": [
                    {
                      "id": 1,
                      "apn": "internet",
                      "type": "ipv4v6"
                    }
                  ]
                },
                "pinCode": "0000",
                "keepalive": {
                  "enable": true,
                  "targetHost": "8.8.8.8",
                  "intervalSec": 60,
                  "reboot": {
                    "enable": false,
                    "cycles": 1
                  }
                }
              }
            }
          }
        },
        "tags": [
          "cellular"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      },
      "put": {
        "summary": "Cellular Interface",
        "description": "Update an Cellular interface settings.",
        "parameters": [
          {
            "name": "body",
            "in": "body",
            "description": "",
            "required": true,
            "schema": {
              "$ref": "#/definitions/Cellular"
            }
          }
        ],
        "responses": {
          "200": {
            "description": "OK",
            "schema": {
              "$ref": "#/definitions/Cellular"
            },
            "examples": {
              "application/json": {
                "id": 1,
                "name": "wwan1",
                "mode": "umts",
                "signal": {
                  "csq": 14,
                  "rssi": -76,
                  "ecio": -8.5
                },
                "operatorName": "Chunghwa Telecom",
                "lac": "11114",
                "tac": "",
                "nid": "",
                "cellId": "1249",
                "bid": "",
                "iccId": "",
                "imsi": "466977502877452",
                "imei": "356853050370859",
                "esn": "802202F0",
                "pinRetryRemain": 3,
                "status": "connected",
                "mac": "00:00:00:00:00:00",
                "ip": "111.70.146.125",
                "netmask": "255.255.255.252",
                "gateway": "111.70.146.126",
                "dns": [
                  "168.95.1.1",
                  "168.95.192.1"
                ],
                "usage": {
                  "txkbyte": 40023,
                  "rxkbyte": 3493
                },
                "enable": true,
                "pdpContext": {
                  "static": true,
                  "id": 1,
                  "retryTimeout": 1200,
                  "primary": {
                    "apn": "internet",
                    "type": "ipv4v6"
                  },
                  "secondary": {
                    "apn": "internet",
                    "type": "ipv4v6"
                  },
                  "list": [
                    {
                      "id": 1,
                      "apn": "internet",
                      "type": "ipv4v6"
                    }
                  ]
                },
                "pinCode": "0000",
                "keepalive": {
                  "enable": true,
                  "targetHost": "8.8.8.8",
                  "intervalSec": 60,
                  "reboot": {
                    "enable": false,
                    "cycles": 1
                  }
                }
              }
            }
          }
        },
        "tags": [
          "cellular"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      }
    },
    "/network/cellulars/{id}/firmware": {
      "parameters": [
        {
          "name": "id",
          "in": "path",
          "type": "integer",
          "required": true
        }
      ],
      "get": {
        "description": "Get firmware information of indicated Cellular interface.\n",
        "responses": {
          "200": {
            "description": "firmware information of indicated Cellular interface.",
            "schema": {
              "$ref": "#/definitions/CellularFirmwareInfo"
            },
            "examples": {
              "application/json": {
                "switchable": true,
                "current": {
                  "fwver": "05.05.58.01",
                  "config": "ATT_005.029_001",
                  "carrier": "ATT"
                },
                "preferred": {
                  "fwver": "05.05.58.01",
                  "config": "ATT_005.029_001",
                  "carrier": "ATT"
                },
                "available": [
                  {
                    "fwver": "05.05.58.01",
                    "config": "ATT_005.029_001",
                    "carrier": "ATT"
                  },
                  {
                    "fwver": "05.05.58.02",
                    "config": "VZW_005.029_002",
                    "carrier": "VZW"
                  }
                ]
              }
            }
          }
        },
        "tags": [
          "cellular"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      },
      "put": {
        "description": "Set preferred firmware",
        "parameters": [
          {
            "name": "body",
            "in": "body",
            "description": "",
            "required": true,
            "schema": {
              "$ref": "#/definitions/CellularFirmwareEntry"
            }
          }
        ],
        "responses": {
          "200": {
            "description": "OK",
            "schema": {
              "$ref": "#/definitions/CellularFirmwareEntry"
            },
            "examples": {
              "application/json": {
                "fwver": "05.05.58.01",
                "config": "ATT_005.029_001",
                "carrier": "ATT"
              }
            }
          }
        },
        "tags": [
          "cellular"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      }
    },
    "/mxc/custom/equipments": {
      "get": {
        "description": "Get custom equipment list",
        "responses": {
          "200": {
            "description": "success",
            "schema": {
              "type": "array",
              "items": {
                "$ref": "#/definitions/CustomEquipment"
              }
            },
            "examples": {
              "application/json": [
                {
                  "id": 1,
                  "equipmentName": "Promgram-1",
                  "equipmentTags": [
                    {
                      "name": "cpu",
                      "dataType": "float32",
                      "access": "ro",
                      "size": 4,
                      "description": "all about cpu"
                    },
                    {
                      "name": "mem",
                      "dataType": "float32",
                      "access": "ro",
                      "size": 4,
                      "description": "all about memory"
                    },
                    {
                      "name": "disk",
                      "dataType": "uint32",
                      "access": "ro",
                      "size": 4,
                      "description": "all about disk"
                    }
                  ]
                },
                {
                  "id": 2,
                  "equipmentName": "Promgram-2",
                  "equipmentTags": [
                    {
                      "name": "abc",
                      "dataType": "string",
                      "access": "ro",
                      "size": 4,
                      "description": "description of abc"
                    },
                    {
                      "name": "def",
                      "dataType": "string",
                      "access": "ro",
                      "size": 4,
                      "description": "description of def"
                    },
                    {
                      "name": "xyz",
                      "dataType": "string",
                      "access": "ro",
                      "size": 4,
                      "description": "description of xyz"
                    }
                  ]
                }
              ]
            }
          }
        },
        "tags": [
          "custom-equipment"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      },
      "post": {
        "description": "Create a new Custom Equipment with tags",
        "parameters": [
          {
            "name": "body",
            "in": "body",
            "required": true,
            "schema": {
              "$ref": "#/definitions/CustomEquipment"
            }
          }
        ],
        "responses": {
          "200": {
            "description": "success",
            "schema": {
              "$ref": "#/definitions/CustomEquipment"
            },
            "examples": {
              "application/json": {
                "id": 1,
                "equipmentName": "Promgram-1",
                "equipmentTags": [
                  {
                    "name": "cpu",
                    "dataType": "float32",
                    "access": "ro",
                    "size": 4,
                    "description": "all about cpu"
                  },
                  {
                    "name": "mem",
                    "dataType": "float32",
                    "access": "ro",
                    "size": 4,
                    "description": "all about memory"
                  },
                  {
                    "name": "disk",
                    "dataType": "uint32",
                    "access": "ro",
                    "size": 4,
                    "description": "all about disk"
                  }
                ]
              }
            }
          }
        },
        "tags": [
          "custom-equipment"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      },
      "delete": {
        "description": "Delete a Custom Equipment with assigned IDs",
        "parameters": [
          {
            "name": "body",
            "in": "body",
            "required": true,
            "schema": {
              "type": "array",
              "items": {
                "type": "integer"
              }
            }
          }
        ],
        "responses": {
          "200": {
            "description": "success"
          }
        },
        "tags": [
          "custom-equipment"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      }
    },
    "/mxc/custom/equipments/{id}": {
      "parameters": [
        {
          "name": "id",
          "in": "path",
          "type": "integer",
          "required": true
        }
      ],
      "delete": {
        "description": "Delete a Custom Equipment with assigned ID",
        "responses": {
          "200": {
            "description": "success"
          }
        },
        "tags": [
          "custom-equipment"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      },
      "put": {
        "description": "Update a Custom Equipment with assigned ID",
        "parameters": [
          {
            "name": "body",
            "in": "body",
            "required": true,
            "schema": {
              "$ref": "#/definitions/CustomEquipment"
            }
          }
        ],
        "responses": {
          "200": {
            "description": "success",
            "schema": {
              "$ref": "#/definitions/CustomEquipment"
            },
            "examples": {
              "application/json": {
                "id": 1,
                "equipmentName": "Promgram-1",
                "equipmentTags": [
                  {
                    "name": "cpu",
                    "dataType": "float32",
                    "access": "ro",
                    "size": 4,
                    "description": "all about cpu"
                  },
                  {
                    "name": "mem",
                    "dataType": "float32",
                    "access": "ro",
                    "size": 4,
                    "description": "all about memory"
                  },
                  {
                    "name": "disk",
                    "dataType": "uint32",
                    "access": "ro",
                    "size": 4,
                    "description": "all about disk"
                  }
                ]
              }
            }
          }
        },
        "tags": [
          "custom-equipment"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      }
    },
    "/network/dhcpd": {
      "get": {
        "description": "Get Overview of DHCP Server information",
        "responses": {
          "200": {
            "description": "success",
            "schema": {
              "$ref": "#/definitions/DHCPServerCollection"
            },
            "examples": {
              "application/json": {
                "status": true,
                "collection": [
                  {
                    "id": 1,
                    "name": "eth0",
                    "available": false,
                    "enable": false,
                    "subnet": "192.168.3.0",
                    "netmask": "255.255.255.0",
                    "startIp": "192.168.3.100",
                    "endIp": "192.168.3.150",
                    "domainNameServers": [
                      "8.8.8.8",
                      "1.1.1.1",
                      "2.2.2.2"
                    ],
                    "domainName": "cloud5566",
                    "leaseTime": "3600"
                  }
                ]
              }
            }
          }
        },
        "tags": [
          "dhcpd"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      }
    },
    "/network/dhcpd/{id}": {
      "parameters": [
        {
          "name": "id",
          "in": "path",
          "type": "integer",
          "required": true
        }
      ],
      "get": {
        "description": "Get a dhcp server configuration",
        "responses": {
          "200": {
            "description": "success",
            "schema": {
              "$ref": "#/definitions/DHCPServer"
            },
            "examples": {
              "application/json": {
                "id": 1,
                "name": "eth0",
                "available": false,
                "enable": false,
                "subnet": "192.168.3.0",
                "netmask": "255.255.255.0",
                "startIp": "192.168.3.100",
                "endIp": "192.168.3.150",
                "domainNameServers": [
                  "8.8.8.8",
                  "1.1.1.1",
                  "2.2.2.2"
                ],
                "domainName": "cloud5566",
                "leaseTime": "3600"
              }
            }
          }
        },
        "tags": [
          "dhcpd"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      },
      "put": {
        "parameters": [
          {
            "name": "body",
            "in": "body",
            "required": true,
            "schema": {
              "$ref": "#/definitions/DHCPServer"
            }
          }
        ],
        "description": "Update a dhcp server configuration",
        "responses": {
          "200": {
            "description": "success",
            "schema": {
              "$ref": "#/definitions/DHCPServer"
            },
            "examples": {
              "application/json": {
                "id": 1,
                "name": "eth0",
                "available": false,
                "enable": false,
                "subnet": "192.168.3.0",
                "netmask": "255.255.255.0",
                "startIp": "192.168.3.100",
                "endIp": "192.168.3.150",
                "domainNameServers": [
                  "8.8.8.8",
                  "1.1.1.1",
                  "2.2.2.2"
                ],
                "domainName": "cloud5566",
                "leaseTime": "3600"
              }
            }
          }
        },
        "tags": [
          "dhcpd"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      }
    },
    "/network/dns": {
      "get": {
        "summary": "Information of Current DNS settings",
        "description": "List all current DNS and DNS source.\n",
        "responses": {
          "200": {
            "description": "DNS",
            "schema": {
              "$ref": "#/definitions/DNS"
            },
            "examples": {
              "application/json": {
                "enableFixed": false,
                "fixedDns": [],
                "source": "eth0",
                "dns": [
                  "8.8.8.8",
                  "8.8.4.4"
                ]
              }
            }
          }
        },
        "tags": [
          "dns"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      },
      "put": {
        "parameters": [
          {
            "name": "body",
            "in": "body",
            "required": true,
            "schema": {
              "$ref": "#/definitions/DNS"
            }
          }
        ],
        "summary": "Update DNS settings",
        "description": "Update DNS settings by interface or using fixed DNS.",
        "responses": {
          "200": {
            "description": "OK",
            "schema": {
              "$ref": "#/definitions/DNS"
            },
            "examples": {
              "application/json": {
                "enableFixed": false,
                "fixedDns": [],
                "source": "eth0",
                "dns": [
                  "8.8.8.8",
                  "8.8.4.4"
                ]
              }
            }
          }
        },
        "tags": [
          "dns"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      }
    },
    "/network/ethernets": {
      "get": {
        "summary": "Ethernet Interface(s)",
        "description": "The system returns information about the settings of all\n*Ethernet interface(s)*.\n",
        "responses": {
          "200": {
            "description": "An array of Ethernet interface(s)",
            "schema": {
              "type": "array",
              "items": {
                "$ref": "#/definitions/Ethernet"
              }
            },
            "examples": {
              "application/json": [
                {
                  "id": 1,
                  "wan": true,
                  "name": "eth0",
                  "ip": "192.168.3.127",
                  "mac": "FF:FF:FF:FF:FF:FF",
                  "netmask": "255.255.255.0",
                  "subnet": "192.168.3.0",
                  "gateway": "192.168.3.254",
                  "dns": [
                    "8.8.8.8",
                    "8.8.4.4"
                  ],
                  "status": true,
                  "enable": true,
                  "enableDhcp": false
                },
                {
                  "id": 2,
                  "wan": false,
                  "name": "eth1",
                  "ip": "192.168.100.127",
                  "mac": "FF:FF:FF:FF:FF:FF",
                  "netmask": "255.255.255.0",
                  "subnet": "192.168.100.0",
                  "gateway": "192.168.100.254",
                  "dns": [
                    "8.8.8.8",
                    "8.8.4.4"
                  ],
                  "status": true,
                  "enable": true,
                  "enableDhcp": false,
                  "restart": true
                }
              ]
            }
          }
        },
        "tags": [
          "ethernet"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      },
      "put": {
        "summary": "Ethernet Interface(s)",
        "description": "Update a list of Ethernet interface(s) settings.",
        "responses": {
          "200": {
            "description": "OK",
            "schema": {
              "type": "array",
              "items": {
                "$ref": "#/definitions/Ethernet"
              }
            }
          }
        },
        "tags": [
          "ethernet"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      }
    },
    "/network/ethernets/{id}": {
      "parameters": [
        {
          "name": "id",
          "in": "path",
          "type": "integer",
          "required": true
        }
      ],
      "get": {
        "description": "Get settings of indicated Ethernet interface.\n",
        "responses": {
          "200": {
            "description": "An Ethernet interface settings.",
            "schema": {
              "$ref": "#/definitions/Ethernet"
            },
            "examples": {
              "application/json": {
                "id": 1,
                "wan": true,
                "name": "eth0",
                "ip": "192.168.3.127",
                "mac": "FF:FF:FF:FF:FF:FF",
                "netmask": "255.255.255.0",
                "subnet": "192.168.3.0",
                "gateway": "192.168.3.254",
                "dns": [
                  "8.8.8.8",
                  "8.8.4.4"
                ],
                "status": true,
                "enable": true,
                "enableDhcp": false
              }
            }
          }
        },
        "tags": [
          "ethernet"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      },
      "put": {
        "summary": "Ethernet Interface",
        "description": "Update an Ethernet interface settings.",
        "parameters": [
          {
            "name": "body",
            "in": "body",
            "description": "",
            "required": true,
            "schema": {
              "$ref": "#/definitions/Ethernet"
            }
          }
        ],
        "responses": {
          "200": {
            "description": "OK",
            "schema": {
              "$ref": "#/definitions/Ethernet"
            },
            "examples": {
              "application/json": {
                "id": 1,
                "wan": true,
                "name": "eth0",
                "ip": "192.168.3.127",
                "mac": "FF:FF:FF:FF:FF:FF",
                "netmask": "255.255.255.0",
                "subnet": "192.168.3.0",
                "gateway": "192.168.3.254",
                "dns": [
                  "8.8.8.8",
                  "8.8.4.4"
                ],
                "status": true,
                "enable": true,
                "enableDhcp": false
              }
            }
          }
        },
        "tags": [
          "ethernet"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      }
    },
    "/system/import": {
      "put": {
        "parameters": [
          {
            "name": "body",
            "in": "body",
            "required": true,
            "schema": {
              "$ref": "#/definitions/ImportInfo"
            }
          }
        ],
        "description": "Put a download url with headers and import settings. For more information, please check out tutorial documents about API Endpoint with files.\n",
        "responses": {
          "200": {
            "description": "success"
          }
        },
        "tags": [
          "import-export"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      }
    },
    "/system/export": {
      "post": {
        "parameters": [
          {
            "name": "body",
            "in": "body",
            "required": true,
            "schema": {
              "$ref": "#/definitions/UrlInfo"
            }
          }
        ],
        "description": "Post a target url with headers, bundle would upload to target url and return download url. Target upload server should response in this json format: <pre>\n  {\n    \"fieldname\": \"file\",\n    \"url\": \"/api/v1/files/download/61256ff7db8b7b40e254b940ae639b8e\"\n  }\n</pre> ThingsPro has a built-in simple upload server which is already used by web. In general cases, using the built-in server is highly recommended. Request export to simple upload server with url: `https://localhost/api/v1/files/upload` For more information, please check out tutorial documents about API Endpoint with files.\n",
        "responses": {
          "200": {
            "description": "sucess",
            "schema": {
              "$ref": "#/definitions/UrlInfo"
            },
            "examples": {
              "application/json": {
                "url": "https://localhost/api/v1/files/upload"
              }
            }
          }
        },
        "tags": [
          "import-export"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      }
    },
    "/mxc/logprofile": {
      "get": {
        "description": "Get Log Profile collection",
        "parameters": [
          {
            "name": "destinations",
            "in": "query",
            "required": false,
            "type": "integer"
          }
        ],
        "responses": {
          "200": {
            "description": "success",
            "schema": {
              "type": "array",
              "items": {
                "$ref": "#/definitions/LogProfile"
              }
            },
            "examples": {
              "application/json": [
                {
                  "id": 1,
                  "name": "log-profile-1",
                  "enable": true,
                  "archiver": {
                    "destination": "Internal",
                    "thresholdBytePerFile": 5242800,
                    "directorySizeLimitByte": 10240000,
                    "archivesToKeep": 24
                  },
                  "uploader": {
                    "httpPost": {
                      "url": "http://host/post",
                      "enableAuth": false,
                      "authentication": {
                        "username": "uploader",
                        "password": "password"
                      },
                      "headerList": [
                        {
                          "name": "Content-Type",
                          "value": "application/json"
                        },
                        {
                          "name": "User-Agent",
                          "value": "Mozilla/5.0"
                        }
                      ],
                      "bypassSsl": true,
                      "cronExpr": "0 * * * *",
                      "format": "json",
                      "compress": "gzip",
                      "enableCompress": true,
                      "retryCount": 3,
                      "retryPeriodSec": 3
                    }
                  },
                  "equipmentList": [
                    {
                      "equipmentName": "My-ioLogik-E2242",
                      "equipmentTags": [
                        {
                          "name": "di0",
                          "logOnChange": false
                        },
                        {
                          "name": "di1",
                          "logOnChange": false
                        },
                        {
                          "name": "ai0",
                          "logOnChange": false
                        }
                      ]
                    },
                    {
                      "equipmentName": "My-other-ioLogik-E2242",
                      "equipmentTags": [
                        {
                          "name": "di0",
                          "logOnChange": false
                        },
                        {
                          "name": "di1",
                          "logOnChange": false
                        },
                        {
                          "name": "ai0",
                          "logOnChange": false
                        }
                      ]
                    }
                  ]
                },
                {
                  "id": 2,
                  "enable": false,
                  "name": "log-profile-2",
                  "archiver": {
                    "destination": "Internal",
                    "thresholdBytePerFile": 5242800,
                    "directorySizeLimitByte": 10240000,
                    "archivesToKeep": 24
                  },
                  "uploader": {
                    "httpPost": {
                      "url": "http://host/post",
                      "enableAuth": true,
                      "authentication": {
                        "username": "uploader",
                        "password": "password"
                      },
                      "headerList": [
                        {
                          "name": "Content-Type",
                          "value": "application/json"
                        },
                        {
                          "name": "User-Agent",
                          "value": "Mozilla/5.0"
                        }
                      ],
                      "bypassSsl": true,
                      "cronExpr": "0 * * * *",
                      "format": "json",
                      "compress": "gzip",
                      "enableCompress": false,
                      "retryCount": 3,
                      "retryPeriodSec": 3
                    }
                  },
                  "equipmentList": [
                    {
                      "equipmentName": "My-ioLogik-E2242",
                      "equipmentTags": [
                        {
                          "name": "di0",
                          "logOnChange": true
                        },
                        {
                          "name": "di1",
                          "logOnChange": false
                        },
                        {
                          "name": "ai0",
                          "logOnChange": true
                        }
                      ]
                    },
                    {
                      "equipmentName": "My-other-ioLogik-E2242",
                      "equipmentTags": [
                        {
                          "name": "di0",
                          "logOnChange": true
                        },
                        {
                          "name": "di1",
                          "logOnChange": true
                        },
                        {
                          "name": "ai0",
                          "logOnChange": true
                        }
                      ]
                    }
                  ]
                }
              ]
            }
          },
          "x-query-destinations": {
            "description": "Get logprofile save destination options",
            "schema": {
              "type": "array",
              "items": {
                "$ref": "#/definitions/DestinationEntry"
              }
            },
            "examples": {
              "application/json": [
                {
                  "name": "Internal",
                  "directory": "/var/mxlogariver"
                },
                {
                  "name": "SD",
                  "directory": "/media"
                }
              ]
            }
          }
        },
        "tags": [
          "logprofile"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      },
      "post": {
        "description": "Create a Log Profile",
        "parameters": [
          {
            "name": "body",
            "in": "body",
            "required": true,
            "schema": {
              "$ref": "#/definitions/LogProfile"
            }
          }
        ],
        "responses": {
          "200": {
            "description": "success",
            "schema": {
              "$ref": "#/definitions/LogProfile"
            },
            "examples": {
              "application/json": {
                "id": 1,
                "name": "log-profile-1",
                "enable": true,
                "archiver": {
                  "destination": "Internal",
                  "thresholdBytePerFile": 5242800,
                  "directorySizeLimitByte": 10240000,
                  "archivesToKeep": 24
                },
                "uploader": {
                  "httpPost": {
                    "url": "http://host/post",
                    "enableAuth": false,
                    "authentication": {
                      "username": "uploader",
                      "password": "password"
                    },
                    "headerList": [
                      {
                        "name": "Content-Type",
                        "value": "application/json"
                      },
                      {
                        "name": "User-Agent",
                        "value": "Mozilla/5.0"
                      }
                    ],
                    "bypassSsl": true,
                    "cronExpr": "0 * * * *",
                    "format": "json",
                    "compress": "gzip",
                    "enableCompress": true,
                    "retryCount": 3,
                    "retryPeriodSec": 3
                  }
                },
                "equipmentList": [
                  {
                    "equipmentName": "My-ioLogik-E2242",
                    "equipmentTags": [
                      {
                        "name": "di0",
                        "logOnChange": false
                      },
                      {
                        "name": "di1",
                        "logOnChange": false
                      },
                      {
                        "name": "ai0",
                        "logOnChange": false
                      }
                    ]
                  },
                  {
                    "equipmentName": "My-other-ioLogik-E2242",
                    "equipmentTags": [
                      {
                        "name": "di0",
                        "logOnChange": false
                      },
                      {
                        "name": "di1",
                        "logOnChange": false
                      },
                      {
                        "name": "ai0",
                        "logOnChange": false
                      }
                    ]
                  }
                ]
              }
            }
          }
        },
        "tags": [
          "logprofile"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      }
    },
    "/mxc/logprofile/{id}": {
      "parameters": [
        {
          "name": "id",
          "in": "path",
          "type": "integer",
          "required": true
        }
      ],
      "get": {
        "description": "Get a Log Profile with assigned ID",
        "responses": {
          "200": {
            "description": "success",
            "schema": {
              "$ref": "#/definitions/LogProfile"
            },
            "examples": {
              "application/json": {
                "id": 1,
                "name": "log-profile-1",
                "enable": true,
                "archiver": {
                  "destination": "Internal",
                  "thresholdBytePerFile": 5242800,
                  "directorySizeLimitByte": 10240000,
                  "archivesToKeep": 24
                },
                "uploader": {
                  "httpPost": {
                    "url": "http://host/post",
                    "enableAuth": false,
                    "authentication": {
                      "username": "uploader",
                      "password": "password"
                    },
                    "headerList": [
                      {
                        "name": "Content-Type",
                        "value": "application/json"
                      },
                      {
                        "name": "User-Agent",
                        "value": "Mozilla/5.0"
                      }
                    ],
                    "bypassSsl": true,
                    "cronExpr": "0 * * * *",
                    "format": "json",
                    "compress": "gzip",
                    "enableCompress": true,
                    "retryCount": 3,
                    "retryPeriodSec": 3
                  }
                },
                "equipmentList": [
                  {
                    "equipmentName": "My-ioLogik-E2242",
                    "equipmentTags": [
                      {
                        "name": "di0",
                        "logOnChange": false
                      },
                      {
                        "name": "di1",
                        "logOnChange": false
                      },
                      {
                        "name": "ai0",
                        "logOnChange": false
                      }
                    ]
                  },
                  {
                    "equipmentName": "My-other-ioLogik-E2242",
                    "equipmentTags": [
                      {
                        "name": "di0",
                        "logOnChange": false
                      },
                      {
                        "name": "di1",
                        "logOnChange": false
                      },
                      {
                        "name": "ai0",
                        "logOnChange": false
                      }
                    ]
                  }
                ]
              }
            }
          }
        },
        "tags": [
          "logprofile"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      },
      "delete": {
        "description": "Delete a Log Profile with assigned ID",
        "responses": {
          "200": {
            "description": "success"
          }
        },
        "tags": [
          "logprofile"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      },
      "put": {
        "description": "Update a Log Profile with assigned ID",
        "parameters": [
          {
            "name": "body",
            "in": "body",
            "required": true,
            "schema": {
              "$ref": "#/definitions/LogProfile"
            }
          }
        ],
        "responses": {
          "200": {
            "description": "success",
            "schema": {
              "$ref": "#/definitions/LogProfile"
            },
            "examples": {
              "application/json": {
                "id": 1,
                "name": "log-profile-1",
                "enable": true,
                "archiver": {
                  "destination": "Internal",
                  "thresholdBytePerFile": 5242800,
                  "directorySizeLimitByte": 10240000,
                  "archivesToKeep": 24
                },
                "uploader": {
                  "httpPost": {
                    "url": "http://host/post",
                    "enableAuth": false,
                    "authentication": {
                      "username": "uploader",
                      "password": "password"
                    },
                    "headerList": [
                      {
                        "name": "Content-Type",
                        "value": "application/json"
                      },
                      {
                        "name": "User-Agent",
                        "value": "Mozilla/5.0"
                      }
                    ],
                    "bypassSsl": true,
                    "cronExpr": "0 * * * *",
                    "format": "json",
                    "compress": "gzip",
                    "enableCompress": true,
                    "retryCount": 3,
                    "retryPeriodSec": 3
                  }
                },
                "equipmentList": [
                  {
                    "equipmentName": "My-ioLogik-E2242",
                    "equipmentTags": [
                      {
                        "name": "di0",
                        "logOnChange": false
                      },
                      {
                        "name": "di1",
                        "logOnChange": false
                      },
                      {
                        "name": "ai0",
                        "logOnChange": false
                      }
                    ]
                  },
                  {
                    "equipmentName": "My-other-ioLogik-E2242",
                    "equipmentTags": [
                      {
                        "name": "di0",
                        "logOnChange": false
                      },
                      {
                        "name": "di1",
                        "logOnChange": false
                      },
                      {
                        "name": "ai0",
                        "logOnChange": false
                      }
                    ]
                  }
                ]
              }
            }
          }
        },
        "tags": [
          "logprofile"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      }
    },
    "/mxc/equipments": {
      "get": {
        "description": "Get all equipment tags. If equipment name conflicts, it will merged into one tag and concat description with \";\"",
        "responses": {
          "200": {
            "description": "success",
            "schema": {
              "type": "array",
              "items": {
                "$ref": "#/definitions/LogListEquipment"
              }
            },
            "examples": {
              "application/json": [
                {
                  "equipmentType": "modbus",
                  "equipmentName": "My-other-ioLogik-E2242",
                  "equipmentTags": [
                    {
                      "name": "di0",
                      "dataType": "boolean",
                      "access": "ro",
                      "size": 1,
                      "description": "di0",
                      "function": "read-discrete-inputs",
                      "address": 0,
                      "quantity": 1
                    },
                    {
                      "name": "di1",
                      "dataType": "boolean",
                      "access": "ro",
                      "size": 1,
                      "description": "di1",
                      "function": "read-discrete-inputs",
                      "address": 1,
                      "quantity": 1
                    },
                    {
                      "name": "ai0",
                      "dataType": "uint16",
                      "access": "ro",
                      "size": 2,
                      "description": "ai0",
                      "function": "read-holding-registers",
                      "address": 0,
                      "quantity": 1
                    }
                  ]
                },
                {
                  "equipmentType": "user",
                  "equipmentName": "program-1",
                  "equipmentTags": [
                    {
                      "name": "cpu",
                      "dataType": "float32",
                      "access": "ro",
                      "size": 4,
                      "description": "CPU Usage (%)"
                    },
                    {
                      "name": "memory",
                      "dataType": "float32",
                      "access": "ro",
                      "size": 4,
                      "description": "Memory Usage (%)"
                    },
                    {
                      "name": "abc",
                      "dataType": "string",
                      "access": "ro",
                      "size": 4,
                      "description": "def"
                    }
                  ]
                }
              ]
            }
          }
        },
        "tags": [
          "logprofile"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      }
    },
    "/mxc/modbusslave": {
      "get": {
        "description": "Get Modbus Slave Configuration",
        "responses": {
          "200": {
            "description": "success",
            "schema": {
              "$ref": "#/definitions/ModbusSlave"
            },
            "examples": {
              "application/json": {
                "enable": true,
                "host": "0.0.0.0",
                "port": 502,
                "unitId": 255,
                "ignoreUnitId": false,
                "anyHost": true
              }
            }
          }
        },
        "tags": [
          "modbusslave"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      },
      "put": {
        "description": "Update Modbus Slave Configuration",
        "parameters": [
          {
            "name": "body",
            "in": "body",
            "required": true,
            "schema": {
              "$ref": "#/definitions/ModbusSlave"
            }
          }
        ],
        "responses": {
          "200": {
            "description": "success",
            "schema": {
              "$ref": "#/definitions/ModbusSlave"
            },
            "examples": {
              "application/json": {
                "enable": true,
                "host": "0.0.0.0",
                "port": 502,
                "unitId": 255,
                "ignoreUnitId": false,
                "anyHost": true
              }
            }
          }
        },
        "tags": [
          "modbusslave"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      }
    },
    "/mxc/modbusslave/mappings": {
      "get": {
        "description": "Get Modbus Slave Mapping Table",
        "responses": {
          "200": {
            "description": "success",
            "schema": {
              "type": "array",
              "items": {
                "$ref": "#/definitions/MappingEntry"
              }
            },
            "examples": {
              "application/json": [
                {
                  "id": 1,
                  "reference": "0x40000",
                  "quantity": 1,
                  "equipmentName": "My_ioLogik-E2242",
                  "equipmentType": "modbus",
                  "tagName": "ai0"
                }
              ]
            }
          }
        },
        "tags": [
          "modbusslave"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      },
      "post": {
        "description": "Create a Mapping Entry",
        "parameters": [
          {
            "name": "body",
            "in": "body",
            "required": true,
            "schema": {
              "$ref": "#/definitions/MappingEntry"
            }
          }
        ],
        "responses": {
          "200": {
            "description": "success",
            "schema": {
              "$ref": "#/definitions/MappingEntry"
            },
            "examples": {
              "application/json": {
                "id": 1,
                "reference": "0x40000",
                "quantity": 1,
                "equipmentName": "My_ioLogik-E2242",
                "equipmentType": "modbus",
                "tagName": "ai0"
              }
            }
          }
        },
        "tags": [
          "modbusslave"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      },
      "put": {
        "description": "Update Modbus Slave Mapping Table",
        "parameters": [
          {
            "name": "body",
            "in": "body",
            "required": true,
            "schema": {
              "type": "array",
              "items": {
                "$ref": "#/definitions/MappingEntry"
              }
            }
          }
        ],
        "responses": {
          "200": {
            "description": "success",
            "schema": {
              "type": "array",
              "items": {
                "$ref": "#/definitions/MappingEntry"
              }
            },
            "examples": {
              "application/json": [
                {
                  "id": 1,
                  "reference": "0x40000",
                  "quantity": 1,
                  "equipmentName": "My_ioLogik-E2242",
                  "equipmentType": "modbus",
                  "tagName": "ai0"
                }
              ]
            }
          }
        },
        "tags": [
          "modbusslave"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      },
      "delete": {
        "description": "Delete a list of MappingEntry with assigned ID",
        "parameters": [
          {
            "name": "body",
            "in": "body",
            "required": true,
            "schema": {
              "type": "array",
              "items": {
                "type": "integer"
              }
            }
          }
        ],
        "responses": {
          "200": {
            "description": "success"
          }
        },
        "tags": [
          "modbusslave"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      }
    },
    "/mxc/mxmodbusslave/mappings/{id}": {
      "parameters": [
        {
          "name": "id",
          "in": "path",
          "type": "integer",
          "required": true
        }
      ],
      "get": {
        "description": "Get a MappingEntry with assigned ID",
        "responses": {
          "200": {
            "description": "success",
            "schema": {
              "$ref": "#/definitions/MappingEntry"
            },
            "examples": {
              "application/json": {
                "id": 1,
                "reference": "0x40000",
                "quantity": 1,
                "equipmentName": "My_ioLogik-E2242",
                "equipmentType": "modbus",
                "tagName": "ai0"
              }
            }
          }
        },
        "tags": [
          "modbusslave"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      },
      "delete": {
        "description": "Delete a MappingEntry with assigned ID",
        "responses": {
          "200": {
            "description": "success"
          }
        },
        "tags": [
          "modbusslave"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      },
      "put": {
        "description": "Update a MappingEntry with assigned ID",
        "parameters": [
          {
            "name": "body",
            "in": "body",
            "required": true,
            "schema": {
              "$ref": "#/definitions/MappingEntry"
            }
          }
        ],
        "responses": {
          "200": {
            "description": "success",
            "schema": {
              "$ref": "#/definitions/MappingEntry"
            },
            "examples": {
              "application/json": {
                "id": 1,
                "reference": "0x40000",
                "quantity": 1,
                "equipmentName": "My_ioLogik-E2242",
                "equipmentType": "modbus",
                "tagName": "ai0"
              }
            }
          }
        },
        "tags": [
          "modbusslave"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      }
    },
    "/network/openvpn": {
      "get": {
        "description": "Get OpenVPN service setting.",
        "responses": {
          "200": {
            "description": "Get OpenVPN setting success.",
            "schema": {
              "$ref": "#/definitions/OpenVPN"
            },
            "examples": {
              "application/json": {
                "enable": true,
                "ovpnFileExist": true,
                "connection": true,
                "vpnRemoteIp": "10.9.8.1",
                "vpnLocalIp": "10.9.8.2"
              }
            }
          }
        },
        "tags": [
          "openvpn"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      },
      "put": {
        "description": "Update OpenVPN service setting.",
        "parameters": [
          {
            "name": "body",
            "in": "body",
            "required": true,
            "schema": {
              "$ref": "#/definitions/OpenVPN"
            }
          }
        ],
        "responses": {
          "200": {
            "description": "Update OpenVPN setting success.",
            "schema": {
              "$ref": "#/definitions/OpenVPN"
            },
            "examples": {
              "application/json": {
                "enable": true,
                "ovpnFileExist": true,
                "connection": true,
                "vpnRemoteIp": "10.9.8.1",
                "vpnLocalIp": "10.9.8.2"
              }
            }
          }
        },
        "tags": [
          "openvpn"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      }
    },
    "/network/openvpn/config": {
      "post": {
        "description": "Upload OpenVPN configuration file to File server.",
        "parameters": [
          {
            "name": "body",
            "in": "body",
            "required": true,
            "schema": {
              "$ref": "#/definitions/OpenVPNPostConfig"
            }
          }
        ],
        "responses": {
          "200": {
            "description": "Upload success.",
            "schema": {
              "$ref": "#/definitions/OpenVPNConfigURL"
            },
            "examples": {
              "application/json": {
                "url": "http://192.168.31.113:18080/url"
              }
            }
          }
        },
        "tags": [
          "openvpn"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      },
      "put": {
        "description": "Provide OpenVPN configuration file path to bundle.",
        "parameters": [
          {
            "name": "body",
            "in": "body",
            "required": true,
            "schema": {
              "$ref": "#/definitions/OpenVPNConfig"
            }
          }
        ],
        "responses": {
          "200": {
            "description": "Provide success."
          }
        },
        "tags": [
          "openvpn"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      },
      "delete": {
        "responses": {
          "200": {
            "description": "Delete OpenVPN configuration file success."
          }
        },
        "tags": [
          "openvpn"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      }
    },
    "/network/openvpn/sample": {
      "post": {
        "description": "Upload OpenVPN sample configuration file to File server.",
        "parameters": [
          {
            "name": "body",
            "in": "body",
            "required": true,
            "schema": {
              "$ref": "#/definitions/OpenVPNPostConfig"
            }
          }
        ],
        "responses": {
          "200": {
            "description": "Upload success.",
            "schema": {
              "$ref": "#/definitions/OpenVPNConfigURL"
            },
            "examples": {
              "application/json": {
                "url": "http://192.168.31.113:18080/url"
              }
            }
          }
        },
        "tags": [
          "openvpn"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      }
    },
    "/system/programs": {
      "get": {
        "description": "Get all custom programs",
        "responses": {
          "200": {
            "description": "success",
            "schema": {
              "$ref": "#/definitions/Programs"
            },
            "examples": {
              "application/json": [
                {
                  "id": 1,
                  "name": "my-user-program",
                  "enable": true,
                  "startMode": "period",
                  "args": "--url http://localhost",
                  "period": 12,
                  "timeout": 1,
                  "lastExcutedTime": "2017-01-09T06:46:01.181Z",
                  "fileExist": true,
                  "logsExist": true
                },
                {
                  "id": 2,
                  "name": "my-user-program-2",
                  "enable": true,
                  "startMode": "period",
                  "args": "--url http://localhost",
                  "period": 10,
                  "timeout": 1,
                  "lastExcutedTime": "2017-01-09T06:46:01.181Z",
                  "fileExist": false,
                  "logsExist": false
                }
              ]
            }
          }
        },
        "tags": [
          "program"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      },
      "post": {
        "description": "Create a new Program",
        "parameters": [
          {
            "name": "body",
            "in": "body",
            "description": "",
            "required": true,
            "schema": {
              "$ref": "#/definitions/UpdateProgram"
            }
          }
        ],
        "responses": {
          "200": {
            "description": "OK",
            "schema": {
              "$ref": "#/definitions/Program"
            },
            "examples": {
              "application/json": {
                "id": 1,
                "name": "my-user-program",
                "enable": true,
                "startMode": "period",
                "args": "--url http://localhost",
                "period": 10,
                "timeout": 1,
                "lastExcutedTime": "2017-01-09T06:46:01.181Z",
                "fileExist": true,
                "logsExist": true,
                "file": {
                  "url": "http://remote-download-url/file.tar.gz",
                  "headers": {
                    "authorization": "xxxxxxx"
                  }
                }
              }
            }
          }
        },
        "tags": [
          "program"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      },
      "delete": {
        "description": "Delete Programs",
        "parameters": [
          {
            "name": "body",
            "in": "body",
            "description": "",
            "required": true,
            "schema": {
              "type": "array",
              "items": {
                "type": "number",
                "description": "IDs"
              }
            }
          }
        ],
        "responses": {
          "200": {
            "description": "OK",
            "schema": {
              "type": "object",
              "properties": {
                "count": {
                  "type": "number",
                  "description": "Affected number of rows"
                }
              }
            },
            "examples": {
              "count": 1
            }
          }
        },
        "tags": [
          "program"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      }
    },
    "/system/programs/{id}": {
      "parameters": [
        {
          "name": "id",
          "in": "path",
          "type": "integer",
          "required": true
        }
      ],
      "get": {
        "description": "Get program by given id",
        "responses": {
          "200": {
            "description": "success",
            "schema": {
              "$ref": "#/definitions/Program"
            },
            "examples": {
              "application/json": {
                "id": 1,
                "name": "my-user-program",
                "enable": true,
                "startMode": "period",
                "args": "--url http://localhost",
                "period": 10,
                "timeout": 1,
                "lastExcutedTime": "2017-01-09T06:46:01.181Z",
                "fileExist": true,
                "logsExist": true,
                "file": {
                  "url": "http://remote-download-url/file.tar.gz",
                  "headers": {
                    "authorization": "xxxxxxx"
                  }
                }
              }
            }
          }
        },
        "tags": [
          "program"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      },
      "put": {
        "description": "Update program settings by given id",
        "parameters": [
          {
            "name": "body",
            "in": "body",
            "description": "",
            "required": true,
            "schema": {
              "$ref": "#/definitions/UpdateProgram"
            }
          }
        ],
        "responses": {
          "200": {
            "description": "OK",
            "schema": {
              "$ref": "#/definitions/Program"
            },
            "examples": {
              "application/json": {
                "id": 1,
                "name": "my-user-program",
                "enable": true,
                "startMode": "period",
                "args": "--url http://localhost",
                "period": 10,
                "timeout": 1,
                "lastExcutedTime": "2017-01-09T06:46:01.181Z",
                "fileExist": true,
                "logsExist": true,
                "file": {
                  "url": "http://remote-download-url/file.tar.gz",
                  "headers": {
                    "authorization": "xxxxxxx"
                  }
                }
              }
            }
          }
        },
        "tags": [
          "program"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      }
    },
    "/system/programs/{id}/file": {
      "parameters": [
        {
          "name": "id",
          "in": "path",
          "type": "integer",
          "required": true
        }
      ],
      "post": {
        "description": "Download program by given id",
        "responses": {
          "200": {
            "description": "success",
            "schema": {
              "$ref": "#/definitions/Download"
            },
            "examples": {
              "application/json": {
                "url": "http://download/file"
              }
            }
          }
        },
        "tags": [
          "program"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      }
    },
    "/system/programs/{id}/logs": {
      "parameters": [
        {
          "name": "id",
          "in": "path",
          "type": "integer",
          "required": true
        }
      ],
      "post": {
        "description": "Download logs by given id",
        "responses": {
          "200": {
            "description": "success"
          }
        },
        "tags": [
          "program"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      }
    },
    "/system/remotecontrol": {
      "get": {
        "description": "Get current settings of remote control",
        "responses": {
          "200": {
            "description": "success",
            "schema": {
              "$ref": "#/definitions/RemoteControl"
            },
            "examples": {
              "application/json": {
                "enable": true,
                "deviceUUID": "f71b4639-d7bb-4fc3-9ee6-c8d08d47f227",
                "keepalive": 60,
                "remoteHost": "moxa.thingspro.local",
                "remotePort": 8080,
                "remoteProtocol": "mqtt",
                "psk": "123sdlkfjasldkfjoasdfjioawjerioqwejrasdfjoi2345klscv"
              }
            }
          }
        },
        "tags": [
          "remotecontrol"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      },
      "put": {
        "description": "Update settings of remote control",
        "parameters": [
          {
            "name": "body",
            "in": "body",
            "required": true,
            "schema": {
              "$ref": "#/definitions/RemoteControl"
            }
          }
        ],
        "responses": {
          "200": {
            "description": "success",
            "schema": {
              "$ref": "#/definitions/RemoteControl"
            },
            "examples": {
              "application/json": {
                "enable": true,
                "deviceUUID": "f71b4639-d7bb-4fc3-9ee6-c8d08d47f227",
                "keepalive": 60,
                "remoteHost": "moxa.thingspro.local",
                "remotePort": 8080,
                "remoteProtocol": "mqtt",
                "psk": "123sdlkfjasldkfjoasdfjioawjerioqwejrasdfjoi2345klscv"
              }
            }
          }
        },
        "tags": [
          "remotecontrol"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      }
    },
    "/system/remotecontrol/test": {
      "post": {
        "description": "Test settings of remote control",
        "parameters": [
          {
            "name": "body",
            "in": "body",
            "required": true,
            "schema": {
              "$ref": "#/definitions/RemoteControl"
            }
          }
        ],
        "responses": {
          "200": {
            "description": "success",
            "schema": {
              "$ref": "#/definitions/TestResult"
            },
            "examples": {
              "application/json": {
                "status": "success",
                "log": "connected to xxxx"
              }
            }
          }
        },
        "tags": [
          "remotecontrol"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      }
    },
    "/network/routes/default": {
      "get": {
        "summary": "Current Default Route and priority list",
        "description": "The system returns the current default route information and default\nroute priority list.\n",
        "responses": {
          "200": {
            "description": "Default Route",
            "schema": {
              "$ref": "#/definitions/DefaultRoute"
            },
            "examples": {
              "application/json": {
                "interface": "eth0",
                "gateway": "192.168.3.254",
                "priorityList": [
                  "wwan0",
                  "eth0"
                ]
              }
            }
          }
        },
        "tags": [
          "route"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      },
      "put": {
        "parameters": [
          {
            "name": "body",
            "in": "body",
            "required": true,
            "schema": {
              "$ref": "#/definitions/DefaultRoute"
            }
          }
        ],
        "summary": "Update Default Route Setting",
        "description": "Update the default route list.",
        "responses": {
          "200": {
            "description": "OK",
            "schema": {
              "$ref": "#/definitions/DefaultRoute"
            },
            "examples": {
              "application/json": {
                "priorityList": [
                  "wwan0",
                  "eth0"
                ]
              }
            }
          }
        },
        "tags": [
          "route"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      }
    },
    "/system/serial": {
      "get": {
        "description": "Get all of serial interfaces settings",
        "responses": {
          "200": {
            "description": "success",
            "schema": {
              "$ref": "#/definitions/Serials"
            },
            "examples": {
              "application/json": [
                {
                  "id": 1,
                  "dev": "/dev/ttyM0",
                  "devDisplayName": "PORT-1",
                  "mode": "rs232"
                },
                {
                  "id": 2,
                  "dev": "/dev/ttyM1",
                  "devDisplayName": "PORT-2",
                  "mode": "rs485-2w"
                },
                {
                  "id": 3,
                  "dev": "/dev/ttyM2",
                  "devDisplayName": "PORT 3",
                  "mode": "rs422/rs485-4w"
                }
              ]
            }
          }
        },
        "tags": [
          "serial"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      }
    },
    "/system/serial/{id}": {
      "parameters": [
        {
          "name": "id",
          "in": "path",
          "type": "integer",
          "required": true
        }
      ],
      "get": {
        "description": "Get a serial interface configuration",
        "responses": {
          "200": {
            "description": "success",
            "schema": {
              "$ref": "#/definitions/Serial"
            },
            "examples": {
              "application/json": {
                "id": 1,
                "dev": "/dev/ttyM0",
                "devDisplayName": "PORT-1",
                "mode": "rs232"
              }
            }
          }
        },
        "tags": [
          "serial"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      },
      "put": {
        "parameters": [
          {
            "name": "body",
            "in": "body",
            "required": true,
            "schema": {
              "$ref": "#/definitions/Serial"
            }
          }
        ],
        "description": "Update a dhcp server configuration",
        "responses": {
          "200": {
            "description": "success",
            "schema": {
              "$ref": "#/definitions/Serial"
            },
            "examples": {
              "application/json": {
                "id": 1,
                "dev": "/dev/ttyM0",
                "devDisplayName": "PORT-1",
                "mode": "rs232"
              }
            }
          }
        },
        "tags": [
          "serial"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      }
    },
    "/system/services": {
      "get": {
        "description": "Get system services status",
        "responses": {
          "200": {
            "description": "success",
            "schema": {
              "type": "array",
              "items": {
                "$ref": "#/definitions/Service"
              }
            },
            "examples": {
              "application/json": [
                {
                  "id": 1,
                  "enable": true,
                  "name": "ssh",
                  "status": true
                },
                {
                  "id": 2,
                  "enable": true,
                  "name": "rsyslog",
                  "status": true
                }
              ]
            }
          }
        },
        "tags": [
          "service"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      }
    },
    "/system/services/{name}": {
      "put": {
        "description": "Update service settings",
        "parameters": [
          {
            "name": "name",
            "in": "path",
            "required": true,
            "type": "string"
          },
          {
            "name": "body",
            "in": "body",
            "required": true,
            "schema": {
              "$ref": "#/definitions/Service"
            }
          }
        ],
        "responses": {
          "200": {
            "description": "success",
            "schema": {
              "$ref": "#/definitions/Service"
            },
            "examples": {
              "application/json": {
                "id": 1,
                "enable": true,
                "name": "ssh",
                "status": true
              }
            }
          }
        },
        "tags": [
          "service"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      },
      "get": {
        "parameters": [
          {
            "name": "name",
            "in": "path",
            "required": true,
            "type": "string"
          }
        ],
        "description": "Get specific service status",
        "responses": {
          "200": {
            "description": "success",
            "schema": {
              "$ref": "#/definitions/Service"
            },
            "examples": {
              "application/json": {
                "id": 1,
                "enable": true,
                "name": "ssh",
                "status": true
              }
            }
          }
        },
        "tags": [
          "service"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      }
    },
    "/system/status": {
      "get": {
        "parameters": [
          {
            "name": "fields",
            "in": "query",
            "required": false,
            "type": "string",
            "description": "Only get selected fields. Using comma as separator (?fields=cpuUsage,uptimeSec,version)"
          }
        ],
        "description": "Get system status",
        "responses": {
          "200": {
            "description": "success",
            "schema": {
              "$ref": "#/definitions/SystemStatus"
            },
            "examples": {
              "application/json": {
                "hostname": "Moxa",
                "version": "1.1.0-1",
                "uptimeSec": 312956,
                "cpuUsage": 5.7,
                "memoryUsage": 63.8,
                "memory": 257286144,
                "disks": [
                  {
                    "name": "system",
                    "mount": "/",
                    "device": "rootfs",
                    "usage": {
                      "total": 770695168,
                      "used": 497655808,
                      "free": 217038848,
                      "percent": 64.6
                    }
                  },
                  {
                    "name": "sd1",
                    "mount": "/media/sd-mmcblk1p1",
                    "device": "/dev/mmcblk1p1",
                    "usage": {
                      "total": 770695168,
                      "used": 497655808,
                      "free": 217038848,
                      "percent": 64.6
                    }
                  }
                ]
              }
            }
          }
        },
        "tags": [
          "status"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      },
      "put": {
        "parameters": [
          {
            "name": "body",
            "in": "body",
            "required": true,
            "schema": {
              "$ref": "#/definitions/SystemStatus"
            }
          }
        ],
        "description": "Update hostname",
        "responses": {
          "200": {
            "description": "success",
            "schema": {
              "$ref": "#/definitions/SystemStatus"
            },
            "examples": {
              "application/json": {
                "hostname": "Moxa",
                "version": "1.1.0-1",
                "uptimeSec": 312956,
                "cpuUsage": 5.7,
                "memoryUsage": 63.8,
                "memory": 257286144,
                "disks": [
                  {
                    "name": "system",
                    "mount": "/",
                    "device": "rootfs",
                    "usage": {
                      "total": 770695168,
                      "used": 497655808,
                      "free": 217038848,
                      "percent": 64.6
                    }
                  },
                  {
                    "name": "sd1",
                    "mount": "/media/sd-mmcblk1p1",
                    "device": "/dev/mmcblk1p1",
                    "usage": {
                      "total": 770695168,
                      "used": 497655808,
                      "free": 217038848,
                      "percent": 64.6
                    }
                  }
                ]
              }
            }
          }
        },
        "tags": [
          "status"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      }
    },
    "/system/reboot": {
      "post": {
        "description": "Reboot system (delay: 3 sec)",
        "responses": {
          "200": {
            "description": "success"
          }
        },
        "tags": [
          "status"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      }
    },
    "/system/syslog": {
      "post": {
        "parameters": [
          {
            "name": "body",
            "in": "body",
            "required": true,
            "schema": {
              "$ref": "#/definitions/UrlInfo"
            }
          }
        ],
        "description": "Uplaod system logs to remote server",
        "responses": {
          "200": {
            "description": "sucess",
            "schema": {
              "$ref": "#/definitions/UrlInfo"
            },
            "examples": {
              "application/json": {
                "url": "https://www.google.com"
              }
            }
          }
        },
        "tags": [
          "status"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      }
    },
    "/network/interfaces": {
      "get": {
        "description": "Get network interfaces",
        "responses": {
          "200": {
            "description": "success",
            "schema": {
              "$ref": "#/definitions/NetworkInterfaces"
            },
            "examples": {
              "application/json": [
                "tunl0",
                "eth0",
                "eth1"
              ]
            }
          }
        },
        "tags": [
          "status"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      }
    },
    "/system/password": {
      "put": {
        "parameters": [
          {
            "name": "body",
            "in": "body",
            "required": true,
            "schema": {
              "$ref": "#/definitions/SystemPassword"
            }
          }
        ],
        "description": "Update OS password",
        "responses": {
          "200": {
            "description": "success"
          }
        },
        "tags": [
          "status"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      }
    },
    "/system/properties": {
      "get": {
        "description": "Get system properties",
        "responses": {
          "200": {
            "schema": {
              "$ref": "#/definitions/SystemProperties"
            },
            "description": "success",
            "examples": {
              "application/json": {
                "gps": {
                  "lat": 121.123,
                  "lng": 22.456
                },
                "aliasName": "my iot gateway"
              }
            }
          }
        },
        "tags": [
          "status"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      }
    },
    "/system/properties/{key}": {
      "parameters": [
        {
          "name": "key",
          "in": "path",
          "type": "string",
          "required": true
        }
      ],
      "get": {
        "description": "Get specific system property",
        "responses": {
          "200": {
            "schema": {
              "allOf": [
                {
                  "$ref": "#/definitions/SystemProperties/properties/aliasName"
                },
                {
                  "$ref": "#/definitions/SystemProperties/properties/gps"
                }
              ]
            },
            "description": "success",
            "examples": {
              "application/json": {
                "lat": 121.123,
                "lng": 22.456
              }
            }
          }
        },
        "tags": [
          "status"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      },
      "put": {
        "description": "Update specific system property",
        "parameters": [
          {
            "name": "body",
            "in": "body",
            "required": true,
            "schema": {
              "$ref": "#/definitions/SystemPropertiesUpdate"
            }
          }
        ],
        "responses": {
          "200": {
            "description": "success",
            "examples": {
              "application/json": {
                "lat": 121.123,
                "lng": 22.456
              }
            }
          }
        },
        "tags": [
          "status"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      }
    },
    "/mxc/system/equipments": {
      "get": {
        "description": "Get system tag information",
        "responses": {
          "200": {
            "description": "success",
            "schema": {
              "$ref": "#/definitions/Equipments"
            },
            "examples": {
              "application/json": [
                {
                  "equipmentName": "SYSTEM",
                  "equipmentTags": [
                    {
                      "name": "cpu_usage",
                      "dataType": "float64",
                      "access": "ro",
                      "size": 8,
                      "description": "CPU Usage"
                    },
                    {
                      "name": "memory_usage",
                      "dataType": "float64",
                      "access": "ro",
                      "size": 8,
                      "description": "Memory Usage"
                    },
                    {
                      "name": "disk_usage",
                      "dataType": "float64",
                      "access": "ro",
                      "size": 8,
                      "description": "Disk Usage"
                    }
                  ]
                }
              ]
            }
          }
        },
        "tags": [
          "status"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      }
    },
    "/system/time": {
      "get": {
        "description": "Get current time settings",
        "responses": {
          "200": {
            "description": "success",
            "schema": {
              "$ref": "#/definitions/Time"
            },
            "examples": {
              "application/json": {
                "time": "2015-03-26T16:27:48.611441Z",
                "timezone": "Asia/Taipei",
                "ntp": {
                  "enable": true,
                  "server": "pool.ntp.org",
                  "interval": 86400
                }
              }
            }
          }
        },
        "tags": [
          "time"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      },
      "put": {
        "parameters": [
          {
            "name": "body",
            "in": "body",
            "required": true,
            "schema": {
              "$ref": "#/definitions/Time"
            }
          }
        ],
        "description": "Update time settings",
        "responses": {
          "200": {
            "description": "success",
            "schema": {
              "$ref": "#/definitions/Time"
            },
            "examples": {
              "application/json": {
                "time": "2015-03-26T16:27:48.611441Z",
                "timezone": "Asia/Taipei",
                "ntp": {
                  "enable": true,
                  "server": "pool.ntp.org",
                  "interval": 86400
                }
              }
            }
          }
        },
        "tags": [
          "time"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      }
    },
    "/system/zoneinfo": {
      "get": {
        "description": "Get current timezone information",
        "responses": {
          "200": {
            "description": "success",
            "schema": {
              "$ref": "#/definitions/Timezone"
            },
            "examples": {
              "application/json": {
                "zone": [
                  {
                    "cca2": "AD",
                    "name": "Europe/Andorra",
                    "offset": "+0100"
                  },
                  {
                    "cca2": "AE",
                    "name": "Asia/Dubai",
                    "offset": "+0400"
                  },
                  {
                    "cca2": "AF",
                    "name": "Asia/Kabul",
                    "offset": "+0430"
                  }
                ],
                "iso3166": [
                  {
                    "cca2": "AD",
                    "name": "Andorra"
                  },
                  {
                    "cca2": "AE",
                    "name": "United Arab Emirates"
                  },
                  {
                    "cca2": "AF",
                    "name": "Afghanistan"
                  }
                ]
              }
            }
          }
        },
        "tags": [
          "time"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      },
      "post": {
        "description": "Update timezone information from internet",
        "responses": {
          "200": {
            "description": "success"
          }
        },
        "tags": [
          "time"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      }
    },
    "/system/firmware": {
      "post": {
        "description": "Upgrade firmware by given url",
        "parameters": [
          {
            "name": "body",
            "in": "body",
            "required": true,
            "schema": {
              "$ref": "#/definitions/FirmwareInfo"
            }
          }
        ],
        "responses": {
          "200": {
            "description": "success"
          }
        },
        "tags": [
          "firmware"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      }
    },
    "/network/wifi": {
      "get": {
        "summary": "WiFi Interface(s)",
        "description": "The system returns information about the settings of all\n*WiFi interface(s)*.\n",
        "responses": {
          "200": {
            "description": "An array of WiFi interface(s)",
            "schema": {
              "type": "array",
              "items": {
                "$ref": "#/definitions/WiFiIface"
              }
            },
            "examples": {
              "application/json": [
                {
                  "id": 1,
                  "name": "wlan0",
                  "product": "WPEQ-353ACNI",
                  "capabilities": [
                    "client",
                    "ap"
                  ],
                  "mode": "client",
                  "enable": true,
                  "status": true,
                  "client": {
                    "enableDhcp": true,
                    "networks": [
                      {
                        "ssid": "test-none",
                        "security": "none"
                      },
                      {
                        "ssid": "test-wpa",
                        "security": "wpa",
                        "password": "12345678",
                        "priority": 5
                      },
                      {
                        "ssid": "test-eap",
                        "security": "eap",
                        "username": "moxa",
                        "password": "moxa",
                        "priority": 10
                      },
                      {
                        "ssid": "test-wep",
                        "security": "wep",
                        "password": "12345",
                        "priority": 1
                      }
                    ],
                    "signal": 100,
                    "ip": "111.70.146.125",
                    "netmask": "255.255.255.252",
                    "gateway": "111.70.146.126",
                    "dns": [
                      "168.95.1.1",
                      "168.95.192.1"
                    ],
                    "usage": {
                      "txkbyte": 40023,
                      "rxkbyte": 3493
                    },
                    "checkalive": {
                      "enable": true,
                      "targetHost": "8.8.8.8",
                      "intervalSec": 60
                    }
                  },
                  "ap": {
                    "mode": "bg",
                    "ssid": "moxa-test",
                    "channel": 11,
                    "security": {
                      "mode": "none"
                    }
                  }
                }
              ]
            }
          }
        },
        "tags": [
          "wifi"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      }
    },
    "/network/wifi/{id}": {
      "parameters": [
        {
          "name": "id",
          "in": "path",
          "type": "integer",
          "required": true
        }
      ],
      "get": {
        "description": "Get settings of indicated WiFi interface.\n",
        "responses": {
          "200": {
            "description": "An WiFi interface settings.",
            "schema": {
              "$ref": "#/definitions/WiFiIface"
            },
            "examples": {
              "application/json": {
                "id": 1,
                "name": "wlan0",
                "product": "WPEQ-353ACNI",
                "capabilities": [
                  "client",
                  "ap"
                ],
                "mode": "client",
                "enable": true,
                "status": true,
                "client": {
                  "enableDhcp": true,
                  "networks": [
                    {
                      "ssid": "test-none",
                      "security": "none"
                    },
                    {
                      "ssid": "test-wpa",
                      "security": "wpa",
                      "password": "12345678",
                      "priority": 5
                    },
                    {
                      "ssid": "test-eap",
                      "security": "eap",
                      "username": "moxa",
                      "password": "moxa",
                      "priority": 10
                    },
                    {
                      "ssid": "test-wep",
                      "security": "wep",
                      "password": "12345",
                      "priority": 1
                    }
                  ],
                  "signal": 100,
                  "ip": "111.70.146.125",
                  "netmask": "255.255.255.252",
                  "gateway": "111.70.146.126",
                  "dns": [
                    "168.95.1.1",
                    "168.95.192.1"
                  ],
                  "usage": {
                    "txkbyte": 40023,
                    "rxkbyte": 3493
                  },
                  "checkalive": {
                    "enable": true,
                    "targetHost": "8.8.8.8",
                    "intervalSec": 60
                  }
                },
                "ap": {
                  "mode": "bg",
                  "ssid": "moxa-test",
                  "channel": 11,
                  "security": {
                    "mode": "none"
                  }
                }
              }
            }
          }
        },
        "tags": [
          "wifi"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      },
      "put": {
        "summary": "WiFi Interface",
        "description": "Update an WiFi interface settings.",
        "parameters": [
          {
            "name": "body",
            "in": "body",
            "description": "",
            "required": true,
            "schema": {
              "$ref": "#/definitions/WiFiIface"
            }
          }
        ],
        "responses": {
          "200": {
            "description": "OK",
            "schema": {
              "$ref": "#/definitions/WiFiIface"
            },
            "examples": {
              "application/json": {
                "id": 1,
                "name": "wlan0",
                "product": "WPEQ-353ACNI",
                "capabilities": [
                  "client",
                  "ap"
                ],
                "mode": "client",
                "enable": true,
                "status": true,
                "client": {
                  "enableDhcp": true,
                  "networks": [
                    {
                      "ssid": "test-none",
                      "security": "none"
                    },
                    {
                      "ssid": "test-wpa",
                      "security": "wpa",
                      "password": "12345678",
                      "priority": 5
                    },
                    {
                      "ssid": "test-eap",
                      "security": "eap",
                      "username": "moxa",
                      "password": "moxa",
                      "priority": 10
                    },
                    {
                      "ssid": "test-wep",
                      "security": "wep",
                      "password": "12345",
                      "priority": 1
                    }
                  ],
                  "signal": 100,
                  "ip": "111.70.146.125",
                  "netmask": "255.255.255.252",
                  "gateway": "111.70.146.126",
                  "dns": [
                    "168.95.1.1",
                    "168.95.192.1"
                  ],
                  "usage": {
                    "txkbyte": 40023,
                    "rxkbyte": 3493
                  },
                  "checkalive": {
                    "enable": true,
                    "targetHost": "8.8.8.8",
                    "intervalSec": 60
                  }
                },
                "ap": {
                  "mode": "bg",
                  "ssid": "moxa-test",
                  "channel": 11,
                  "security": {
                    "mode": "none"
                  }
                }
              }
            }
          }
        },
        "tags": [
          "wifi"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      }
    },
    "/network/wifi/{id}/blacklist": {
      "parameters": [
        {
          "name": "id",
          "in": "path",
          "type": "integer",
          "required": true
        }
      ],
      "post": {
        "description": "Add a MAC into blacklist of an indicated WiFi interface.\n",
        "parameters": [
          {
            "name": "body",
            "in": "body",
            "description": "",
            "required": true,
            "schema": {
              "$ref": "#/definitions/WiFiIfaceBlacklist"
            }
          }
        ],
        "responses": {
          "200": {
            "description": "OK",
            "schema": {
              "$ref": "#/definitions/WiFiIfaceBlacklist"
            },
            "examples": {
              "application/json": {
                "id": 1,
                "mac": "01:23:45:67:89:0a",
                "description": "test1"
              }
            }
          }
        },
        "tags": [
          "wifi"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      },
      "get": {
        "description": "Get blacklist of an indicated WiFi AP interface.\n",
        "responses": {
          "200": {
            "description": "A blacklist of an indicated WiFi AP interface.",
            "schema": {
              "type": "array",
              "items": {
                "$ref": "#/definitions/WiFiIfaceBlacklist"
              }
            },
            "examples": {
              "application/json": [
                {
                  "id": 1,
                  "mac": "01:23:45:67:89:0a",
                  "description": "test1"
                }
              ]
            }
          }
        },
        "tags": [
          "wifi"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      },
      "put": {
        "summary": "WiFi Blacklist for AP",
        "description": "Update blacklist of an indicated WiFi AP interface.",
        "parameters": [
          {
            "name": "body",
            "in": "body",
            "description": "",
            "required": true,
            "schema": {
              "type": "array",
              "items": {
                "$ref": "#/definitions/WiFiIfaceBlacklist"
              }
            }
          }
        ],
        "responses": {
          "200": {
            "description": "OK",
            "schema": {
              "type": "array",
              "items": {
                "$ref": "#/definitions/WiFiIfaceBlacklist"
              }
            },
            "examples": {
              "application/json": [
                {
                  "id": 1,
                  "mac": "01:23:45:67:89:0a",
                  "description": "test1"
                }
              ]
            }
          }
        },
        "tags": [
          "wifi"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      },
      "delete": {
        "parameters": [
          {
            "name": "body",
            "in": "body",
            "required": true,
            "schema": {
              "type": "array",
              "items": {
                "description": "MAC ID of a blacklist",
                "type": "integer"
              }
            }
          }
        ],
        "description": "Delete multiple MACs",
        "responses": {
          "200": {
            "description": "success"
          }
        },
        "tags": [
          "wifi"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      }
    },
    "/network/wifi/{id}/blacklist/{mac_id}": {
      "parameters": [
        {
          "name": "id",
          "in": "path",
          "description": "A WiFi interface ID",
          "type": "integer",
          "required": true
        },
        {
          "name": "mac_id",
          "in": "path",
          "description": "A MAC ID in a blacklist of the WiFi AP interface",
          "type": "integer",
          "required": true
        }
      ],
      "get": {
        "description": "Get a MAC item from blacklist of an indicated WiFi AP interface.\n",
        "responses": {
          "200": {
            "description": "A MAC item in a blacklist of an indicated WiFi AP interface.\n",
            "schema": {
              "$ref": "#/definitions/WiFiIfaceBlacklist"
            },
            "examples": {
              "application/json": {
                "id": 1,
                "mac": "01:23:45:67:89:0a",
                "description": "test1"
              }
            }
          }
        },
        "tags": [
          "wifi"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      },
      "put": {
        "summary": "WiFi Blacklist item for AP",
        "description": "Update a MAC item in blacklist of an indicated WiFi AP interface.\n",
        "parameters": [
          {
            "name": "body",
            "in": "body",
            "description": "",
            "required": true,
            "schema": {
              "$ref": "#/definitions/WiFiIfaceBlacklist"
            }
          }
        ],
        "responses": {
          "200": {
            "description": "OK",
            "schema": {
              "$ref": "#/definitions/WiFiIfaceBlacklist"
            },
            "examples": {
              "application/json": {
                "id": 1,
                "mac": "01:23:45:67:89:0a",
                "description": "test1"
              }
            }
          }
        },
        "tags": [
          "wifi"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      },
      "delete": {
        "parameters": [
          {
            "name": "body",
            "in": "body",
            "required": true,
            "schema": {
              "description": "MAC ID of a blacklist",
              "type": "integer"
            }
          }
        ],
        "description": "Delete a MACs",
        "responses": {
          "200": {
            "description": "success"
          }
        },
        "tags": [
          "wifi"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      }
    },
    "/network/wifi/{id}/scan-networks": {
      "parameters": [
        {
          "name": "id",
          "in": "path",
          "description": "A WiFi interface ID",
          "type": "integer",
          "required": true
        }
      ],
      "get": {
        "description": "Get a list of WiFi stations arounded.\n",
        "responses": {
          "200": {
            "description": "A list of WiFi stations.\n",
            "schema": {
              "type": "array",
              "items": {
                "$ref": "#/definitions/WiFiAP"
              }
            },
            "examples": {
              "application/json": [
                {
                  "ssid": "test",
                  "bssid": "01:23:45:67:89:0a",
                  "signal": -43,
                  "frequency": 2462,
                  "security": "wpa2"
                }
              ]
            }
          }
        },
        "tags": [
          "wifi"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      }
    },
    "/mxc/modbus/equipment-templates": {
      "get": {
        "description": "Get all equipment templates",
        "responses": {
          "200": {
            "description": "success",
            "schema": {
              "type": "array",
              "items": {
                "$ref": "#/definitions/EquipmentTemplate"
              }
            },
            "examples": {
              "application/json": [
                {
                  "id": 1,
                  "name": "ioLogik-E1210",
                  "tagList": [
                    {
                      "name": "di0",
                      "function": "read-discrete-inputs",
                      "address": 0,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di1",
                      "function": "read-discrete-inputs",
                      "address": 1,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di2",
                      "function": "read-discrete-inputs",
                      "address": 2,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di3",
                      "function": "read-discrete-inputs",
                      "address": 3,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di4",
                      "function": "read-discrete-inputs",
                      "address": 4,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di5",
                      "function": "read-discrete-inputs",
                      "address": 5,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di6",
                      "function": "read-discrete-inputs",
                      "address": 6,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di7",
                      "function": "read-discrete-inputs",
                      "address": 7,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di8",
                      "function": "read-discrete-inputs",
                      "address": 8,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di9",
                      "function": "read-discrete-inputs",
                      "address": 9,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di10",
                      "function": "read-discrete-inputs",
                      "address": 10,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di11",
                      "function": "read-discrete-inputs",
                      "address": 11,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di12",
                      "function": "read-discrete-inputs",
                      "address": 12,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di13",
                      "function": "read-discrete-inputs",
                      "address": 13,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di14",
                      "function": "read-discrete-inputs",
                      "address": 14,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di15",
                      "function": "read-discrete-inputs",
                      "address": 15,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    }
                  ]
                },
                {
                  "id": 2,
                  "name": "ioLogik-E1211",
                  "tagList": [
                    {
                      "name": "do0",
                      "function": "read-coils",
                      "address": 0,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do1",
                      "function": "read-coils",
                      "address": 1,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do2",
                      "function": "read-coils",
                      "address": 2,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do3",
                      "function": "read-coils",
                      "address": 3,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do4",
                      "function": "read-coils",
                      "address": 4,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do5",
                      "function": "read-coils",
                      "address": 5,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do6",
                      "function": "read-coils",
                      "address": 6,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do7",
                      "function": "read-coils",
                      "address": 7,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do8",
                      "function": "read-coils",
                      "address": 8,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do9",
                      "function": "read-coils",
                      "address": 9,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do10",
                      "function": "read-coils",
                      "address": 10,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do11",
                      "function": "read-coils",
                      "address": 11,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do12",
                      "function": "read-coils",
                      "address": 12,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do13",
                      "function": "read-coils",
                      "address": 13,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do14",
                      "function": "read-coils",
                      "address": 14,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do15",
                      "function": "read-coils",
                      "address": 15,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    }
                  ]
                },
                {
                  "id": 3,
                  "name": "ioLogik-E1212",
                  "tagList": [
                    {
                      "name": "di0",
                      "function": "read-discrete-inputs",
                      "address": 0,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di1",
                      "function": "read-discrete-inputs",
                      "address": 1,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di2",
                      "function": "read-discrete-inputs",
                      "address": 2,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di3",
                      "function": "read-discrete-inputs",
                      "address": 3,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di4",
                      "function": "read-discrete-inputs",
                      "address": 4,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di5",
                      "function": "read-discrete-inputs",
                      "address": 5,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di6",
                      "function": "read-discrete-inputs",
                      "address": 6,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di7",
                      "function": "read-discrete-inputs",
                      "address": 7,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di8",
                      "function": "read-discrete-inputs",
                      "address": 8,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di9",
                      "function": "read-discrete-inputs",
                      "address": 9,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di10",
                      "function": "read-discrete-inputs",
                      "address": 10,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di11",
                      "function": "read-discrete-inputs",
                      "address": 11,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di12",
                      "function": "read-discrete-inputs",
                      "address": 12,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di13",
                      "function": "read-discrete-inputs",
                      "address": 13,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di14",
                      "function": "read-discrete-inputs",
                      "address": 14,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di15",
                      "function": "read-discrete-inputs",
                      "address": 15,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do0",
                      "function": "read-coils",
                      "address": 0,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do1",
                      "function": "read-coils",
                      "address": 1,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do2",
                      "function": "read-coils",
                      "address": 2,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do3",
                      "function": "read-coils",
                      "address": 3,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do4",
                      "function": "read-coils",
                      "address": 4,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do5",
                      "function": "read-coils",
                      "address": 5,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do6",
                      "function": "read-coils",
                      "address": 6,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do7",
                      "function": "read-coils",
                      "address": 7,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    }
                  ]
                },
                {
                  "id": 4,
                  "name": "ioLogik-E1213",
                  "tagList": [
                    {
                      "name": "di0",
                      "function": "read-discrete-inputs",
                      "address": 0,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di1",
                      "function": "read-discrete-inputs",
                      "address": 1,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di2",
                      "function": "read-discrete-inputs",
                      "address": 2,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di3",
                      "function": "read-discrete-inputs",
                      "address": 3,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di4",
                      "function": "read-discrete-inputs",
                      "address": 4,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di5",
                      "function": "read-discrete-inputs",
                      "address": 5,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di6",
                      "function": "read-discrete-inputs",
                      "address": 6,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di7",
                      "function": "read-discrete-inputs",
                      "address": 7,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di8",
                      "function": "read-discrete-inputs",
                      "address": 8,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di9",
                      "function": "read-discrete-inputs",
                      "address": 9,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di10",
                      "function": "read-discrete-inputs",
                      "address": 10,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di11",
                      "function": "read-discrete-inputs",
                      "address": 11,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do0",
                      "function": "read-coils",
                      "address": 0,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do1",
                      "function": "read-coils",
                      "address": 1,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do2",
                      "function": "read-coils",
                      "address": 2,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do3",
                      "function": "read-coils",
                      "address": 3,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do4",
                      "function": "read-coils",
                      "address": 4,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do5",
                      "function": "read-coils",
                      "address": 5,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do6",
                      "function": "read-coils",
                      "address": 6,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do7",
                      "function": "read-coils",
                      "address": 7,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    }
                  ]
                },
                {
                  "id": 5,
                  "name": "ioLogik-E1214",
                  "tagList": [
                    {
                      "name": "di0",
                      "function": "read-discrete-inputs",
                      "address": 0,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di1",
                      "function": "read-discrete-inputs",
                      "address": 1,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di2",
                      "function": "read-discrete-inputs",
                      "address": 2,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di3",
                      "function": "read-discrete-inputs",
                      "address": 3,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di4",
                      "function": "read-discrete-inputs",
                      "address": 4,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di5",
                      "function": "read-discrete-inputs",
                      "address": 5,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "ro0",
                      "function": "read-coils",
                      "address": 0,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "ro1",
                      "function": "read-coils",
                      "address": 1,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "ro2",
                      "function": "read-coils",
                      "address": 2,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "ro3",
                      "function": "read-coils",
                      "address": 3,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "ro4",
                      "function": "read-coils",
                      "address": 4,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "ro5",
                      "function": "read-coils",
                      "address": 5,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    }
                  ]
                },
                {
                  "id": 6,
                  "name": "ioLogik-E1240",
                  "tagList": [
                    {
                      "name": "ai0",
                      "function": "read-input-registers",
                      "address": 0,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai1",
                      "function": "read-input-registers",
                      "address": 1,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai2",
                      "function": "read-input-registers",
                      "address": 2,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai3",
                      "function": "read-input-registers",
                      "address": 3,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai4",
                      "function": "read-input-registers",
                      "address": 4,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai5",
                      "function": "read-input-registers",
                      "address": 5,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai6",
                      "function": "read-input-registers",
                      "address": 6,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai7",
                      "function": "read-input-registers",
                      "address": 7,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    }
                  ]
                },
                {
                  "id": 7,
                  "name": "ioLogik-E1241",
                  "tagList": [
                    {
                      "name": "ao0",
                      "function": "read-holding-registers",
                      "address": 1024,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ao1",
                      "function": "read-holding-registers",
                      "address": 1025,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ao2",
                      "function": "read-holding-registers",
                      "address": 1026,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ao3",
                      "function": "read-holding-registers",
                      "address": 1027,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    }
                  ]
                },
                {
                  "id": 8,
                  "name": "ioLogik-E1242",
                  "tagList": [
                    {
                      "name": "di0",
                      "function": "read-discrete-inputs",
                      "address": 0,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di1",
                      "function": "read-discrete-inputs",
                      "address": 1,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di2",
                      "function": "read-discrete-inputs",
                      "address": 2,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di3",
                      "function": "read-discrete-inputs",
                      "address": 3,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di4",
                      "function": "read-discrete-inputs",
                      "address": 4,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di5",
                      "function": "read-discrete-inputs",
                      "address": 5,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di6",
                      "function": "read-discrete-inputs",
                      "address": 6,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di7",
                      "function": "read-discrete-inputs",
                      "address": 7,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do0",
                      "function": "read-coils",
                      "address": 0,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do1",
                      "function": "read-coils",
                      "address": 1,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do2",
                      "function": "read-coils",
                      "address": 2,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do3",
                      "function": "read-coils",
                      "address": 3,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "ai0",
                      "function": "read-input-registers",
                      "address": 512,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai1",
                      "function": "read-input-registers",
                      "address": 513,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai2",
                      "function": "read-input-registers",
                      "address": 514,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai3",
                      "function": "read-input-registers",
                      "address": 515,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    }
                  ]
                },
                {
                  "id": 9,
                  "name": "ioLogik-E1260",
                  "tagList": [
                    {
                      "name": "rtdi0",
                      "function": "read-input-registers",
                      "address": 1536,
                      "quantity": 1,
                      "dataType": "uint16",
                      "enableAutoScaling": 1,
                      "autoScalingMode": "intercept",
                      "autoScaling": {
                        "slope": 0.1,
                        "offset": 0
                      },
                      "description": ""
                    },
                    {
                      "name": "rtdi1",
                      "function": "read-input-registers",
                      "address": 1537,
                      "quantity": 1,
                      "dataType": "uint16",
                      "enableAutoScaling": 1,
                      "autoScalingMode": "intercept",
                      "autoScaling": {
                        "slope": 0.1,
                        "offset": 0
                      },
                      "description": ""
                    },
                    {
                      "name": "rtdi2",
                      "function": "read-input-registers",
                      "address": 1538,
                      "quantity": 1,
                      "dataType": "uint16",
                      "enableAutoScaling": 1,
                      "autoScalingMode": "intercept",
                      "autoScaling": {
                        "slope": 0.1,
                        "offset": 0
                      },
                      "description": ""
                    },
                    {
                      "name": "rtdi3",
                      "function": "read-input-registers",
                      "address": 1539,
                      "quantity": 1,
                      "dataType": "uint16",
                      "enableAutoScaling": 1,
                      "autoScalingMode": "intercept",
                      "autoScaling": {
                        "slope": 0.1,
                        "offset": 0
                      },
                      "description": ""
                    },
                    {
                      "name": "rtdi4",
                      "function": "read-input-registers",
                      "address": 1540,
                      "quantity": 1,
                      "dataType": "uint16",
                      "enableAutoScaling": 1,
                      "autoScalingMode": "intercept",
                      "autoScaling": {
                        "slope": 0.1,
                        "offset": 0
                      },
                      "description": ""
                    },
                    {
                      "name": "rtdi5",
                      "function": "read-input-registers",
                      "address": 1541,
                      "quantity": 1,
                      "dataType": "uint16",
                      "enableAutoScaling": 1,
                      "autoScalingMode": "intercept",
                      "autoScaling": {
                        "slope": 0.1,
                        "offset": 0
                      },
                      "description": ""
                    }
                  ]
                },
                {
                  "id": 10,
                  "name": "ioLogik-E1261H-T",
                  "tagList": [
                    {
                      "name": "do0",
                      "function": "read-coils",
                      "address": 0,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do1",
                      "function": "read-coils",
                      "address": 1,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do2",
                      "function": "read-coils",
                      "address": 2,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do3",
                      "function": "read-coils",
                      "address": 3,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do4",
                      "function": "read-coils",
                      "address": 4,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do5",
                      "function": "read-coils",
                      "address": 5,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do6",
                      "function": "read-coils",
                      "address": 6,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do7",
                      "function": "read-coils",
                      "address": 7,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do8",
                      "function": "read-coils",
                      "address": 8,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do9",
                      "function": "read-coils",
                      "address": 9,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do10",
                      "function": "read-coils",
                      "address": 10,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do11",
                      "function": "read-coils",
                      "address": 11,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di0",
                      "function": "read-discrete-inputs",
                      "address": 0,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di1",
                      "function": "read-discrete-inputs",
                      "address": 1,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di2",
                      "function": "read-discrete-inputs",
                      "address": 2,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di3",
                      "function": "read-discrete-inputs",
                      "address": 3,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di4",
                      "function": "read-discrete-inputs",
                      "address": 4,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di5",
                      "function": "read-discrete-inputs",
                      "address": 5,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di6",
                      "function": "read-discrete-inputs",
                      "address": 6,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di7",
                      "function": "read-discrete-inputs",
                      "address": 7,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di8",
                      "function": "read-discrete-inputs",
                      "address": 8,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di9",
                      "function": "read-discrete-inputs",
                      "address": 9,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di10",
                      "function": "read-discrete-inputs",
                      "address": 10,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di11",
                      "function": "read-discrete-inputs",
                      "address": 11,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "ai0",
                      "function": "read-input-registers",
                      "address": 512,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai1",
                      "function": "read-input-registers",
                      "address": 513,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai2",
                      "function": "read-input-registers",
                      "address": 514,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai3",
                      "function": "read-input-registers",
                      "address": 515,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai4",
                      "function": "read-input-registers",
                      "address": 516,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "rtdi0",
                      "function": "read-input-registers",
                      "address": 1536,
                      "quantity": 1,
                      "dataType": "uint16",
                      "enableAutoScaling": 1,
                      "autoScalingMode": "intercept",
                      "autoScaling": {
                        "slope": 0.1,
                        "offset": 0
                      },
                      "description": ""
                    },
                    {
                      "name": "rtdi1",
                      "function": "read-input-registers",
                      "address": 1537,
                      "quantity": 1,
                      "dataType": "uint16",
                      "enableAutoScaling": 1,
                      "autoScalingMode": "intercept",
                      "autoScaling": {
                        "slope": 0.1,
                        "offset": 0
                      },
                      "description": ""
                    },
                    {
                      "name": "rtdi2",
                      "function": "read-input-registers",
                      "address": 1538,
                      "quantity": 1,
                      "dataType": "uint16",
                      "enableAutoScaling": 1,
                      "autoScalingMode": "intercept",
                      "autoScaling": {
                        "slope": 0.1,
                        "offset": 0
                      },
                      "description": ""
                    }
                  ]
                },
                {
                  "id": 11,
                  "name": "ioLogik-E1261W-T",
                  "tagList": [
                    {
                      "name": "do0",
                      "function": "read-coils",
                      "address": 0,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do1",
                      "function": "read-coils",
                      "address": 1,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do2",
                      "function": "read-coils",
                      "address": 2,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do3",
                      "function": "read-coils",
                      "address": 3,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do4",
                      "function": "read-coils",
                      "address": 4,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do5",
                      "function": "read-coils",
                      "address": 5,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do6",
                      "function": "read-coils",
                      "address": 6,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do7",
                      "function": "read-coils",
                      "address": 7,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do8",
                      "function": "read-coils",
                      "address": 8,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do9",
                      "function": "read-coils",
                      "address": 9,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do10",
                      "function": "read-coils",
                      "address": 10,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do11",
                      "function": "read-coils",
                      "address": 11,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di0",
                      "function": "read-discrete-inputs",
                      "address": 0,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di1",
                      "function": "read-discrete-inputs",
                      "address": 1,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di2",
                      "function": "read-discrete-inputs",
                      "address": 2,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di3",
                      "function": "read-discrete-inputs",
                      "address": 3,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di4",
                      "function": "read-discrete-inputs",
                      "address": 4,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di5",
                      "function": "read-discrete-inputs",
                      "address": 5,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di6",
                      "function": "read-discrete-inputs",
                      "address": 6,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di7",
                      "function": "read-discrete-inputs",
                      "address": 7,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di8",
                      "function": "read-discrete-inputs",
                      "address": 8,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di9",
                      "function": "read-discrete-inputs",
                      "address": 9,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di10",
                      "function": "read-discrete-inputs",
                      "address": 10,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di11",
                      "function": "read-discrete-inputs",
                      "address": 11,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "ai0",
                      "function": "read-input-registers",
                      "address": 512,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai1",
                      "function": "read-input-registers",
                      "address": 513,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai2",
                      "function": "read-input-registers",
                      "address": 514,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai3",
                      "function": "read-input-registers",
                      "address": 515,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai4",
                      "function": "read-input-registers",
                      "address": 516,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "rtdi0",
                      "function": "read-input-registers",
                      "address": 1536,
                      "quantity": 1,
                      "dataType": "uint16",
                      "enableAutoScaling": 1,
                      "autoScalingMode": "intercept",
                      "autoScaling": {
                        "slope": 0.1,
                        "offset": 0
                      },
                      "description": ""
                    },
                    {
                      "name": "rtdi1",
                      "function": "read-input-registers",
                      "address": 1537,
                      "quantity": 1,
                      "dataType": "uint16",
                      "enableAutoScaling": 1,
                      "autoScalingMode": "intercept",
                      "autoScaling": {
                        "slope": 0.1,
                        "offset": 0
                      },
                      "description": ""
                    },
                    {
                      "name": "rtdi2",
                      "function": "read-input-registers",
                      "address": 1538,
                      "quantity": 1,
                      "dataType": "uint16",
                      "enableAutoScaling": 1,
                      "autoScalingMode": "intercept",
                      "autoScaling": {
                        "slope": 0.1,
                        "offset": 0
                      },
                      "description": ""
                    }
                  ]
                },
                {
                  "id": 12,
                  "name": "ioLogik-E1262",
                  "tagList": [
                    {
                      "name": "tci0",
                      "function": "read-input-registers",
                      "address": 2048,
                      "quantity": 2,
                      "dataType": "uint32",
                      "enableAutoScaling": 1,
                      "autoScalingMode": "intercept",
                      "autoScaling": {
                        "slope": 0.1,
                        "offset": 0
                      },
                      "description": ""
                    },
                    {
                      "name": "tci1",
                      "function": "read-input-registers",
                      "address": 2050,
                      "quantity": 2,
                      "dataType": "uint32",
                      "enableAutoScaling": 1,
                      "autoScalingMode": "intercept",
                      "autoScaling": {
                        "slope": 0.1,
                        "offset": 0
                      },
                      "description": ""
                    },
                    {
                      "name": "tci2",
                      "function": "read-input-registers",
                      "address": 2052,
                      "quantity": 2,
                      "dataType": "uint32",
                      "enableAutoScaling": 1,
                      "autoScalingMode": "intercept",
                      "autoScaling": {
                        "slope": 0.1,
                        "offset": 0
                      },
                      "description": ""
                    },
                    {
                      "name": "tci3",
                      "function": "read-input-registers",
                      "address": 2054,
                      "quantity": 2,
                      "dataType": "uint32",
                      "enableAutoScaling": 1,
                      "autoScalingMode": "intercept",
                      "autoScaling": {
                        "slope": 0.1,
                        "offset": 0
                      },
                      "description": ""
                    },
                    {
                      "name": "tci4",
                      "function": "read-input-registers",
                      "address": 2056,
                      "quantity": 2,
                      "dataType": "uint32",
                      "enableAutoScaling": 1,
                      "autoScalingMode": "intercept",
                      "autoScaling": {
                        "slope": 0.1,
                        "offset": 0
                      },
                      "description": ""
                    },
                    {
                      "name": "tci5",
                      "function": "read-input-registers",
                      "address": 2058,
                      "quantity": 2,
                      "dataType": "uint32",
                      "enableAutoScaling": 1,
                      "autoScalingMode": "intercept",
                      "autoScaling": {
                        "slope": 0.1,
                        "offset": 0
                      },
                      "description": ""
                    },
                    {
                      "name": "tci6",
                      "function": "read-input-registers",
                      "address": 2060,
                      "quantity": 2,
                      "dataType": "uint32",
                      "enableAutoScaling": 1,
                      "autoScalingMode": "intercept",
                      "autoScaling": {
                        "slope": 0.1,
                        "offset": 0
                      },
                      "description": ""
                    },
                    {
                      "name": "tci7",
                      "function": "read-input-registers",
                      "address": 2062,
                      "quantity": 2,
                      "dataType": "uint32",
                      "enableAutoScaling": 1,
                      "autoScalingMode": "intercept",
                      "autoScaling": {
                        "slope": 0.1,
                        "offset": 0
                      },
                      "description": ""
                    }
                  ]
                },
                {
                  "id": 13,
                  "name": "ioLogik-E1263H-T",
                  "tagList": [
                    {
                      "name": "do0",
                      "function": "read-coils",
                      "address": 0,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do1",
                      "function": "read-coils",
                      "address": 1,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do2",
                      "function": "read-coils",
                      "address": 2,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do3",
                      "function": "read-coils",
                      "address": 3,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do4",
                      "function": "read-coils",
                      "address": 4,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do5",
                      "function": "read-coils",
                      "address": 5,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do6",
                      "function": "read-coils",
                      "address": 6,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do7",
                      "function": "read-coils",
                      "address": 7,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do8",
                      "function": "read-coils",
                      "address": 8,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do9",
                      "function": "read-coils",
                      "address": 9,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do10",
                      "function": "read-coils",
                      "address": 10,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do11",
                      "function": "read-coils",
                      "address": 11,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do12",
                      "function": "read-coils",
                      "address": 12,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do13",
                      "function": "read-coils",
                      "address": 13,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do14",
                      "function": "read-coils",
                      "address": 14,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do15",
                      "function": "read-coils",
                      "address": 15,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do16",
                      "function": "read-coils",
                      "address": 16,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do17",
                      "function": "read-coils",
                      "address": 17,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do18",
                      "function": "read-coils",
                      "address": 18,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do19",
                      "function": "read-coils",
                      "address": 19,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do20",
                      "function": "read-coils",
                      "address": 20,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do21",
                      "function": "read-coils",
                      "address": 21,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do22",
                      "function": "read-coils",
                      "address": 22,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do23",
                      "function": "read-coils",
                      "address": 23,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di0",
                      "function": "read-discrete-inputs",
                      "address": 0,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di1",
                      "function": "read-discrete-inputs",
                      "address": 1,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di2",
                      "function": "read-discrete-inputs",
                      "address": 2,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di3",
                      "function": "read-discrete-inputs",
                      "address": 3,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di4",
                      "function": "read-discrete-inputs",
                      "address": 4,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di5",
                      "function": "read-discrete-inputs",
                      "address": 5,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di6",
                      "function": "read-discrete-inputs",
                      "address": 6,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di7",
                      "function": "read-discrete-inputs",
                      "address": 7,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di8",
                      "function": "read-discrete-inputs",
                      "address": 8,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di9",
                      "function": "read-discrete-inputs",
                      "address": 9,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di10",
                      "function": "read-discrete-inputs",
                      "address": 10,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di11",
                      "function": "read-discrete-inputs",
                      "address": 11,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di12",
                      "function": "read-discrete-inputs",
                      "address": 12,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di13",
                      "function": "read-discrete-inputs",
                      "address": 13,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di14",
                      "function": "read-discrete-inputs",
                      "address": 14,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di15",
                      "function": "read-discrete-inputs",
                      "address": 15,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di16",
                      "function": "read-discrete-inputs",
                      "address": 16,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di17",
                      "function": "read-discrete-inputs",
                      "address": 17,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di18",
                      "function": "read-discrete-inputs",
                      "address": 18,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di19",
                      "function": "read-discrete-inputs",
                      "address": 19,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di20",
                      "function": "read-discrete-inputs",
                      "address": 20,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di21",
                      "function": "read-discrete-inputs",
                      "address": 21,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di22",
                      "function": "read-discrete-inputs",
                      "address": 22,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di23",
                      "function": "read-discrete-inputs",
                      "address": 23,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "ai0",
                      "function": "read-input-registers",
                      "address": 512,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai1",
                      "function": "read-input-registers",
                      "address": 513,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai2",
                      "function": "read-input-registers",
                      "address": 514,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai3",
                      "function": "read-input-registers",
                      "address": 515,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai4",
                      "function": "read-input-registers",
                      "address": 516,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai5",
                      "function": "read-input-registers",
                      "address": 517,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai6",
                      "function": "read-input-registers",
                      "address": 518,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai7",
                      "function": "read-input-registers",
                      "address": 519,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai8",
                      "function": "read-input-registers",
                      "address": 520,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai9",
                      "function": "read-input-registers",
                      "address": 521,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "rtdi0",
                      "function": "read-input-registers",
                      "address": 1536,
                      "quantity": 1,
                      "dataType": "uint16",
                      "enableAutoScaling": 1,
                      "autoScalingMode": "intercept",
                      "autoScaling": {
                        "slope": 0.1,
                        "offset": 0
                      },
                      "description": ""
                    },
                    {
                      "name": "rtdi1",
                      "function": "read-input-registers",
                      "address": 1537,
                      "quantity": 1,
                      "dataType": "uint16",
                      "enableAutoScaling": 1,
                      "autoScalingMode": "intercept",
                      "autoScaling": {
                        "slope": 0.1,
                        "offset": 0
                      },
                      "description": ""
                    },
                    {
                      "name": "rtdi2",
                      "function": "read-input-registers",
                      "address": 1538,
                      "quantity": 1,
                      "dataType": "uint16",
                      "enableAutoScaling": 1,
                      "autoScalingMode": "intercept",
                      "autoScaling": {
                        "slope": 0.1,
                        "offset": 0
                      },
                      "description": ""
                    }
                  ]
                },
                {
                  "id": 14,
                  "name": "ioLogik-R1210",
                  "tagList": [
                    {
                      "name": "di0",
                      "function": "read-input-registers",
                      "address": 0,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di1",
                      "function": "read-input-registers",
                      "address": 1,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di2",
                      "function": "read-input-registers",
                      "address": 2,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di3",
                      "function": "read-input-registers",
                      "address": 3,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di4",
                      "function": "read-input-registers",
                      "address": 4,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di5",
                      "function": "read-input-registers",
                      "address": 5,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di6",
                      "function": "read-input-registers",
                      "address": 6,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di7",
                      "function": "read-input-registers",
                      "address": 7,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di8",
                      "function": "read-input-registers",
                      "address": 8,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di9",
                      "function": "read-input-registers",
                      "address": 9,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di10",
                      "function": "read-input-registers",
                      "address": 10,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di11",
                      "function": "read-input-registers",
                      "address": 11,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di12",
                      "function": "read-input-registers",
                      "address": 12,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di13",
                      "function": "read-input-registers",
                      "address": 13,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di14",
                      "function": "read-input-registers",
                      "address": 14,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di15",
                      "function": "read-input-registers",
                      "address": 15,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    }
                  ]
                },
                {
                  "id": 15,
                  "name": "ioLogik-R1212",
                  "tagList": [
                    {
                      "name": "di0",
                      "function": "read-input-registers",
                      "address": 0,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di1",
                      "function": "read-input-registers",
                      "address": 1,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di2",
                      "function": "read-input-registers",
                      "address": 2,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di3",
                      "function": "read-input-registers",
                      "address": 3,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di4",
                      "function": "read-input-registers",
                      "address": 4,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di5",
                      "function": "read-input-registers",
                      "address": 5,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di6",
                      "function": "read-input-registers",
                      "address": 6,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di7",
                      "function": "read-input-registers",
                      "address": 7,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di8",
                      "function": "read-input-registers",
                      "address": 8,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di9",
                      "function": "read-input-registers",
                      "address": 9,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di10",
                      "function": "read-input-registers",
                      "address": 10,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di11",
                      "function": "read-input-registers",
                      "address": 11,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di12",
                      "function": "read-input-registers",
                      "address": 12,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di13",
                      "function": "read-input-registers",
                      "address": 13,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di14",
                      "function": "read-input-registers",
                      "address": 14,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di15",
                      "function": "read-input-registers",
                      "address": 15,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do0",
                      "function": "read-holding-registers",
                      "address": 320,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do1",
                      "function": "read-holding-registers",
                      "address": 321,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do2",
                      "function": "read-holding-registers",
                      "address": 322,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do3",
                      "function": "read-holding-registers",
                      "address": 323,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do4",
                      "function": "read-holding-registers",
                      "address": 324,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do5",
                      "function": "read-holding-registers",
                      "address": 325,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do6",
                      "function": "read-holding-registers",
                      "address": 326,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do7",
                      "function": "read-holding-registers",
                      "address": 327,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    }
                  ]
                },
                {
                  "id": 16,
                  "name": "ioLogik-R1214",
                  "tagList": [
                    {
                      "name": "di0",
                      "function": "read-input-registers",
                      "address": 0,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di1",
                      "function": "read-input-registers",
                      "address": 1,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di2",
                      "function": "read-input-registers",
                      "address": 2,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di3",
                      "function": "read-input-registers",
                      "address": 3,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di4",
                      "function": "read-input-registers",
                      "address": 4,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di5",
                      "function": "read-input-registers",
                      "address": 5,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "ro0",
                      "function": "read-holding-registers",
                      "address": 320,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ro1",
                      "function": "read-holding-registers",
                      "address": 321,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ro2",
                      "function": "read-holding-registers",
                      "address": 322,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ro3",
                      "function": "read-holding-registers",
                      "address": 323,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ro4",
                      "function": "read-holding-registers",
                      "address": 324,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ro5",
                      "function": "read-holding-registers",
                      "address": 325,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    }
                  ]
                },
                {
                  "id": 17,
                  "name": "ioLogik-R1240",
                  "tagList": [
                    {
                      "name": "ai0",
                      "function": "read-input-registers",
                      "address": 704,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai1",
                      "function": "read-input-registers",
                      "address": 705,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai2",
                      "function": "read-input-registers",
                      "address": 706,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai3",
                      "function": "read-input-registers",
                      "address": 707,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai4",
                      "function": "read-input-registers",
                      "address": 708,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai5",
                      "function": "read-input-registers",
                      "address": 709,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai6",
                      "function": "read-input-registers",
                      "address": 710,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai7",
                      "function": "read-input-registers",
                      "address": 711,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    }
                  ]
                },
                {
                  "id": 18,
                  "name": "ioLogik-R1241",
                  "tagList": [
                    {
                      "name": "ao0",
                      "function": "read-holding-registers",
                      "address": 1184,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ao1",
                      "function": "read-holding-registers",
                      "address": 1185,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ao2",
                      "function": "read-holding-registers",
                      "address": 1186,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ao3",
                      "function": "read-holding-registers",
                      "address": 1187,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    }
                  ]
                }
              ]
            }
          }
        },
        "tags": [
          "modbus"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      },
      "post": {
        "parameters": [
          {
            "name": "body",
            "in": "body",
            "required": true,
            "schema": {
              "$ref": "#/definitions/EquipmentTemplate"
            }
          }
        ],
        "description": "Create a new equipment template",
        "responses": {
          "200": {
            "description": "success",
            "schema": {
              "$ref": "#/definitions/EquipmentTemplate"
            },
            "examples": {
              "application/json": {
                "id": 9,
                "name": "ioLogik-E1260",
                "tagList": [
                  {
                    "name": "rtdi0",
                    "function": "read-input-registers",
                    "address": 1536,
                    "quantity": 1,
                    "dataType": "uint16",
                    "enableAutoScaling": 1,
                    "autoScalingMode": "intercept",
                    "autoScaling": {
                      "slope": 0.1,
                      "offset": 0
                    },
                    "description": ""
                  },
                  {
                    "name": "rtdi1",
                    "function": "read-input-registers",
                    "address": 1537,
                    "quantity": 1,
                    "dataType": "uint16",
                    "enableAutoScaling": 1,
                    "autoScalingMode": "intercept",
                    "autoScaling": {
                      "slope": 0.1,
                      "offset": 0
                    },
                    "description": ""
                  },
                  {
                    "name": "rtdi2",
                    "function": "read-input-registers",
                    "address": 1538,
                    "quantity": 1,
                    "dataType": "uint16",
                    "enableAutoScaling": 1,
                    "autoScalingMode": "intercept",
                    "autoScaling": {
                      "slope": 0.1,
                      "offset": 0
                    },
                    "description": ""
                  },
                  {
                    "name": "rtdi3",
                    "function": "read-input-registers",
                    "address": 1539,
                    "quantity": 1,
                    "dataType": "uint16",
                    "enableAutoScaling": 1,
                    "autoScalingMode": "intercept",
                    "autoScaling": {
                      "slope": 0.1,
                      "offset": 0
                    },
                    "description": ""
                  },
                  {
                    "name": "rtdi4",
                    "function": "read-input-registers",
                    "address": 1540,
                    "quantity": 1,
                    "dataType": "uint16",
                    "enableAutoScaling": 1,
                    "autoScalingMode": "intercept",
                    "autoScaling": {
                      "slope": 0.1,
                      "offset": 0
                    },
                    "description": ""
                  },
                  {
                    "name": "rtdi5",
                    "function": "read-input-registers",
                    "address": 1541,
                    "quantity": 1,
                    "dataType": "uint16",
                    "enableAutoScaling": 1,
                    "autoScalingMode": "intercept",
                    "autoScaling": {
                      "slope": 0.1,
                      "offset": 0
                    },
                    "description": ""
                  }
                ]
              }
            }
          }
        },
        "tags": [
          "modbus"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      },
      "delete": {
        "description": "Delete multiple equipment templates",
        "responses": {
          "200": {
            "description": "success",
            "schema": {
              "type": "array",
              "items": {
                "description": "Target equipment template IDs",
                "type": "integer"
              }
            },
            "examples": {
              "application/json": [
                {
                  "id": 1,
                  "name": "ioLogik-E1210",
                  "tagList": [
                    {
                      "name": "di0",
                      "function": "read-discrete-inputs",
                      "address": 0,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di1",
                      "function": "read-discrete-inputs",
                      "address": 1,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di2",
                      "function": "read-discrete-inputs",
                      "address": 2,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di3",
                      "function": "read-discrete-inputs",
                      "address": 3,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di4",
                      "function": "read-discrete-inputs",
                      "address": 4,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di5",
                      "function": "read-discrete-inputs",
                      "address": 5,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di6",
                      "function": "read-discrete-inputs",
                      "address": 6,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di7",
                      "function": "read-discrete-inputs",
                      "address": 7,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di8",
                      "function": "read-discrete-inputs",
                      "address": 8,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di9",
                      "function": "read-discrete-inputs",
                      "address": 9,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di10",
                      "function": "read-discrete-inputs",
                      "address": 10,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di11",
                      "function": "read-discrete-inputs",
                      "address": 11,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di12",
                      "function": "read-discrete-inputs",
                      "address": 12,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di13",
                      "function": "read-discrete-inputs",
                      "address": 13,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di14",
                      "function": "read-discrete-inputs",
                      "address": 14,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di15",
                      "function": "read-discrete-inputs",
                      "address": 15,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    }
                  ]
                },
                {
                  "id": 2,
                  "name": "ioLogik-E1211",
                  "tagList": [
                    {
                      "name": "do0",
                      "function": "read-coils",
                      "address": 0,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do1",
                      "function": "read-coils",
                      "address": 1,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do2",
                      "function": "read-coils",
                      "address": 2,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do3",
                      "function": "read-coils",
                      "address": 3,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do4",
                      "function": "read-coils",
                      "address": 4,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do5",
                      "function": "read-coils",
                      "address": 5,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do6",
                      "function": "read-coils",
                      "address": 6,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do7",
                      "function": "read-coils",
                      "address": 7,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do8",
                      "function": "read-coils",
                      "address": 8,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do9",
                      "function": "read-coils",
                      "address": 9,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do10",
                      "function": "read-coils",
                      "address": 10,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do11",
                      "function": "read-coils",
                      "address": 11,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do12",
                      "function": "read-coils",
                      "address": 12,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do13",
                      "function": "read-coils",
                      "address": 13,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do14",
                      "function": "read-coils",
                      "address": 14,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do15",
                      "function": "read-coils",
                      "address": 15,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    }
                  ]
                },
                {
                  "id": 3,
                  "name": "ioLogik-E1212",
                  "tagList": [
                    {
                      "name": "di0",
                      "function": "read-discrete-inputs",
                      "address": 0,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di1",
                      "function": "read-discrete-inputs",
                      "address": 1,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di2",
                      "function": "read-discrete-inputs",
                      "address": 2,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di3",
                      "function": "read-discrete-inputs",
                      "address": 3,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di4",
                      "function": "read-discrete-inputs",
                      "address": 4,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di5",
                      "function": "read-discrete-inputs",
                      "address": 5,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di6",
                      "function": "read-discrete-inputs",
                      "address": 6,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di7",
                      "function": "read-discrete-inputs",
                      "address": 7,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di8",
                      "function": "read-discrete-inputs",
                      "address": 8,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di9",
                      "function": "read-discrete-inputs",
                      "address": 9,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di10",
                      "function": "read-discrete-inputs",
                      "address": 10,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di11",
                      "function": "read-discrete-inputs",
                      "address": 11,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di12",
                      "function": "read-discrete-inputs",
                      "address": 12,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di13",
                      "function": "read-discrete-inputs",
                      "address": 13,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di14",
                      "function": "read-discrete-inputs",
                      "address": 14,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di15",
                      "function": "read-discrete-inputs",
                      "address": 15,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do0",
                      "function": "read-coils",
                      "address": 0,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do1",
                      "function": "read-coils",
                      "address": 1,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do2",
                      "function": "read-coils",
                      "address": 2,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do3",
                      "function": "read-coils",
                      "address": 3,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do4",
                      "function": "read-coils",
                      "address": 4,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do5",
                      "function": "read-coils",
                      "address": 5,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do6",
                      "function": "read-coils",
                      "address": 6,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do7",
                      "function": "read-coils",
                      "address": 7,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    }
                  ]
                },
                {
                  "id": 4,
                  "name": "ioLogik-E1213",
                  "tagList": [
                    {
                      "name": "di0",
                      "function": "read-discrete-inputs",
                      "address": 0,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di1",
                      "function": "read-discrete-inputs",
                      "address": 1,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di2",
                      "function": "read-discrete-inputs",
                      "address": 2,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di3",
                      "function": "read-discrete-inputs",
                      "address": 3,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di4",
                      "function": "read-discrete-inputs",
                      "address": 4,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di5",
                      "function": "read-discrete-inputs",
                      "address": 5,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di6",
                      "function": "read-discrete-inputs",
                      "address": 6,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di7",
                      "function": "read-discrete-inputs",
                      "address": 7,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di8",
                      "function": "read-discrete-inputs",
                      "address": 8,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di9",
                      "function": "read-discrete-inputs",
                      "address": 9,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di10",
                      "function": "read-discrete-inputs",
                      "address": 10,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di11",
                      "function": "read-discrete-inputs",
                      "address": 11,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do0",
                      "function": "read-coils",
                      "address": 0,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do1",
                      "function": "read-coils",
                      "address": 1,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do2",
                      "function": "read-coils",
                      "address": 2,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do3",
                      "function": "read-coils",
                      "address": 3,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do4",
                      "function": "read-coils",
                      "address": 4,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do5",
                      "function": "read-coils",
                      "address": 5,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do6",
                      "function": "read-coils",
                      "address": 6,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do7",
                      "function": "read-coils",
                      "address": 7,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    }
                  ]
                },
                {
                  "id": 5,
                  "name": "ioLogik-E1214",
                  "tagList": [
                    {
                      "name": "di0",
                      "function": "read-discrete-inputs",
                      "address": 0,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di1",
                      "function": "read-discrete-inputs",
                      "address": 1,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di2",
                      "function": "read-discrete-inputs",
                      "address": 2,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di3",
                      "function": "read-discrete-inputs",
                      "address": 3,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di4",
                      "function": "read-discrete-inputs",
                      "address": 4,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di5",
                      "function": "read-discrete-inputs",
                      "address": 5,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "ro0",
                      "function": "read-coils",
                      "address": 0,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "ro1",
                      "function": "read-coils",
                      "address": 1,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "ro2",
                      "function": "read-coils",
                      "address": 2,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "ro3",
                      "function": "read-coils",
                      "address": 3,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "ro4",
                      "function": "read-coils",
                      "address": 4,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "ro5",
                      "function": "read-coils",
                      "address": 5,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    }
                  ]
                },
                {
                  "id": 6,
                  "name": "ioLogik-E1240",
                  "tagList": [
                    {
                      "name": "ai0",
                      "function": "read-input-registers",
                      "address": 0,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai1",
                      "function": "read-input-registers",
                      "address": 1,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai2",
                      "function": "read-input-registers",
                      "address": 2,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai3",
                      "function": "read-input-registers",
                      "address": 3,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai4",
                      "function": "read-input-registers",
                      "address": 4,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai5",
                      "function": "read-input-registers",
                      "address": 5,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai6",
                      "function": "read-input-registers",
                      "address": 6,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai7",
                      "function": "read-input-registers",
                      "address": 7,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    }
                  ]
                },
                {
                  "id": 7,
                  "name": "ioLogik-E1241",
                  "tagList": [
                    {
                      "name": "ao0",
                      "function": "read-holding-registers",
                      "address": 1024,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ao1",
                      "function": "read-holding-registers",
                      "address": 1025,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ao2",
                      "function": "read-holding-registers",
                      "address": 1026,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ao3",
                      "function": "read-holding-registers",
                      "address": 1027,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    }
                  ]
                },
                {
                  "id": 8,
                  "name": "ioLogik-E1242",
                  "tagList": [
                    {
                      "name": "di0",
                      "function": "read-discrete-inputs",
                      "address": 0,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di1",
                      "function": "read-discrete-inputs",
                      "address": 1,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di2",
                      "function": "read-discrete-inputs",
                      "address": 2,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di3",
                      "function": "read-discrete-inputs",
                      "address": 3,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di4",
                      "function": "read-discrete-inputs",
                      "address": 4,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di5",
                      "function": "read-discrete-inputs",
                      "address": 5,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di6",
                      "function": "read-discrete-inputs",
                      "address": 6,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di7",
                      "function": "read-discrete-inputs",
                      "address": 7,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do0",
                      "function": "read-coils",
                      "address": 0,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do1",
                      "function": "read-coils",
                      "address": 1,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do2",
                      "function": "read-coils",
                      "address": 2,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do3",
                      "function": "read-coils",
                      "address": 3,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "ai0",
                      "function": "read-input-registers",
                      "address": 512,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai1",
                      "function": "read-input-registers",
                      "address": 513,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai2",
                      "function": "read-input-registers",
                      "address": 514,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai3",
                      "function": "read-input-registers",
                      "address": 515,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    }
                  ]
                },
                {
                  "id": 9,
                  "name": "ioLogik-E1260",
                  "tagList": [
                    {
                      "name": "rtdi0",
                      "function": "read-input-registers",
                      "address": 1536,
                      "quantity": 1,
                      "dataType": "uint16",
                      "enableAutoScaling": 1,
                      "autoScalingMode": "intercept",
                      "autoScaling": {
                        "slope": 0.1,
                        "offset": 0
                      },
                      "description": ""
                    },
                    {
                      "name": "rtdi1",
                      "function": "read-input-registers",
                      "address": 1537,
                      "quantity": 1,
                      "dataType": "uint16",
                      "enableAutoScaling": 1,
                      "autoScalingMode": "intercept",
                      "autoScaling": {
                        "slope": 0.1,
                        "offset": 0
                      },
                      "description": ""
                    },
                    {
                      "name": "rtdi2",
                      "function": "read-input-registers",
                      "address": 1538,
                      "quantity": 1,
                      "dataType": "uint16",
                      "enableAutoScaling": 1,
                      "autoScalingMode": "intercept",
                      "autoScaling": {
                        "slope": 0.1,
                        "offset": 0
                      },
                      "description": ""
                    },
                    {
                      "name": "rtdi3",
                      "function": "read-input-registers",
                      "address": 1539,
                      "quantity": 1,
                      "dataType": "uint16",
                      "enableAutoScaling": 1,
                      "autoScalingMode": "intercept",
                      "autoScaling": {
                        "slope": 0.1,
                        "offset": 0
                      },
                      "description": ""
                    },
                    {
                      "name": "rtdi4",
                      "function": "read-input-registers",
                      "address": 1540,
                      "quantity": 1,
                      "dataType": "uint16",
                      "enableAutoScaling": 1,
                      "autoScalingMode": "intercept",
                      "autoScaling": {
                        "slope": 0.1,
                        "offset": 0
                      },
                      "description": ""
                    },
                    {
                      "name": "rtdi5",
                      "function": "read-input-registers",
                      "address": 1541,
                      "quantity": 1,
                      "dataType": "uint16",
                      "enableAutoScaling": 1,
                      "autoScalingMode": "intercept",
                      "autoScaling": {
                        "slope": 0.1,
                        "offset": 0
                      },
                      "description": ""
                    }
                  ]
                },
                {
                  "id": 10,
                  "name": "ioLogik-E1261H-T",
                  "tagList": [
                    {
                      "name": "do0",
                      "function": "read-coils",
                      "address": 0,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do1",
                      "function": "read-coils",
                      "address": 1,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do2",
                      "function": "read-coils",
                      "address": 2,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do3",
                      "function": "read-coils",
                      "address": 3,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do4",
                      "function": "read-coils",
                      "address": 4,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do5",
                      "function": "read-coils",
                      "address": 5,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do6",
                      "function": "read-coils",
                      "address": 6,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do7",
                      "function": "read-coils",
                      "address": 7,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do8",
                      "function": "read-coils",
                      "address": 8,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do9",
                      "function": "read-coils",
                      "address": 9,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do10",
                      "function": "read-coils",
                      "address": 10,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do11",
                      "function": "read-coils",
                      "address": 11,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di0",
                      "function": "read-discrete-inputs",
                      "address": 0,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di1",
                      "function": "read-discrete-inputs",
                      "address": 1,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di2",
                      "function": "read-discrete-inputs",
                      "address": 2,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di3",
                      "function": "read-discrete-inputs",
                      "address": 3,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di4",
                      "function": "read-discrete-inputs",
                      "address": 4,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di5",
                      "function": "read-discrete-inputs",
                      "address": 5,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di6",
                      "function": "read-discrete-inputs",
                      "address": 6,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di7",
                      "function": "read-discrete-inputs",
                      "address": 7,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di8",
                      "function": "read-discrete-inputs",
                      "address": 8,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di9",
                      "function": "read-discrete-inputs",
                      "address": 9,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di10",
                      "function": "read-discrete-inputs",
                      "address": 10,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di11",
                      "function": "read-discrete-inputs",
                      "address": 11,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "ai0",
                      "function": "read-input-registers",
                      "address": 512,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai1",
                      "function": "read-input-registers",
                      "address": 513,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai2",
                      "function": "read-input-registers",
                      "address": 514,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai3",
                      "function": "read-input-registers",
                      "address": 515,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai4",
                      "function": "read-input-registers",
                      "address": 516,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "rtdi0",
                      "function": "read-input-registers",
                      "address": 1536,
                      "quantity": 1,
                      "dataType": "uint16",
                      "enableAutoScaling": 1,
                      "autoScalingMode": "intercept",
                      "autoScaling": {
                        "slope": 0.1,
                        "offset": 0
                      },
                      "description": ""
                    },
                    {
                      "name": "rtdi1",
                      "function": "read-input-registers",
                      "address": 1537,
                      "quantity": 1,
                      "dataType": "uint16",
                      "enableAutoScaling": 1,
                      "autoScalingMode": "intercept",
                      "autoScaling": {
                        "slope": 0.1,
                        "offset": 0
                      },
                      "description": ""
                    },
                    {
                      "name": "rtdi2",
                      "function": "read-input-registers",
                      "address": 1538,
                      "quantity": 1,
                      "dataType": "uint16",
                      "enableAutoScaling": 1,
                      "autoScalingMode": "intercept",
                      "autoScaling": {
                        "slope": 0.1,
                        "offset": 0
                      },
                      "description": ""
                    }
                  ]
                },
                {
                  "id": 11,
                  "name": "ioLogik-E1261W-T",
                  "tagList": [
                    {
                      "name": "do0",
                      "function": "read-coils",
                      "address": 0,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do1",
                      "function": "read-coils",
                      "address": 1,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do2",
                      "function": "read-coils",
                      "address": 2,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do3",
                      "function": "read-coils",
                      "address": 3,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do4",
                      "function": "read-coils",
                      "address": 4,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do5",
                      "function": "read-coils",
                      "address": 5,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do6",
                      "function": "read-coils",
                      "address": 6,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do7",
                      "function": "read-coils",
                      "address": 7,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do8",
                      "function": "read-coils",
                      "address": 8,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do9",
                      "function": "read-coils",
                      "address": 9,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do10",
                      "function": "read-coils",
                      "address": 10,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do11",
                      "function": "read-coils",
                      "address": 11,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di0",
                      "function": "read-discrete-inputs",
                      "address": 0,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di1",
                      "function": "read-discrete-inputs",
                      "address": 1,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di2",
                      "function": "read-discrete-inputs",
                      "address": 2,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di3",
                      "function": "read-discrete-inputs",
                      "address": 3,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di4",
                      "function": "read-discrete-inputs",
                      "address": 4,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di5",
                      "function": "read-discrete-inputs",
                      "address": 5,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di6",
                      "function": "read-discrete-inputs",
                      "address": 6,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di7",
                      "function": "read-discrete-inputs",
                      "address": 7,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di8",
                      "function": "read-discrete-inputs",
                      "address": 8,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di9",
                      "function": "read-discrete-inputs",
                      "address": 9,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di10",
                      "function": "read-discrete-inputs",
                      "address": 10,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di11",
                      "function": "read-discrete-inputs",
                      "address": 11,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "ai0",
                      "function": "read-input-registers",
                      "address": 512,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai1",
                      "function": "read-input-registers",
                      "address": 513,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai2",
                      "function": "read-input-registers",
                      "address": 514,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai3",
                      "function": "read-input-registers",
                      "address": 515,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai4",
                      "function": "read-input-registers",
                      "address": 516,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "rtdi0",
                      "function": "read-input-registers",
                      "address": 1536,
                      "quantity": 1,
                      "dataType": "uint16",
                      "enableAutoScaling": 1,
                      "autoScalingMode": "intercept",
                      "autoScaling": {
                        "slope": 0.1,
                        "offset": 0
                      },
                      "description": ""
                    },
                    {
                      "name": "rtdi1",
                      "function": "read-input-registers",
                      "address": 1537,
                      "quantity": 1,
                      "dataType": "uint16",
                      "enableAutoScaling": 1,
                      "autoScalingMode": "intercept",
                      "autoScaling": {
                        "slope": 0.1,
                        "offset": 0
                      },
                      "description": ""
                    },
                    {
                      "name": "rtdi2",
                      "function": "read-input-registers",
                      "address": 1538,
                      "quantity": 1,
                      "dataType": "uint16",
                      "enableAutoScaling": 1,
                      "autoScalingMode": "intercept",
                      "autoScaling": {
                        "slope": 0.1,
                        "offset": 0
                      },
                      "description": ""
                    }
                  ]
                },
                {
                  "id": 12,
                  "name": "ioLogik-E1262",
                  "tagList": [
                    {
                      "name": "tci0",
                      "function": "read-input-registers",
                      "address": 2048,
                      "quantity": 2,
                      "dataType": "uint32",
                      "enableAutoScaling": 1,
                      "autoScalingMode": "intercept",
                      "autoScaling": {
                        "slope": 0.1,
                        "offset": 0
                      },
                      "description": ""
                    },
                    {
                      "name": "tci1",
                      "function": "read-input-registers",
                      "address": 2050,
                      "quantity": 2,
                      "dataType": "uint32",
                      "enableAutoScaling": 1,
                      "autoScalingMode": "intercept",
                      "autoScaling": {
                        "slope": 0.1,
                        "offset": 0
                      },
                      "description": ""
                    },
                    {
                      "name": "tci2",
                      "function": "read-input-registers",
                      "address": 2052,
                      "quantity": 2,
                      "dataType": "uint32",
                      "enableAutoScaling": 1,
                      "autoScalingMode": "intercept",
                      "autoScaling": {
                        "slope": 0.1,
                        "offset": 0
                      },
                      "description": ""
                    },
                    {
                      "name": "tci3",
                      "function": "read-input-registers",
                      "address": 2054,
                      "quantity": 2,
                      "dataType": "uint32",
                      "enableAutoScaling": 1,
                      "autoScalingMode": "intercept",
                      "autoScaling": {
                        "slope": 0.1,
                        "offset": 0
                      },
                      "description": ""
                    },
                    {
                      "name": "tci4",
                      "function": "read-input-registers",
                      "address": 2056,
                      "quantity": 2,
                      "dataType": "uint32",
                      "enableAutoScaling": 1,
                      "autoScalingMode": "intercept",
                      "autoScaling": {
                        "slope": 0.1,
                        "offset": 0
                      },
                      "description": ""
                    },
                    {
                      "name": "tci5",
                      "function": "read-input-registers",
                      "address": 2058,
                      "quantity": 2,
                      "dataType": "uint32",
                      "enableAutoScaling": 1,
                      "autoScalingMode": "intercept",
                      "autoScaling": {
                        "slope": 0.1,
                        "offset": 0
                      },
                      "description": ""
                    },
                    {
                      "name": "tci6",
                      "function": "read-input-registers",
                      "address": 2060,
                      "quantity": 2,
                      "dataType": "uint32",
                      "enableAutoScaling": 1,
                      "autoScalingMode": "intercept",
                      "autoScaling": {
                        "slope": 0.1,
                        "offset": 0
                      },
                      "description": ""
                    },
                    {
                      "name": "tci7",
                      "function": "read-input-registers",
                      "address": 2062,
                      "quantity": 2,
                      "dataType": "uint32",
                      "enableAutoScaling": 1,
                      "autoScalingMode": "intercept",
                      "autoScaling": {
                        "slope": 0.1,
                        "offset": 0
                      },
                      "description": ""
                    }
                  ]
                },
                {
                  "id": 13,
                  "name": "ioLogik-E1263H-T",
                  "tagList": [
                    {
                      "name": "do0",
                      "function": "read-coils",
                      "address": 0,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do1",
                      "function": "read-coils",
                      "address": 1,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do2",
                      "function": "read-coils",
                      "address": 2,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do3",
                      "function": "read-coils",
                      "address": 3,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do4",
                      "function": "read-coils",
                      "address": 4,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do5",
                      "function": "read-coils",
                      "address": 5,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do6",
                      "function": "read-coils",
                      "address": 6,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do7",
                      "function": "read-coils",
                      "address": 7,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do8",
                      "function": "read-coils",
                      "address": 8,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do9",
                      "function": "read-coils",
                      "address": 9,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do10",
                      "function": "read-coils",
                      "address": 10,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do11",
                      "function": "read-coils",
                      "address": 11,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do12",
                      "function": "read-coils",
                      "address": 12,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do13",
                      "function": "read-coils",
                      "address": 13,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do14",
                      "function": "read-coils",
                      "address": 14,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do15",
                      "function": "read-coils",
                      "address": 15,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do16",
                      "function": "read-coils",
                      "address": 16,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do17",
                      "function": "read-coils",
                      "address": 17,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do18",
                      "function": "read-coils",
                      "address": 18,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do19",
                      "function": "read-coils",
                      "address": 19,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do20",
                      "function": "read-coils",
                      "address": 20,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do21",
                      "function": "read-coils",
                      "address": 21,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do22",
                      "function": "read-coils",
                      "address": 22,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do23",
                      "function": "read-coils",
                      "address": 23,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di0",
                      "function": "read-discrete-inputs",
                      "address": 0,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di1",
                      "function": "read-discrete-inputs",
                      "address": 1,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di2",
                      "function": "read-discrete-inputs",
                      "address": 2,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di3",
                      "function": "read-discrete-inputs",
                      "address": 3,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di4",
                      "function": "read-discrete-inputs",
                      "address": 4,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di5",
                      "function": "read-discrete-inputs",
                      "address": 5,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di6",
                      "function": "read-discrete-inputs",
                      "address": 6,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di7",
                      "function": "read-discrete-inputs",
                      "address": 7,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di8",
                      "function": "read-discrete-inputs",
                      "address": 8,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di9",
                      "function": "read-discrete-inputs",
                      "address": 9,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di10",
                      "function": "read-discrete-inputs",
                      "address": 10,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di11",
                      "function": "read-discrete-inputs",
                      "address": 11,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di12",
                      "function": "read-discrete-inputs",
                      "address": 12,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di13",
                      "function": "read-discrete-inputs",
                      "address": 13,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di14",
                      "function": "read-discrete-inputs",
                      "address": 14,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di15",
                      "function": "read-discrete-inputs",
                      "address": 15,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di16",
                      "function": "read-discrete-inputs",
                      "address": 16,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di17",
                      "function": "read-discrete-inputs",
                      "address": 17,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di18",
                      "function": "read-discrete-inputs",
                      "address": 18,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di19",
                      "function": "read-discrete-inputs",
                      "address": 19,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di20",
                      "function": "read-discrete-inputs",
                      "address": 20,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di21",
                      "function": "read-discrete-inputs",
                      "address": 21,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di22",
                      "function": "read-discrete-inputs",
                      "address": 22,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di23",
                      "function": "read-discrete-inputs",
                      "address": 23,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "ai0",
                      "function": "read-input-registers",
                      "address": 512,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai1",
                      "function": "read-input-registers",
                      "address": 513,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai2",
                      "function": "read-input-registers",
                      "address": 514,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai3",
                      "function": "read-input-registers",
                      "address": 515,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai4",
                      "function": "read-input-registers",
                      "address": 516,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai5",
                      "function": "read-input-registers",
                      "address": 517,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai6",
                      "function": "read-input-registers",
                      "address": 518,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai7",
                      "function": "read-input-registers",
                      "address": 519,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai8",
                      "function": "read-input-registers",
                      "address": 520,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai9",
                      "function": "read-input-registers",
                      "address": 521,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "rtdi0",
                      "function": "read-input-registers",
                      "address": 1536,
                      "quantity": 1,
                      "dataType": "uint16",
                      "enableAutoScaling": 1,
                      "autoScalingMode": "intercept",
                      "autoScaling": {
                        "slope": 0.1,
                        "offset": 0
                      },
                      "description": ""
                    },
                    {
                      "name": "rtdi1",
                      "function": "read-input-registers",
                      "address": 1537,
                      "quantity": 1,
                      "dataType": "uint16",
                      "enableAutoScaling": 1,
                      "autoScalingMode": "intercept",
                      "autoScaling": {
                        "slope": 0.1,
                        "offset": 0
                      },
                      "description": ""
                    },
                    {
                      "name": "rtdi2",
                      "function": "read-input-registers",
                      "address": 1538,
                      "quantity": 1,
                      "dataType": "uint16",
                      "enableAutoScaling": 1,
                      "autoScalingMode": "intercept",
                      "autoScaling": {
                        "slope": 0.1,
                        "offset": 0
                      },
                      "description": ""
                    }
                  ]
                },
                {
                  "id": 14,
                  "name": "ioLogik-R1210",
                  "tagList": [
                    {
                      "name": "di0",
                      "function": "read-input-registers",
                      "address": 0,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di1",
                      "function": "read-input-registers",
                      "address": 1,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di2",
                      "function": "read-input-registers",
                      "address": 2,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di3",
                      "function": "read-input-registers",
                      "address": 3,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di4",
                      "function": "read-input-registers",
                      "address": 4,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di5",
                      "function": "read-input-registers",
                      "address": 5,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di6",
                      "function": "read-input-registers",
                      "address": 6,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di7",
                      "function": "read-input-registers",
                      "address": 7,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di8",
                      "function": "read-input-registers",
                      "address": 8,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di9",
                      "function": "read-input-registers",
                      "address": 9,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di10",
                      "function": "read-input-registers",
                      "address": 10,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di11",
                      "function": "read-input-registers",
                      "address": 11,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di12",
                      "function": "read-input-registers",
                      "address": 12,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di13",
                      "function": "read-input-registers",
                      "address": 13,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di14",
                      "function": "read-input-registers",
                      "address": 14,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di15",
                      "function": "read-input-registers",
                      "address": 15,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    }
                  ]
                },
                {
                  "id": 15,
                  "name": "ioLogik-R1212",
                  "tagList": [
                    {
                      "name": "di0",
                      "function": "read-input-registers",
                      "address": 0,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di1",
                      "function": "read-input-registers",
                      "address": 1,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di2",
                      "function": "read-input-registers",
                      "address": 2,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di3",
                      "function": "read-input-registers",
                      "address": 3,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di4",
                      "function": "read-input-registers",
                      "address": 4,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di5",
                      "function": "read-input-registers",
                      "address": 5,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di6",
                      "function": "read-input-registers",
                      "address": 6,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di7",
                      "function": "read-input-registers",
                      "address": 7,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di8",
                      "function": "read-input-registers",
                      "address": 8,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di9",
                      "function": "read-input-registers",
                      "address": 9,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di10",
                      "function": "read-input-registers",
                      "address": 10,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di11",
                      "function": "read-input-registers",
                      "address": 11,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di12",
                      "function": "read-input-registers",
                      "address": 12,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di13",
                      "function": "read-input-registers",
                      "address": 13,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di14",
                      "function": "read-input-registers",
                      "address": 14,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di15",
                      "function": "read-input-registers",
                      "address": 15,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do0",
                      "function": "read-holding-registers",
                      "address": 320,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do1",
                      "function": "read-holding-registers",
                      "address": 321,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do2",
                      "function": "read-holding-registers",
                      "address": 322,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do3",
                      "function": "read-holding-registers",
                      "address": 323,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do4",
                      "function": "read-holding-registers",
                      "address": 324,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do5",
                      "function": "read-holding-registers",
                      "address": 325,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do6",
                      "function": "read-holding-registers",
                      "address": 326,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "do7",
                      "function": "read-holding-registers",
                      "address": 327,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    }
                  ]
                },
                {
                  "id": 16,
                  "name": "ioLogik-R1214",
                  "tagList": [
                    {
                      "name": "di0",
                      "function": "read-input-registers",
                      "address": 0,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di1",
                      "function": "read-input-registers",
                      "address": 1,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di2",
                      "function": "read-input-registers",
                      "address": 2,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di3",
                      "function": "read-input-registers",
                      "address": 3,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di4",
                      "function": "read-input-registers",
                      "address": 4,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di5",
                      "function": "read-input-registers",
                      "address": 5,
                      "quantity": 1,
                      "dataType": "boolean",
                      "description": ""
                    },
                    {
                      "name": "ro0",
                      "function": "read-holding-registers",
                      "address": 320,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ro1",
                      "function": "read-holding-registers",
                      "address": 321,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ro2",
                      "function": "read-holding-registers",
                      "address": 322,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ro3",
                      "function": "read-holding-registers",
                      "address": 323,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ro4",
                      "function": "read-holding-registers",
                      "address": 324,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ro5",
                      "function": "read-holding-registers",
                      "address": 325,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    }
                  ]
                },
                {
                  "id": 17,
                  "name": "ioLogik-R1240",
                  "tagList": [
                    {
                      "name": "ai0",
                      "function": "read-input-registers",
                      "address": 704,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai1",
                      "function": "read-input-registers",
                      "address": 705,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai2",
                      "function": "read-input-registers",
                      "address": 706,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai3",
                      "function": "read-input-registers",
                      "address": 707,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai4",
                      "function": "read-input-registers",
                      "address": 708,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai5",
                      "function": "read-input-registers",
                      "address": 709,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai6",
                      "function": "read-input-registers",
                      "address": 710,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ai7",
                      "function": "read-input-registers",
                      "address": 711,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    }
                  ]
                },
                {
                  "id": 18,
                  "name": "ioLogik-R1241",
                  "tagList": [
                    {
                      "name": "ao0",
                      "function": "read-holding-registers",
                      "address": 1184,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ao1",
                      "function": "read-holding-registers",
                      "address": 1185,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ao2",
                      "function": "read-holding-registers",
                      "address": 1186,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    },
                    {
                      "name": "ao3",
                      "function": "read-holding-registers",
                      "address": 1187,
                      "quantity": 1,
                      "dataType": "uint16",
                      "description": ""
                    }
                  ]
                }
              ]
            }
          }
        },
        "tags": [
          "modbus"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      }
    },
    "/mxc/modbus/equipment-templates/{id}": {
      "parameters": [
        {
          "name": "id",
          "in": "path",
          "type": "integer",
          "required": true
        }
      ],
      "get": {
        "description": "Get equipment templates by ID",
        "responses": {
          "200": {
            "description": "success",
            "schema": {
              "$ref": "#/definitions/EquipmentTemplate"
            },
            "examples": {
              "application/json": {
                "id": 9,
                "name": "ioLogik-E1260",
                "tagList": [
                  {
                    "name": "rtdi0",
                    "function": "read-input-registers",
                    "address": 1536,
                    "quantity": 1,
                    "dataType": "uint16",
                    "enableAutoScaling": 1,
                    "autoScalingMode": "intercept",
                    "autoScaling": {
                      "slope": 0.1,
                      "offset": 0
                    },
                    "description": ""
                  },
                  {
                    "name": "rtdi1",
                    "function": "read-input-registers",
                    "address": 1537,
                    "quantity": 1,
                    "dataType": "uint16",
                    "enableAutoScaling": 1,
                    "autoScalingMode": "intercept",
                    "autoScaling": {
                      "slope": 0.1,
                      "offset": 0
                    },
                    "description": ""
                  },
                  {
                    "name": "rtdi2",
                    "function": "read-input-registers",
                    "address": 1538,
                    "quantity": 1,
                    "dataType": "uint16",
                    "enableAutoScaling": 1,
                    "autoScalingMode": "intercept",
                    "autoScaling": {
                      "slope": 0.1,
                      "offset": 0
                    },
                    "description": ""
                  },
                  {
                    "name": "rtdi3",
                    "function": "read-input-registers",
                    "address": 1539,
                    "quantity": 1,
                    "dataType": "uint16",
                    "enableAutoScaling": 1,
                    "autoScalingMode": "intercept",
                    "autoScaling": {
                      "slope": 0.1,
                      "offset": 0
                    },
                    "description": ""
                  },
                  {
                    "name": "rtdi4",
                    "function": "read-input-registers",
                    "address": 1540,
                    "quantity": 1,
                    "dataType": "uint16",
                    "enableAutoScaling": 1,
                    "autoScalingMode": "intercept",
                    "autoScaling": {
                      "slope": 0.1,
                      "offset": 0
                    },
                    "description": ""
                  },
                  {
                    "name": "rtdi5",
                    "function": "read-input-registers",
                    "address": 1541,
                    "quantity": 1,
                    "dataType": "uint16",
                    "enableAutoScaling": 1,
                    "autoScalingMode": "intercept",
                    "autoScaling": {
                      "slope": 0.1,
                      "offset": 0
                    },
                    "description": ""
                  }
                ]
              }
            }
          }
        },
        "tags": [
          "modbus"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      },
      "put": {
        "parameters": [
          {
            "name": "body",
            "in": "body",
            "required": true,
            "schema": {
              "$ref": "#/definitions/EquipmentTemplate"
            }
          }
        ],
        "description": "Update an equipment template by ID",
        "responses": {
          "200": {
            "description": "success",
            "schema": {
              "$ref": "#/definitions/EquipmentTemplate"
            },
            "examples": {
              "application/json": {
                "id": 9,
                "name": "ioLogik-E1260",
                "tagList": [
                  {
                    "name": "rtdi0",
                    "function": "read-input-registers",
                    "address": 1536,
                    "quantity": 1,
                    "dataType": "uint16",
                    "enableAutoScaling": 1,
                    "autoScalingMode": "intercept",
                    "autoScaling": {
                      "slope": 0.1,
                      "offset": 0
                    },
                    "description": ""
                  },
                  {
                    "name": "rtdi1",
                    "function": "read-input-registers",
                    "address": 1537,
                    "quantity": 1,
                    "dataType": "uint16",
                    "enableAutoScaling": 1,
                    "autoScalingMode": "intercept",
                    "autoScaling": {
                      "slope": 0.1,
                      "offset": 0
                    },
                    "description": ""
                  },
                  {
                    "name": "rtdi2",
                    "function": "read-input-registers",
                    "address": 1538,
                    "quantity": 1,
                    "dataType": "uint16",
                    "enableAutoScaling": 1,
                    "autoScalingMode": "intercept",
                    "autoScaling": {
                      "slope": 0.1,
                      "offset": 0
                    },
                    "description": ""
                  },
                  {
                    "name": "rtdi3",
                    "function": "read-input-registers",
                    "address": 1539,
                    "quantity": 1,
                    "dataType": "uint16",
                    "enableAutoScaling": 1,
                    "autoScalingMode": "intercept",
                    "autoScaling": {
                      "slope": 0.1,
                      "offset": 0
                    },
                    "description": ""
                  },
                  {
                    "name": "rtdi4",
                    "function": "read-input-registers",
                    "address": 1540,
                    "quantity": 1,
                    "dataType": "uint16",
                    "enableAutoScaling": 1,
                    "autoScalingMode": "intercept",
                    "autoScaling": {
                      "slope": 0.1,
                      "offset": 0
                    },
                    "description": ""
                  },
                  {
                    "name": "rtdi5",
                    "function": "read-input-registers",
                    "address": 1541,
                    "quantity": 1,
                    "dataType": "uint16",
                    "enableAutoScaling": 1,
                    "autoScalingMode": "intercept",
                    "autoScaling": {
                      "slope": 0.1,
                      "offset": 0
                    },
                    "description": ""
                  }
                ]
              }
            }
          }
        },
        "tags": [
          "modbus"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      },
      "delete": {
        "description": "Delete an equipment templates by ID",
        "responses": {
          "200": {
            "description": "success"
          }
        },
        "tags": [
          "modbus"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      }
    },
    "/mxc/modbus/interfaces": {
      "get": {
        "description": "Get all interfaces",
        "responses": {
          "200": {
            "description": "success",
            "schema": {
              "type": "array",
              "items": {
                "$ref": "#/definitions/Interface"
              }
            },
            "examples": {
              "application/json": [
                {
                  "id": 1,
                  "name": "Modbus_Gateway_1",
                  "type": "modbus-rtu",
                  "config": {
                    "dev": "/dev/ttyM0",
                    "devDisplayName": "PORT 1",
                    "baudRate": 115200,
                    "parity": "none",
                    "stopBits": 1,
                    "intercharTimeoutMs": 100,
                    "interframeDelayMs": 0
                  },
                  "requestTimeoutMs": 500,
                  "pollingPeriodMs": 5000,
                  "deviceList": []
                },
                {
                  "id": 2,
                  "name": "Modbus_Gateway_2",
                  "type": "modbus-rtu",
                  "config": {
                    "dev": "/dev/ttyM1",
                    "devDisplayName": "PORT 2",
                    "baudRate": 115200,
                    "parity": "none",
                    "stopBits": 1,
                    "intercharTimeoutMs": 100,
                    "interframeDelayMs": 0
                  },
                  "requestTimeoutMs": 500,
                  "pollingPeriodMs": 5000,
                  "deviceList": []
                }
              ]
            }
          }
        },
        "tags": [
          "modbus"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      },
      "post": {
        "parameters": [
          {
            "name": "body",
            "in": "body",
            "required": true,
            "schema": {
              "$ref": "#/definitions/Interface"
            }
          }
        ],
        "description": "Create a TCP interface (RTU interfaces are already built-in and can't be deleted)",
        "responses": {
          "200": {
            "description": "sucess",
            "schema": {
              "$ref": "#/definitions/Interface"
            },
            "examples": {
              "application/json": {
                "id": 1,
                "name": "Modbus_Gateway_1",
                "type": "modbus-rtu",
                "config": {
                  "host": "192.168.1.1",
                  "port": 32556
                },
                "requestTimeoutMs": 500,
                "pollingPeriodMs": 5000,
                "deviceList": []
              }
            }
          }
        },
        "tags": [
          "modbus"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      }
    },
    "/mxc/modbus/interfaces/{id}": {
      "parameters": [
        {
          "name": "id",
          "in": "path",
          "type": "integer",
          "required": true
        }
      ],
      "get": {
        "description": "Get an interface by given ID",
        "responses": {
          "200": {
            "description": "success",
            "schema": {
              "$ref": "#/definitions/Interface"
            },
            "examples": {
              "application/json": {
                "id": 1,
                "name": "Modbus_Gateway_1",
                "type": "modbus-rtu",
                "config": {
                  "dev": "/dev/ttyM0",
                  "devDisplayName": "PORT 1",
                  "baudRate": 115200,
                  "parity": "none",
                  "stopBits": 1,
                  "intercharTimeoutMs": 100,
                  "interframeDelayMs": 0
                },
                "requestTimeoutMs": 500,
                "pollingPeriodMs": 5000,
                "deviceList": []
              }
            }
          }
        },
        "tags": [
          "modbus"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      },
      "put": {
        "parameters": [
          {
            "name": "body",
            "in": "body",
            "required": true,
            "schema": {
              "$ref": "#/definitions/Interface"
            }
          }
        ],
        "description": "Update an interface by given ID",
        "responses": {
          "200": {
            "description": "success",
            "schema": {
              "$ref": "#/definitions/Interface"
            },
            "examples": {
              "application/json": {
                "id": 1,
                "name": "Modbus_Gateway_1",
                "type": "modbus-rtu",
                "config": {
                  "dev": "/dev/ttyM0",
                  "devDisplayName": "PORT 1",
                  "baudRate": 115200,
                  "parity": "none",
                  "stopBits": 1,
                  "intercharTimeoutMs": 100,
                  "interframeDelayMs": 0
                },
                "requestTimeoutMs": 500,
                "pollingPeriodMs": 5000,
                "deviceList": []
              }
            }
          }
        },
        "tags": [
          "modbus"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      },
      "delete": {
        "description": "Delete an interface by Given ID (Can't delete built-in RTU interfaces)",
        "responses": {
          "200": {
            "description": "success"
          }
        },
        "tags": [
          "modbus"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      }
    },
    "/mxc/modbus/equipments": {
      "get": {
        "description": "Get all modbus equipments for Log Profile",
        "responses": {
          "200": {
            "description": "success",
            "schema": {
              "type": "array",
              "items": {
                "$ref": "#/definitions/ModbusListEquipment"
              }
            },
            "examples": {
              "application/json": [
                {
                  "equipmentName": "LIGHT",
                  "equipmentTags": [
                    {
                      "name": "di0",
                      "function": "read-discrete-inputs",
                      "address": 0,
                      "quantity": 1,
                      "type": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di1",
                      "function": "read-discrete-inputs",
                      "address": 1,
                      "quantity": 1,
                      "type": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di2",
                      "function": "read-discrete-inputs",
                      "address": 2,
                      "quantity": 1,
                      "type": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di3",
                      "function": "read-discrete-inputs",
                      "address": 3,
                      "quantity": 1,
                      "type": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di4",
                      "function": "read-discrete-inputs",
                      "address": 4,
                      "quantity": 1,
                      "type": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di5",
                      "function": "read-discrete-inputs",
                      "address": 5,
                      "quantity": 1,
                      "type": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di6",
                      "function": "read-discrete-inputs",
                      "address": 6,
                      "quantity": 1,
                      "type": "boolean",
                      "description": ""
                    },
                    {
                      "name": "di7",
                      "function": "read-discrete-inputs",
                      "address": 7,
                      "quantity": 1,
                      "type": "boolean",
                      "description": ""
                    }
                  ]
                }
              ]
            }
          }
        },
        "tags": [
          "modbus"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      }
    },
    "/network/portmapping": {
      "get": {
        "summary": "Port Mapping Rule(s)",
        "description": "List all port mapping rules.",
        "responses": {
          "200": {
            "description": "An array of port mapping rule(s)",
            "schema": {
              "type": "array",
              "items": {
                "$ref": "#/definitions/PortMapping"
              }
            },
            "examples": {
              "application/json": [
                {
                  "id": 1,
                  "enable": true,
                  "service": "http",
                  "extPort": {
                    "start": 8080,
                    "end": 8080
                  },
                  "intPort": {
                    "start": 80,
                    "end": 80
                  },
                  "intIp": "192.168.5.123",
                  "protocol": "tcp"
                },
                {
                  "id": 2,
                  "enable": false,
                  "service": "test",
                  "extPort": {
                    "start": 10080,
                    "end": 10083
                  },
                  "intPort": {
                    "start": 8080,
                    "end": 8083
                  },
                  "intIp": "192.168.5.123",
                  "protocol": "both"
                }
              ]
            }
          }
        },
        "tags": [
          "iptables"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      },
      "post": {
        "parameters": [
          {
            "name": "body",
            "in": "body",
            "required": true,
            "schema": {
              "$ref": "#/definitions/PortMapping"
            }
          }
        ],
        "summary": "Create a Port Mapping Rule",
        "description": "Append a port mapping rule in the table.",
        "responses": {
          "200": {
            "description": "OK",
            "schema": {
              "$ref": "#/definitions/PortMapping"
            },
            "examples": {
              "application/json": {
                "id": 1,
                "enable": true,
                "service": "http",
                "extPort": {
                  "start": 8080,
                  "end": 8080
                },
                "intPort": {
                  "start": 80,
                  "end": 80
                },
                "intIp": "192.168.5.123",
                "protocol": "tcp"
              }
            }
          }
        },
        "tags": [
          "iptables"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      },
      "delete": {
        "parameters": [
          {
            "name": "body",
            "in": "body",
            "required": true,
            "schema": {
              "type": "array",
              "items": {
                "description": "Target rule ID",
                "type": "integer"
              }
            }
          }
        ],
        "description": "Delete multiple rules",
        "responses": {
          "200": {
            "description": "success"
          }
        },
        "tags": [
          "iptables"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      }
    },
    "/network/portmapping/{id}": {
      "get": {
        "description": "Get a port mapping rule by ID",
        "responses": {
          "200": {
            "description": "success",
            "schema": {
              "$ref": "#/definitions/PortMapping"
            },
            "examples": {
              "application/json": {
                "id": 1,
                "enable": true,
                "service": "http",
                "extPort": {
                  "start": 8080,
                  "end": 8080
                },
                "intPort": {
                  "start": 80,
                  "end": 80
                },
                "intIp": "192.168.5.123",
                "protocol": "tcp"
              }
            }
          }
        },
        "tags": [
          "iptables"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      },
      "parameters": [
        {
          "name": "id",
          "in": "path",
          "type": "integer",
          "required": true
        }
      ],
      "put": {
        "parameters": [
          {
            "name": "body",
            "in": "body",
            "required": true,
            "schema": {
              "$ref": "#/definitions/PortMapping"
            }
          }
        ],
        "summary": "Update a Port Mapping Rule",
        "description": "Update a port mapping rule in the table.",
        "responses": {
          "200": {
            "description": "OK",
            "schema": {
              "$ref": "#/definitions/PortMapping"
            },
            "examples": {
              "application/json": {
                "id": 1,
                "enable": true,
                "service": "http",
                "extPort": {
                  "start": 8080,
                  "end": 8080
                },
                "intPort": {
                  "start": 80,
                  "end": 80
                },
                "intIp": "192.168.5.123",
                "protocol": "tcp"
              }
            }
          }
        },
        "tags": [
          "iptables"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      },
      "delete": {
        "description": "Delete port mapping rule by ID",
        "responses": {
          "200": {
            "description": "success"
          }
        },
        "tags": [
          "iptables"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      }
    },
    "/network/ssnat": {
      "get": {
        "summary": "Simple SNAT Rule(s)",
        "description": "List all simple source NAT rules.",
        "responses": {
          "200": {
            "description": "An array of simple SNAT rule(s)",
            "schema": {
              "type": "array",
              "items": {
                "$ref": "#/definitions/SSNAT"
              }
            },
            "examples": {
              "application/json": [
                {
                  "id": 1,
                  "enable": true,
                  "priority": 0,
                  "service": "http",
                  "protocol": "both",
                  "intIp": "192.168.5.123",
                  "portStart": 80,
                  "portEnd": 80,
                  "outInterface": "wan"
                },
                {
                  "id": 2,
                  "enable": false,
                  "priority": 1,
                  "service": "https",
                  "protocol": "both",
                  "intIp": "192.168.5.123",
                  "portStart": 443,
                  "portEnd": 443,
                  "outInterface": "wan"
                }
              ]
            }
          }
        },
        "tags": [
          "iptables"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      },
      "post": {
        "parameters": [
          {
            "name": "body",
            "in": "body",
            "required": true,
            "schema": {
              "$ref": "#/definitions/SSNAT"
            }
          }
        ],
        "summary": "Create a Simple SNAT Rule",
        "description": "Create a simple source NAT rule in the table, only internal IP,\nsource port, and internal IP is provided.\n",
        "responses": {
          "200": {
            "description": "OK",
            "schema": {
              "$ref": "#/definitions/SSNAT"
            },
            "examples": {
              "application/json": {
                "id": 1,
                "enable": true,
                "priority": 0,
                "service": "http",
                "protocol": "both",
                "intIp": "192.168.5.123",
                "portStart": 80,
                "portEnd": 80,
                "outInterface": "wan"
              }
            }
          }
        },
        "tags": [
          "iptables"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      },
      "delete": {
        "parameters": [
          {
            "name": "body",
            "in": "body",
            "required": true,
            "schema": {
              "type": "array",
              "items": {
                "description": "Target rule ID",
                "type": "integer"
              }
            }
          }
        ],
        "description": "Delete multiple rules",
        "responses": {
          "200": {
            "description": "success"
          }
        },
        "tags": [
          "iptables"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      }
    },
    "/network/ssnat/{id}": {
      "get": {
        "description": "Get a simple source NAT rule by ID",
        "responses": {
          "200": {
            "description": "success",
            "schema": {
              "$ref": "#/definitions/SSNAT"
            },
            "examples": {
              "application/json": {
                "id": 1,
                "enable": true,
                "priority": 0,
                "service": "http",
                "protocol": "both",
                "intIp": "192.168.5.123",
                "portStart": 80,
                "portEnd": 80,
                "outInterface": "wan"
              }
            }
          }
        },
        "tags": [
          "iptables"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      },
      "parameters": [
        {
          "name": "id",
          "in": "path",
          "type": "integer",
          "required": true
        }
      ],
      "put": {
        "parameters": [
          {
            "name": "body",
            "in": "body",
            "required": true,
            "schema": {
              "$ref": "#/definitions/SSNAT"
            }
          }
        ],
        "summary": "Update a Simple SNAT Rule",
        "description": "Update a simple source NAT rule in the table.",
        "responses": {
          "200": {
            "description": "OK",
            "schema": {
              "$ref": "#/definitions/SSNAT"
            },
            "examples": {
              "application/json": {
                "id": 1,
                "enable": true,
                "priority": 0,
                "service": "http",
                "protocol": "both",
                "intIp": "192.168.5.123",
                "portStart": 80,
                "portEnd": 80,
                "outInterface": "wan"
              }
            }
          }
        },
        "tags": [
          "iptables"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      },
      "delete": {
        "description": "Delete simple source NAT rule by ID",
        "responses": {
          "200": {
            "description": "success"
          }
        },
        "tags": [
          "iptables"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      }
    },
    "/network/firewall/wan/https": {
      "get": {
        "description": "Get the firewall status for HTTPS on WAN",
        "responses": {
          "200": {
            "description": "status",
            "schema": {
              "$ref": "#/definitions/FirewallWanHttps"
            },
            "examples": {
              "application/json": {
                "enable": false
              }
            }
          }
        },
        "tags": [
          "iptables"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      },
      "put": {
        "parameters": [
          {
            "name": "body",
            "in": "body",
            "required": true,
            "schema": {
              "$ref": "#/definitions/FirewallWanHttps"
            }
          }
        ],
        "description": "Update the firewall status for HTTPS on WAN",
        "responses": {
          "200": {
            "description": "OK",
            "schema": {
              "$ref": "#/definitions/FirewallWanHttps"
            },
            "examples": {
              "application/json": {
                "enable": false
              }
            }
          }
        },
        "tags": [
          "iptables"
        ],
        "security": [
          {
            "mx-api-token": []
          }
        ]
      }
    }
  },
  "definitions": {
    "Cellular": {
      "title": "Cellular",
      "required": [
        "id",
        "enable",
        "pinCode",
        "pdpContext",
        "keepalive"
      ],
      "properties": {
        "id": {
          "type": "integer",
          "description": "Identifier for an Cellular interface."
        },
        "name": {
          "type": "string",
          "description": "Interface name."
        },
        "mode": {
          "type": "string",
          "description": "Given cellular connection mode. Could be one of `\"umts\"`, `\"lte\"`."
        },
        "signal": {
          "type": "object",
          "description": "Cellular RF signal strength, include RSSI and EcIo.",
          "required": [
            "csq",
            "rssi",
            "ecio"
          ],
          "properties": {
            "csq": {
              "type": "integer",
              "description": "Signal quality, Only shows the first part of the response, RSSI\n(Received signal strength indicator).\n"
            },
            "rssi": {
              "type": "integer",
              "description": "Cellular RF signal strength, in `dbm`. Value `0` indicates no\nSIM card found.\n"
            },
            "ecio": {
              "type": "integer",
              "description": "The ratio of the received energy per chip (= code bit) and the\ninterference level, given in `dBm`.\n"
            }
          }
        },
        "operatorName": {
          "type": "string",
          "description": "Indicate current operator name if exist."
        },
        "lac": {
          "type": "string",
          "description": "Location area code."
        },
        "tac": {
          "type": "string",
          "description": "Tracking area code (LTE)."
        },
        "nid": {
          "type": "string",
          "description": "Network ID (CDMA)."
        },
        "cellId": {
          "type": "string",
          "description": "Cell ID."
        },
        "bid": {
          "type": "string",
          "description": "Base station ID (CDMA)."
        },
        "iccId": {
          "type": "string",
          "description": "ICC ID of SIM card."
        },
        "imsi": {
          "type": "string",
          "description": "IMSI of SIM card."
        },
        "imei": {
          "type": "string",
          "description": "IMEI of cellular module."
        },
        "esn": {
          "type": "string",
          "description": "ESN of cellular module."
        },
        "pinRetryRemain": {
          "type": "integer",
          "description": "PIN Retry remaining."
        },
        "status": {
          "type": "string",
          "description": "Indicate current status of cellular connection. Could be one of \"nosim\", \"pin\", \"noservice\", \"ready\", \"connected\", \"connecting\", \"connect-failed\"."
        },
        "mac": {
          "type": "string",
          "readOnly": true,
          "description": "The identical MAC address."
        },
        "ip": {
          "type": "string",
          "pattern": "^(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)$",
          "description": "IP address. `\"\"` when not connected."
        },
        "netmask": {
          "type": "string",
          "pattern": "^(254|252|248|240|224|192|128)\\.0\\.0\\.0|255\\.(254|252|248|240|224|192|128|0)\\.0\\.0|255\\.255\\.(254|252|248|240|224|192|128|0)\\.0|255\\.255\\.255\\.(254|252|248|240|224|192|128|0)",
          "description": "Subnet mask. `\"\"` when not connected."
        },
        "gateway": {
          "type": "string",
          "pattern": "^(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)$",
          "description": "Gateway IP address. `\"\"` when not connected."
        },
        "dns": {
          "type": "array",
          "description": "A list of DNS IP addresses. `[]` when not connected.",
          "items": {
            "type": "string",
            "pattern": "^(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)$"
          }
        },
        "usage": {
          "type": "object",
          "description": "Data usage.",
          "required": [
            "txkbyte",
            "rxkbyte"
          ],
          "properties": {
            "txkbyte": {
              "type": "integer",
              "description": "Amount of data transmitted, in Kbytes."
            },
            "rxkbyte": {
              "type": "integer",
              "description": "Amount of data received, in Kbytes."
            }
          }
        },
        "enable": {
          "type": "boolean",
          "description": "Enable Cellular Networking."
        },
        "pdpContext": {
          "type": "object",
          "description": "PDP context data for dialing up to Cellular Network.",
          "required": [
            "static",
            "id",
            "primary",
            "secondary"
          ],
          "properties": {
            "static": {
              "type": "boolean",
              "description": "Use static APN or dynamic."
            },
            "id": {
              "type": "integer",
              "description": "Specifies PDP context id.",
              "minimum": 1,
              "maximum": 16
            },
            "retryTimeout": {
              "type": "integer",
              "description": "Retry timeout in seconds for static APN to switch primary to\nsecondary settings.\n",
              "minimum": 60,
              "maximum": 86399
            },
            "primary": {
              "type": "object",
              "description": "Primary PDP context.",
              "properties": {
                "apn": {
                  "type": "string",
                  "description": "Edit APN of the specified PDP context."
                },
                "type": {
                  "type": "string",
                  "description": "Indicate the PDP type to use.",
                  "enum": [
                    "ipv4",
                    "ipv6",
                    "ipv4v6"
                  ]
                }
              }
            },
            "secondary": {
              "type": "object",
              "description": "Secondary PDP context.",
              "properties": {
                "apn": {
                  "type": "string",
                  "description": "Edit APN of the specified PDP context."
                },
                "type": {
                  "type": "string",
                  "description": "Indicate the PDP type to use.",
                  "enum": [
                    "ipv4",
                    "ipv6",
                    "ipv4v6"
                  ]
                }
              }
            },
            "list": {
              "readOnly": true,
              "type": "array",
              "description": "PDP context list.",
              "items": {
                "type": "object",
                "description": "An PDP context",
                "required": [
                  "id",
                  "apn",
                  "type"
                ],
                "properties": {
                  "id": {
                    "type": "integer",
                    "minimum": 1,
                    "maximum": 16
                  },
                  "apn": {
                    "type": "string"
                  },
                  "type": {
                    "type": "string",
                    "enum": [
                      "ipv4",
                      "ipv6",
                      "ipv4v6"
                    ]
                  }
                }
              }
            }
          }
        },
        "pinCode": {
          "type": "string",
          "description": "PIN code of SIM card. Takes no effect when SIM card PIN weren't not set."
        },
        "keepalive": {
          "type": "object",
          "description": "Keep-alive configuration.",
          "required": [
            "enable",
            "targetHost",
            "intervalSec"
          ],
          "properties": {
            "enable": {
              "type": "boolean",
              "description": "Enable/disable Cellular connection keep-alive by ping."
            },
            "targetHost": {
              "type": "string",
              "description": "IP address to ping."
            },
            "intervalSec": {
              "type": "integer",
              "minimum": 60,
              "maximum": 86399,
              "description": "Check alive interval."
            },
            "reboot": {
              "type": "object",
              "description": "Reboot system while check alive failed after a defined cycle(s).\n",
              "properties": {
                "enable": {
                  "type": "boolean",
                  "description": "Enable/disable reboot policy for check alive failed.\n"
                },
                "cycles": {
                  "type": "integer",
                  "minimum": 1,
                  "maximum": 48,
                  "description": "Define cycles to check if reboot is required; a cycle is\na global value defined by system, default should be 20\nminutes.\n"
                }
              }
            }
          }
        }
      },
      "example": {
        "id": 1,
        "name": "wwan1",
        "mode": "umts",
        "signal": {
          "csq": 14,
          "rssi": -76,
          "ecio": -8.5
        },
        "operatorName": "Chunghwa Telecom",
        "lac": "11114",
        "tac": "",
        "nid": "",
        "cellId": "1249",
        "bid": "",
        "iccId": "",
        "imsi": "466977502877452",
        "imei": "356853050370859",
        "esn": "802202F0",
        "pinRetryRemain": 3,
        "status": "connected",
        "mac": "00:00:00:00:00:00",
        "ip": "111.70.146.125",
        "netmask": "255.255.255.252",
        "gateway": "111.70.146.126",
        "dns": [
          "168.95.1.1",
          "168.95.192.1"
        ],
        "usage": {
          "txkbyte": 40023,
          "rxkbyte": 3493
        },
        "enable": true,
        "pdpContext": {
          "static": true,
          "id": 1,
          "retryTimeout": 1200,
          "primary": {
            "apn": "internet",
            "type": "ipv4v6"
          },
          "secondary": {
            "apn": "internet",
            "type": "ipv4v6"
          },
          "list": [
            {
              "id": 1,
              "apn": "internet",
              "type": "ipv4v6"
            }
          ]
        },
        "pinCode": "0000",
        "keepalive": {
          "enable": true,
          "targetHost": "8.8.8.8",
          "intervalSec": 60,
          "reboot": {
            "enable": false,
            "cycles": 1
          }
        }
      }
    },
    "CellularFirmwareInfo": {
      "title": "CellularFirmwareInfo",
      "description": "Display current, preferred, available firmware properties, if current firmware is not  equal to preferred firmware, you should check your configuration. (fwver, config, carrier mismatch?).",
      "properties": {
        "switchable": {
          "type": "boolean",
          "readOnly": true,
          "description": "Cellular firmware could be switched or not."
        },
        "current": {
          "$ref": "#/definitions/CellularFirmwareEntry"
        },
        "preferred": {
          "$ref": "#/definitions/CellularFirmwareEntry"
        },
        "available": {
          "type": "array",
          "items": {
            "$ref": "#/definitions/CellularFirmwareEntry"
          }
        }
      },
      "example": {
        "switchable": true,
        "current": {
          "fwver": "05.05.58.01",
          "config": "ATT_005.029_001",
          "carrier": "ATT"
        },
        "preferred": {
          "fwver": "05.05.58.01",
          "config": "ATT_005.029_001",
          "carrier": "ATT"
        },
        "available": [
          {
            "fwver": "05.05.58.01",
            "config": "ATT_005.029_001",
            "carrier": "ATT"
          },
          {
            "fwver": "05.05.58.02",
            "config": "VZW_005.029_002",
            "carrier": "VZW"
          }
        ]
      }
    },
    "CellularFirmwareEntry": {
      "title": "CellularFirmwareEntry",
      "type": "object",
      "description": "sdfdf",
      "required": [
        "fwver",
        "config",
        "carrier"
      ],
      "properties": {
        "fwver": {
          "type": "string",
          "description": "Firmware version",
          "minLength": 0,
          "maxLength": 32
        },
        "config": {
          "type": "string",
          "description": "Config name",
          "minLength": 0,
          "maxLength": 32
        },
        "carrier": {
          "type": "string",
          "description": "Carrier name",
          "minLength": 0,
          "maxLength": 32
        }
      },
      "example": {
        "fwver": "05.05.58.01",
        "config": "ATT_005.029_001",
        "carrier": "ATT"
      }
    },
    "CustomEquipment": {
      "title": "Custom Equipment",
      "description": "Custom Equipment object",
      "type": "object",
      "required": [
        "equipmentName",
        "equipmentTags"
      ],
      "properties": {
        "id": {
          "type": "integer",
          "description": "ID of equipment",
          "readOnly": true
        },
        "equipmentName": {
          "description": "Name of custom equipment",
          "type": "string"
        },
        "equipmentTags": {
          "description": "Tag List of custom equipment",
          "type": "array",
          "items": {
            "$ref": "#/definitions/CustomEquipmentTag"
          }
        }
      }
    },
    "CustomEquipmentTag": {
      "title": "Tag",
      "description": "Equipment's tag entry",
      "type": "object",
      "required": [
        "name",
        "dataType",
        "access",
        "size",
        "description"
      ],
      "properties": {
        "name": {
          "description": "Name of tag",
          "type": "string",
          "minLength": 1,
          "maxLength": 255
        },
        "dataType": {
          "description": "Data type of tag",
          "type": "string",
          "enum": [
            "boolean",
            "uint16",
            "uint32",
            "uint64",
            "int16",
            "int32",
            "int64",
            "float32",
            "float64",
            "string",
            "bytearray"
          ]
        },
        "access": {
          "description": "Access type of tag",
          "type": "string",
          "enum": [
            "ro",
            "wo",
            "rw"
          ]
        },
        "size": {
          "description": "Size of tag in byte",
          "type": "integer"
        },
        "description": {
          "description": "Description of tag",
          "type": "string",
          "minLength": 0,
          "maxLength": 65535
        }
      }
    },
    "DHCPServer": {
      "description": "DHCP Server configuration",
      "type": "object",
      "required": [
        "name",
        "enable",
        "netmask",
        "startIp",
        "endIp",
        "domainNameServers",
        "domainName",
        "leaseTime"
      ],
      "properties": {
        "available": {
          "readOnly": true,
          "type": "boolean",
          "description": "DHCP server is available or not (the interface must be \"static IP\"\nand/or worked as a WiFi AP), default should be false.\n"
        },
        "name": {
          "description": "Name of dhcp server",
          "type": "string",
          "minLength": 1,
          "maxLength": 255
        },
        "enable": {
          "description": "Enable dhcp server",
          "type": "boolean"
        },
        "netmask": {
          "description": "Netmask of dhcp server",
          "type": "string",
          "minLength": 7,
          "maxLength": 15
        },
        "startIp": {
          "description": "Range IP start",
          "type": "string",
          "minLength": 7,
          "maxLength": 15
        },
        "endIp": {
          "description": "Range IP end",
          "type": "string",
          "minLength": 7,
          "maxLength": 15
        },
        "domainNameServers": {
          "description": "Domain name servers",
          "type": "array",
          "items": {
            "type": "string",
            "minLength": 7,
            "maxLength": 15
          }
        },
        "domainName": {
          "description": "Domain name",
          "type": "string",
          "maxLength": 255
        },
        "leaseTime": {
          "description": "Lease time of dhcp pool",
          "type": "integer",
          "minimum": 60,
          "maximum": 65535
        }
      },
      "example": {
        "id": 1,
        "name": "eth0",
        "available": false,
        "enable": false,
        "subnet": "192.168.3.0",
        "netmask": "255.255.255.0",
        "startIp": "192.168.3.100",
        "endIp": "192.168.3.150",
        "domainNameServers": [
          "8.8.8.8",
          "1.1.1.1",
          "2.2.2.2"
        ],
        "domainName": "cloud5566",
        "leaseTime": "3600"
      }
    },
    "DHCPServerCollection": {
      "description": "Collection of DHCP Servers and overview status",
      "type": "object",
      "readOnly": true,
      "properties": {
        "status": {
          "description": "DHCP Server is enable or not",
          "type": "boolean"
        },
        "collection": {
          "description": "All of dhcp server instance config",
          "type": "array",
          "items": {
            "$ref": "#/definitions/DHCPServer"
          }
        }
      },
      "example": {
        "status": true,
        "collection": [
          {
            "id": 1,
            "name": "eth0",
            "available": false,
            "enable": false,
            "subnet": "192.168.3.0",
            "netmask": "255.255.255.0",
            "startIp": "192.168.3.100",
            "endIp": "192.168.3.150",
            "domainNameServers": [
              "8.8.8.8",
              "1.1.1.1",
              "2.2.2.2"
            ],
            "domainName": "cloud5566",
            "leaseTime": "3600"
          }
        ]
      }
    },
    "DNS": {
      "title": "DNS",
      "required": [
        "enableFixed"
      ],
      "properties": {
        "source": {
          "type": "string",
          "readOnly": true,
          "description": "The current dns corresponging source, may be a network interface or\n`fixed` for fixed DNS (readonly)\n"
        },
        "dns": {
          "type": "array",
          "items": {
            "type": "string",
            "pattern": "^(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)$"
          },
          "readOnly": true,
          "description": "Current DNS setting(s) (readonly)."
        },
        "enableFixed": {
          "type": "boolean",
          "description": "Using fixed DNS (true) or by interface (false), false if not given.\n"
        },
        "fixedDns": {
          "type": "array",
          "items": {
            "type": "string",
            "pattern": "^(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)$"
          },
          "description": "DNS settings if enableFixed is `true`.\n"
        }
      },
      "example": {
        "enableFixed": false,
        "fixedDns": [],
        "source": "eth0",
        "dns": [
          "8.8.8.8",
          "8.8.4.4"
        ]
      }
    },
    "Ethernet": {
      "title": "Ethernet",
      "required": [
        "id",
        "enable",
        "enableDhcp"
      ],
      "properties": {
        "id": {
          "type": "integer",
          "description": "Identifier of an Ethernet interface."
        },
        "enable": {
          "type": "boolean",
          "description": "Set interface UP."
        },
        "wan": {
          "type": "boolean",
          "description": "Define the interface type is WAN (`true`) or LAN (`false`)"
        },
        "name": {
          "type": "string",
          "readOnly": true,
          "description": "Indicate the interface name."
        },
        "enableDhcp": {
          "type": "boolean",
          "description": "Enable (`true`) the dhcp client or using the static IP (`false`)."
        },
        "ip": {
          "type": "string",
          "pattern": "^(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)$",
          "description": "IP address for the Ethernet interface."
        },
        "mac": {
          "type": "string",
          "readOnly": true,
          "description": "The identical MAC address."
        },
        "netmask": {
          "type": "string",
          "pattern": "^(254|252|248|240|224|192|128)\\.0\\.0\\.0|255\\.(254|252|248|240|224|192|128|0)\\.0\\.0|255\\.255\\.(254|252|248|240|224|192|128|0)\\.0|255\\.255\\.255\\.(254|252|248|240|224|192|128|0)",
          "description": "Subnet mask for the Ethernet interface."
        },
        "subnet": {
          "type": "string",
          "readOnly": true,
          "pattern": "^(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)$",
          "description": "A subnet (short for \"subnetwork\") is an identifiably separate part of\nan organization's network.\n"
        },
        "broadcast": {
          "type": "string",
          "readOnly": true,
          "pattern": "^(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)$",
          "description": "A broadcast address is a logical address at which all devices\nconnected to a multiple-access communications network are enabled\nto receive datagrams.\n"
        },
        "gateway": {
          "type": "string",
          "pattern": "^(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)$",
          "description": "Gateway is a router or a proxy server that routes between networks.\n"
        },
        "dns": {
          "type": "array",
          "items": {
            "type": "string",
            "pattern": "^(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)$"
          },
          "description": "The Domain Name System (DNS) is a hierarchical distributed naming\nsystem for computers, services, or any resource connected to the\nInternet or a private network.\n"
        },
        "status": {
          "type": "boolean",
          "readOnly": true,
          "description": "Current status for the Ethernet interface, `false` for down and `true` for up.\n"
        },
        "restart": {
          "type": "boolean",
          "readOnly": true,
          "description": "`true` means that view must be restarted after receiving the response.\n"
        }
      },
      "example": {
        "id": 1,
        "wan": true,
        "name": "eth0",
        "ip": "192.168.3.127",
        "mac": "FF:FF:FF:FF:FF:FF",
        "netmask": "255.255.255.0",
        "subnet": "192.168.3.0",
        "gateway": "192.168.3.254",
        "dns": [
          "8.8.8.8",
          "8.8.4.4"
        ],
        "status": true,
        "enable": true,
        "enableDhcp": false
      }
    },
    "UrlInfo": {
      "description": "Url information",
      "type": "object",
      "required": [
        "url"
      ],
      "properties": {
        "url": {
          "description": "Url address",
          "type": "string",
          "minLength": 1,
          "maxLength": 4096
        },
        "headers": {
          "description": "Headers",
          "type": "object"
        }
      },
      "example": {
        "url": "https://server/upload",
        "headers": {
          "accessToken": "MOXAMOXA-TEST-SYSTEM"
        }
      }
    },
    "ImportInfo": {
      "description": "Import information",
      "type": "object",
      "required": [
        "scopes",
        "file"
      ],
      "properties": {
        "file": {
          "$ref": "#/definitions/UrlInfo"
        },
        "scopes": {
          "description": "Import scopes (only selected scopes' configuration will be imported)",
          "type": "array",
          "items": {
            "type": "string",
            "enum": [
              "modbus",
              "time",
              "dns",
              "ethernet",
              "cellular",
              "openvpn",
              "dhcpd",
              "serial",
              "portforwarding",
              "remotecontrol",
              "program",
              "applications",
              "system"
            ]
          }
        }
      }
    },
    "LogProfile": {
      "title": "LogProfile",
      "required": [
        "name",
        "archiver",
        "uploader",
        "equipmentList"
      ],
      "properties": {
        "id": {
          "type": "integer",
          "readOnly": true
        },
        "enable": {
          "type": "boolean",
          "description": "Enable Log Profile",
          "default": true
        },
        "name": {
          "type": "string",
          "description": "Name of Log Profile",
          "pattern": "^[A-Za-z0-9_-]+$",
          "minLength": 2,
          "maxLength": 255
        },
        "archiver": {
          "$ref": "#/definitions/Archiver"
        },
        "uploader": {
          "$ref": "#/definitions/Uploader"
        },
        "equipmentList": {
          "type": "array",
          "description": "Collection of equipments using current Log Profile",
          "items": {
            "$ref": "#/definitions/LogEquipmentEntry"
          }
        }
      },
      "example": {
        "id": 1,
        "name": "log-profile-1",
        "enable": true,
        "archiver": {
          "destination": "Internal",
          "thresholdBytePerFile": 5242800,
          "directorySizeLimitByte": 10240000,
          "archivesToKeep": 24
        },
        "uploader": {
          "httpPost": {
            "url": "http://host/post",
            "enableAuth": false,
            "authentication": {
              "username": "uploader",
              "password": "password"
            },
            "headerList": [
              {
                "name": "Content-Type",
                "value": "application/json"
              },
              {
                "name": "User-Agent",
                "value": "Mozilla/5.0"
              }
            ],
            "bypassSsl": true,
            "cronExpr": "0 * * * *",
            "format": "json",
            "compress": "gzip",
            "enableCompress": true,
            "retryCount": 3,
            "retryPeriodSec": 3
          }
        },
        "equipmentList": [
          {
            "equipmentName": "My-ioLogik-E2242",
            "equipmentTags": [
              {
                "name": "di0",
                "logOnChange": false
              },
              {
                "name": "di1",
                "logOnChange": false
              },
              {
                "name": "ai0",
                "logOnChange": false
              }
            ]
          },
          {
            "equipmentName": "My-other-ioLogik-E2242",
            "equipmentTags": [
              {
                "name": "di0",
                "logOnChange": false
              },
              {
                "name": "di1",
                "logOnChange": false
              },
              {
                "name": "ai0",
                "logOnChange": false
              }
            ]
          }
        ]
      }
    },
    "Archiver": {
      "title": "Archiver",
      "type": "object",
      "description": "Archiver Options for Log Profile",
      "required": [
        "destination",
        "thresholdBytePerFile",
        "directorySizeLimitByte",
        "archivesToKeep"
      ],
      "properties": {
        "destination": {
          "description": "Archive files' place, refer to \"/mxc/logprofile/destination:name\"",
          "type": "string"
        },
        "thresholdBytePerFile": {
          "description": "Maximum size of an archive file (byte)",
          "type": "integer",
          "minimum": 1048576
        },
        "directorySizeLimitByte": {
          "description": "Maximum archive folder size (byte)",
          "type": "integer",
          "minimum": 10240
        },
        "archivesToKeep": {
          "description": "Maximum count of archive files",
          "type": "integer",
          "minimum": 1,
          "maximum": 1000
        }
      }
    },
    "DestinationEntry": {
      "title": "DestinationEntry",
      "description": "Archive files' place could be set to",
      "type": "object",
      "required": [
        "name",
        "directory"
      ],
      "properties": {
        "name": {
          "description": "destination name",
          "type": "string"
        },
        "directory": {
          "description": "Archive files' path",
          "type": "string"
        }
      }
    },
    "Uploader": {
      "title": "Uploader",
      "description": "Uploader Options for Log Profile",
      "type": "object",
      "required": [
        "httpPost"
      ],
      "properties": {
        "httpPost": {
          "type": "object",
          "required": [
            "url",
            "enableAuth",
            "authentication",
            "bypassSsl",
            "cronExpr",
            "format",
            "compress",
            "enableCompress",
            "retryCount",
            "retryPeriodSec"
          ],
          "properties": {
            "url": {
              "description": "Upload url",
              "type": "string"
            },
            "enableAuth": {
              "description": "Enable HTTP Basic Authication",
              "type": "boolean"
            },
            "authentication": {
              "type": "object",
              "required": [
                "username",
                "password"
              ],
              "properties": {
                "username": {
                  "description": "Username for HTTP Basic Authication",
                  "type": "string"
                },
                "password": {
                  "description": "Password of HTTP Basic Authication",
                  "type": "string"
                }
              }
            },
            "headerList": {
              "description": "HTTP/HTTPS headers list",
              "type": "array",
              "items": {
                "type": "object",
                "required": [
                  "name",
                  "value"
                ],
                "properties": {
                  "name": {
                    "description": "Name of headers",
                    "type": "string"
                  },
                  "value": {
                    "description": "Value of headers",
                    "type": "string"
                  }
                }
              }
            },
            "bypassSsl": {
              "description": "Bypass SSL certificate",
              "type": "boolean"
            },
            "cronExpr": {
              "description": "Schedule upload (use cron format)",
              "type": "string"
            },
            "format": {
              "description": "Type of upload file format (supports: json, csv, xml)",
              "type": "string",
              "enum": [
                "json",
                "csv",
                "xml"
              ]
            },
            "compress": {
              "description": "Compress Algorithm (supports: gzip)",
              "type": "string",
              "enum": [
                "gzip"
              ]
            },
            "enableCompress": {
              "description": "Enable compress",
              "type": "boolean"
            },
            "retryCount": {
              "description": "Upload retry count",
              "type": "integer"
            },
            "retryPeriodSec": {
              "description": "Upload retry period (seconds)",
              "type": "integer"
            }
          }
        }
      }
    },
    "LogEquipmentEntry": {
      "title": "Equipment Entry",
      "description": "Device Tags Options for Log Profile",
      "type": "object",
      "required": [
        "equipmentName",
        "equipmentTags"
      ],
      "properties": {
        "equipmentName": {
          "description": "Name of equipment",
          "type": "string"
        },
        "equipmentTags": {
          "description": "Equipment Tags List",
          "type": "array",
          "items": {
            "type": "object",
            "required": [
              "name",
              "logOnChange"
            ],
            "properties": {
              "name": {
                "description": "Name of tag",
                "type": "string"
              },
              "logOnChange": {
                "description": "Enable log on change",
                "type": "boolean"
              }
            }
          }
        }
      }
    },
    "LogListEquipment": {
      "title": "Equipment",
      "description": "Equipment object",
      "type": "object",
      "required": [
        "equipmentType",
        "equipmentName",
        "equipmentTags"
      ],
      "properties": {
        "equipmentType": {
          "description": "Type of equipment",
          "type": "string",
          "enum": [
            "modbus",
            "user",
            "system"
          ]
        },
        "equipmentName": {
          "description": "Name of equipment",
          "type": "string",
          "minLength": 1,
          "maxLength": 255
        },
        "equipmentTags": {
          "description": "Tag List of equipment",
          "type": "array",
          "items": {
            "$ref": "#/definitions/LogListEquipmentTag"
          }
        }
      }
    },
    "LogListEquipmentTag": {
      "title": "Tag",
      "description": "Equipment's tag entry",
      "type": "object",
      "required": [
        "name",
        "dataType",
        "access",
        "size",
        "description"
      ],
      "properties": {
        "name": {
          "description": "Name of tag",
          "type": "string",
          "minLength": 1,
          "maxLength": 255
        },
        "dataType": {
          "description": "Data type of tag",
          "type": "string",
          "enum": [
            "boolean",
            "uint16",
            "uint32",
            "uint64",
            "int16",
            "int32",
            "int64",
            "float32",
            "float64",
            "string",
            "bytearray"
          ]
        },
        "access": {
          "description": "Access type of tag",
          "type": "string",
          "enum": [
            "ro",
            "wo",
            "rw"
          ]
        },
        "size": {
          "description": "Size of tag in byte",
          "type": "integer"
        },
        "description": {
          "description": "Description of tag",
          "type": "string",
          "minLength": 0,
          "maxLength": 4096
        }
      }
    },
    "ModbusSlave": {
      "title": "ModbusSlave",
      "required": [
        "enable",
        "port"
      ],
      "properties": {
        "enable": {
          "type": "boolean",
          "description": "Enable/Disable ModbusSlave function"
        },
        "host": {
          "type": "string",
          "description": "IP or Hostname of Modbus Slave",
          "pattern": "^[A-Za-z0-9._-]+$"
        },
        "port": {
          "type": "integer",
          "description": "Port number of Modbus Slave"
        },
        "unitId": {
          "type": "integer",
          "description": "Modbus Device ID (default 0xFF for Modbus-TCP)",
          "pattern": "^([0-9]|[1-9][0-9]|1[0-9]{2}|2[0-3][0-9]|24[0-7]|255)$"
        },
        "ignoreUnitId": {
          "type": "boolean",
          "description": "Ignore Unit ID"
        },
        "anyHost": {
          "type": "boolean",
          "description": "Bind Modbus Slave at any network interface"
        }
      },
      "example": {
        "enable": true,
        "host": "0.0.0.0",
        "port": 502,
        "unitId": 255,
        "ignoreUnitId": false,
        "anyHost": true
      }
    },
    "MappingEntry": {
      "title": "MappingEntry",
      "required": [
        "reference",
        "quantity",
        "equipmentName",
        "equipmentType",
        "tagName"
      ],
      "properties": {
        "id": {
          "type": "integer",
          "description": "Identity for MappingEntry"
        },
        "reference": {
          "type": "string",
          "description": "Modbus access address (or offset)",
          "pattern": "^(0x[0134][0-9A-Fa-f]{4})$"
        },
        "quantity": {
          "type": "integer",
          "description": "Modbus access quantity"
        },
        "equipmentName": {
          "type": "string",
          "description": "Equipment Name of Tag",
          "pattern": "^[A-Za-z0-9_-]+$",
          "minLength": 3,
          "maxLength": 255
        },
        "equipmentType": {
          "type": "string",
          "description": "Type of Tag"
        },
        "tagName": {
          "type": "string",
          "description": "Tag Name of Tag",
          "pattern": "[A-Za-z0-9_-]+",
          "minLength": 2,
          "maxLength": 255
        }
      },
      "example": {
        "id": 1,
        "reference": "0x40000",
        "quantity": 1,
        "equipmentName": "My_ioLogik-E2242",
        "equipmentType": "modbus",
        "tagName": "ai0"
      }
    },
    "OpenVPN": {
      "title": "OpenVPN",
      "required": [
        "enable"
      ],
      "properties": {
        "enable": {
          "type": "boolean",
          "description": "Enable OpenVPN service."
        },
        "ovpnFileExist": {
          "type": "boolean",
          "description": "When OpenVPN configuration file is uploaded, set true.",
          "readOnly": true
        },
        "connection": {
          "type": "boolean",
          "description": "When OpenVPN client is connected to server, set true.",
          "readOnly": true
        },
        "vpnRemoteIp": {
          "type": "string",
          "description": "IP of OpenVPN server.",
          "readOnly": true
        },
        "vpnLocalIp": {
          "type": "string",
          "description": "IP of OpenVPN client.",
          "readOnly": true
        }
      },
      "example": {
        "enable": true,
        "ovpnFileExist": true,
        "connection": true,
        "vpnRemoteIp": "10.9.8.1",
        "vpnLocalIp": "10.9.8.2"
      }
    },
    "OpenVPNConfig": {
      "title": "OpenVPNConfig",
      "required": [
        "file"
      ],
      "properties": {
        "file": {
          "required": [
            "url",
            "headers"
          ],
          "properties": {
            "url": {
              "type": "string"
            },
            "headers": {
              "type": "object"
            }
          }
        }
      },
      "example": {
        "file": {
          "url": "http://192.168.31.113:18080/url",
          "headers": {
            "X-Mx-AccessToken": "MOXAMOXA-TEST-SYSTEM"
          }
        }
      }
    },
    "OpenVPNPostConfig": {
      "title": "OpenVPNPostConfig",
      "required": [
        "url",
        "headers"
      ],
      "properties": {
        "url": {
          "type": "string"
        },
        "headers": {
          "type": "object"
        }
      },
      "example": {
        "url": "http://192.168.31.113:18080/url",
        "headers": {
          "X-Mx-AccessToken": "MOXAMOXA-TEST-SYSTEM"
        }
      }
    },
    "OpenVPNConfigURL": {
      "title": "OpenVPNConfigURL",
      "required": [
        "url"
      ],
      "properties": {
        "url": {
          "type": "string"
        }
      },
      "example": {
        "url": "http://192.168.31.113:18080/url"
      }
    },
    "Programs": {
      "type": "array",
      "items": {
        "$ref": "#/definitions/Program"
      },
      "example": {
        "id": 1,
        "name": "my-user-program",
        "enable": true,
        "startMode": "period",
        "args": "--url http://localhost",
        "period": 10,
        "timeout": 1,
        "lastExcutedTime": "2017-01-09T06:46:01.181Z",
        "fileExist": true,
        "logsExist": true,
        "file": {
          "url": "http://remote-download-url/file.tar.gz",
          "headers": {
            "authorization": "xxxxxxx"
          }
        }
      }
    },
    "Program": {
      "type": "object",
      "properties": {
        "id": {
          "type": "number",
          "readOnly": true,
          "description": "ID of this program"
        },
        "name": {
          "type": "string",
          "description": "Program name",
          "maxLength": 255,
          "minLength": 2,
          "pattern": "^[A-Za-z0-9_-]+$"
        },
        "enable": {
          "type": "boolean",
          "description": "Enable program"
        },
        "startMode": {
          "type": "string",
          "description": "Program start mode",
          "enum": [
            "boot",
            "period"
          ]
        },
        "args": {
          "type": "string",
          "description": "arguments",
          "minLength": 0,
          "maxLength": 2048
        },
        "period": {
          "type": "number",
          "description": "Period execution time (unit minutes)",
          "minimum": 0,
          "maximum": 65535
        },
        "timeout": {
          "type": "number",
          "description": "execution timeout (in seconds, 0 means no timeout)",
          "minimum": 0,
          "maximum": 65535
        },
        "lastExcutedTime": {
          "type": "string",
          "format": "date-time",
          "readOnly": true,
          "description": "Last program has been excuted time (iso 8601)"
        },
        "fileExist": {
          "type": "boolean",
          "readOnly": true,
          "description": "User program uploaded or not"
        },
        "logsExist": {
          "type": "boolean",
          "readOnly": true,
          "description": "Logs avaliable for download or not"
        }
      },
      "example": {
        "id": 1,
        "name": "my-user-program",
        "enable": true,
        "startMode": "period",
        "args": "--url http://localhost",
        "period": 10,
        "timeout": 1,
        "lastExcutedTime": "2017-01-09T06:46:01.181Z",
        "fileExist": true,
        "logsExist": true,
        "file": {
          "url": "http://remote-download-url/file.tar.gz",
          "headers": {
            "authorization": "xxxxxxx"
          }
        }
      }
    },
    "UpdateProgram": {
      "allOf": [
        {
          "$ref": "#/definitions/Program"
        },
        {
          "$ref": "#/definitions/Upload"
        }
      ]
    },
    "Upload": {
      "type": "object",
      "properties": {
        "file": {
          "type": "object",
          "properties": {
            "url": {
              "type": "string",
              "description": "Download link"
            },
            "header": {
              "type": "object",
              "description": "Headers for download link"
            }
          }
        }
      }
    },
    "Download": {
      "required": [
        "url"
      ],
      "properties": {
        "url": {
          "type": "string"
        },
        "headers": {
          "type": "object"
        }
      },
      "example": {
        "url": "http://download/file"
      }
    },
    "RemoteControl": {
      "description": "Remote control configuration",
      "type": "object",
      "required": [
        "remoteHost",
        "remotePort",
        "psk",
        "enable"
      ],
      "properties": {
        "deviceUUID": {
          "description": "A unique id given by ThingsPro Cloud Server (format in UUIDv4)",
          "type": "string"
        },
        "keepalive": {
          "description": "Keepalive interval for remote connection, each heartbeat packet costs 2 bytes"
        },
        "remoteHost": {
          "description": "ThingsPro Cloud Server Host / IP address",
          "type": "string"
        },
        "remotePort": {
          "description": "ThingsPro Cloud Server Port",
          "type": "number",
          "minLength": 1,
          "maxLength": 65535
        },
        "remoteProtocol": {
          "description": "This is a reversed key.",
          "type": "string",
          "readOnly": true
        },
        "psk": {
          "description": "Pre-shared key for remote control service",
          "type": "string"
        },
        "enable": {
          "description": "Enable remote control or not",
          "type": "boolean"
        }
      },
      "example": {
        "enable": true,
        "deviceUUID": "f71b4639-d7bb-4fc3-9ee6-c8d08d47f227",
        "keepalive": 60,
        "remoteHost": "moxa.thingspro.local",
        "remotePort": 8080,
        "remoteProtocol": "mqtt",
        "psk": "123sdlkfjasldkfjoasdfjioawjerioqwejrasdfjoi2345klscv"
      }
    },
    "TestResult": {
      "description": "Remote control test result",
      "type": "object",
      "properties": {
        "status": {
          "description": "success or error",
          "type": "string"
        },
        "log": {
          "description": "Detail of testing log",
          "type": "string"
        }
      },
      "example": {
        "status": "success",
        "log": "connected to xxxx"
      }
    },
    "DefaultRoute": {
      "title": "DefaultRoute",
      "required": [
        "interface"
      ],
      "properties": {
        "interface": {
          "type": "string",
          "readOnly": true,
          "description": "Indicate the interface name (readonly)."
        },
        "gateway": {
          "type": "string",
          "pattern": "^(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)$",
          "readOnly": true,
          "description": "Gateway is a router or a proxy server that routes between networks\n(readonly).\n"
        },
        "priorityList": {
          "type": "array",
          "items": {
            "description": "interface for default route",
            "type": "string",
            "pattern": "[A-Za-z0-9_-]+",
            "minLength": 2,
            "maxLength": 255
          }
        }
      },
      "example": {
        "interface": "eth0",
        "gateway": "192.168.3.254",
        "priorityList": [
          "wwan0",
          "eth0"
        ]
      }
    },
    "Serial": {
      "description": "Serial interface configuration",
      "type": "object",
      "required": [
        "mode"
      ],
      "properties": {
        "id": {
          "description": "ID of serial interface",
          "type": "integer",
          "readOnly": true
        },
        "dev": {
          "description": "Serial interface physical path",
          "type": "string",
          "readOnly": true,
          "minLength": 1,
          "maxLength": 1024
        },
        "devDisplayName": {
          "description": "Display name of serial interface",
          "readOnly": true,
          "type": "string"
        },
        "mode": {
          "description": "Mode of serial interface",
          "type": "string",
          "enum": [
            "rs232",
            "rs485-2w",
            "rs422/rs485-4w"
          ]
        }
      },
      "example": {
        "id": 1,
        "dev": "/dev/ttyM0",
        "devDisplayName": "PORT-1",
        "mode": "rs232"
      }
    },
    "Serials": {
      "description": "Collection of serial interfaces",
      "type": "array",
      "items": {
        "$ref": "#/definitions/Serial"
      },
      "example": [
        {
          "id": 1,
          "dev": "/dev/ttyM0",
          "devDisplayName": "PORT-1",
          "mode": "rs232"
        },
        {
          "id": 2,
          "dev": "/dev/ttyM1",
          "devDisplayName": "PORT-2",
          "mode": "rs485-2w"
        },
        {
          "id": 3,
          "dev": "/dev/ttyM2",
          "devDisplayName": "PORT 3",
          "mode": "rs422/rs485-4w"
        }
      ]
    },
    "Service": {
      "description": "Service status / configuration",
      "type": "object",
      "required": [
        "enable"
      ],
      "properties": {
        "id": {
          "description": "Service ID",
          "type": "integer",
          "readOnly": true
        },
        "enable": {
          "description": "Enable/Disable service",
          "type": "boolean"
        },
        "name": {
          "description": "Name of service",
          "type": "string",
          "readOnly": true
        },
        "status": {
          "description": "Current status of service",
          "type": "string",
          "readOnly": true
        }
      },
      "example": {
        "id": 1,
        "enable": true,
        "name": "ssh",
        "status": true
      }
    },
    "SystemStatus": {
      "description": "System status",
      "type": "object",
      "properties": {
        "hostname": {
          "description": "Hostname",
          "type": "string",
          "minLength": 1,
          "maxLength": 63,
          "pattern": "/^(?![0-9]+$)(?!.*-$)(?!-)[a-zA-Z0-9-]{1,63}$/"
        },
        "version": {
          "description": "Version of system",
          "type": "string",
          "readOnly": true
        },
        "uptimeSec": {
          "description": "System uptime (unit: seconds)",
          "type": "string",
          "readOnly": true
        },
        "cpuUsage": {
          "description": "CPU usage (in percentage)",
          "type": "number",
          "readOnly": true
        },
        "memoryUsage": {
          "description": "System memory usage (in percentage)",
          "type": "number",
          "readOnly": true
        },
        "memory": {
          "description": "System total memory (unit: byte)",
          "type": "integer",
          "readOnly": true
        },
        "disks": {
          "type": "array",
          "readOnly": true,
          "items": {
            "$ref": "#/definitions/Disk"
          }
        }
      },
      "example": {
        "hostname": "Moxa",
        "version": "1.1.0-1",
        "uptimeSec": 312956,
        "cpuUsage": 5.7,
        "memoryUsage": 63.8,
        "memory": 257286144,
        "disks": [
          {
            "name": "system",
            "mount": "/",
            "device": "rootfs",
            "usage": {
              "total": 770695168,
              "used": 497655808,
              "free": 217038848,
              "percent": 64.6
            }
          },
          {
            "name": "sd1",
            "mount": "/media/sd-mmcblk1p1",
            "device": "/dev/mmcblk1p1",
            "usage": {
              "total": 770695168,
              "used": 497655808,
              "free": 217038848,
              "percent": 64.6
            }
          }
        ]
      }
    },
    "Disk": {
      "description": "Disk information",
      "type": "object",
      "readOnly": true,
      "properties": {
        "name": {
          "description": "Disk alias",
          "type": "string",
          "readOnly": true
        },
        "mount": {
          "description": "Mount point",
          "type": "string",
          "readOnly": true
        },
        "device": {
          "description": "Physical device node path",
          "type": "string",
          "readOnly": true
        },
        "usage": {
          "description": "Usage of this disk",
          "type": "object",
          "readOnly": true,
          "properties": {
            "total": {
              "description": "Total size (unit: byte)",
              "type": "integer",
              "readOnly": true
            },
            "used": {
              "description": "Used size (unit: byte)",
              "type": "integer",
              "readOnly": true
            },
            "free": {
              "description": "Free size (unit: byte)",
              "type": "integer",
              "readOnly": true
            },
            "percent": {
              "description": "Percent of used size",
              "type": "number",
              "readOnly": true
            }
          }
        }
      }
    },
    "NetworkInterfaces": {
      "description": "Network Interfaces",
      "type": "array",
      "items": {
        "type": "string"
      },
      "example": {
        "url": "https://server/upload",
        "headers": {
          "accessToken": "MOXAMOXA-TEST-SYSTEM"
        }
      }
    },
    "SystemPassword": {
      "description": "System Password",
      "required": [
        "password"
      ],
      "type": "object",
      "properties": {
        "password": {
          "description": "password",
          "type": "string",
          "minLength": 4,
          "maxLength": 255
        }
      },
      "example": {
        "passowrd": "thisisyourpassword"
      }
    },
    "SystemProperties": {
      "description": "System Properties",
      "type": "object",
      "properties": {
        "aliasName": {
          "description": "Alias name of this device",
          "type": "string",
          "maxLength": 255,
          "default": "MOXA IoT Gateway"
        },
        "gps": {
          "description": "GPS location information",
          "type": "object",
          "required": [
            "lat",
            "lng"
          ],
          "properties": {
            "lat": {
              "type": "number",
              "format": "float",
              "description": "latitude",
              "default": 0
            },
            "lng": {
              "type": "number",
              "format": "float",
              "description": "longitude",
              "default": 0
            }
          }
        }
      },
      "example": {
        "gps": {
          "lat": 121.123,
          "lng": 22.456
        },
        "aliasName": "my iot gateway"
      }
    },
    "SystemPropertiesUpdate": {
      "description": "Request payload for updating system property",
      "type": "object",
      "required": [
        "data"
      ],
      "properties": {
        "data": {
          "type": "object",
          "allOf": [
            {
              "$ref": "#/definitions/SystemProperties/properties/aliasName"
            },
            {
              "$ref": "#/definitions/SystemProperties/properties/gps"
            }
          ]
        }
      },
      "example": {
        "data": {
          "lat": 121.123,
          "lng": 22.456
        }
      }
    },
    "Equipments": {
      "description": "system tags",
      "type": "array",
      "items": {
        "type": "object",
        "required": [
          "equipmentName",
          "equipmentTags"
        ],
        "properties": {
          "equipmentName": {
            "description": "equipment name of tags",
            "type": "string",
            "minLength": 3,
            "maxLength": 255
          },
          "equipmentTags": {
            "description": "list of tags",
            "type": "array",
            "items": {
              "type": "object",
              "required": [
                "name",
                "dataType",
                "access",
                "size",
                "description"
              ],
              "properties": {
                "name": {
                  "description": "Name of tag",
                  "type": "string",
                  "minLength": 1,
                  "maxLength": 255
                },
                "dataType": {
                  "description": "Data type of tag",
                  "type": "string",
                  "enum": [
                    "boolean",
                    "uint16",
                    "uint32",
                    "uint64",
                    "int16",
                    "int32",
                    "int64",
                    "float32",
                    "float64",
                    "string",
                    "bytearray"
                  ]
                },
                "access": {
                  "description": "Access type of tag",
                  "type": "string",
                  "enum": [
                    "ro",
                    "wo",
                    "rw"
                  ]
                },
                "size": {
                  "description": "Size of tag in byte",
                  "type": "integer"
                },
                "description": {
                  "description": "Description of tag",
                  "type": "string",
                  "minLength": 0,
                  "maxLength": 4096
                }
              }
            }
          }
        }
      }
    },
    "Time": {
      "description": "Time configuration",
      "type": "object",
      "properties": {
        "time": {
          "description": "Current system time (format: iso 8601)",
          "type": "string"
        },
        "timezone": {
          "description": "Current timezone",
          "type": "string"
        },
        "ntp": {
          "$ref": "#/definitions/NTP"
        }
      },
      "example": {
        "time": "2015-03-26T16:27:48.611441Z",
        "timezone": "Asia/Taipei",
        "ntp": {
          "enable": true,
          "server": "pool.ntp.org",
          "interval": 86400
        }
      }
    },
    "NTP": {
      "description": "NTP configuration",
      "type": "object",
      "required": [
        "enable",
        "server",
        "interval"
      ],
      "properties": {
        "enable": {
          "description": "Enable NTP client",
          "type": "boolean"
        },
        "server": {
          "description": "Target NTP server",
          "type": "string",
          "minLength": 1,
          "maxLength": 2048
        },
        "interval": {
          "description": "Time sync interval in seconds (at least: 60 seconds.)",
          "type": "integer",
          "minimum": 60,
          "maximum": 2592000
        }
      },
      "example": {
        "enable": false,
        "server": "pool.ntp.org",
        "interval": 86400
      }
    },
    "Timezone": {
      "description": "Timezone information",
      "type": "object",
      "required": [
        "zone",
        "iso3166"
      ],
      "properties": {
        "zone": {
          "description": "TZ zone list with cca2 and TZ",
          "readOnly": true,
          "type": "array",
          "items": {
            "$ref": "#/definitions/TimezoneZone"
          }
        },
        "iso3166": {
          "description": "ISO 3166 alpha-2 country codes",
          "readOnly": true,
          "type": "array",
          "items": {
            "$ref": "#/definitions/TimezoneIso3166"
          }
        }
      },
      "example": {
        "zone": [
          {
            "cca2": "AD",
            "name": "Europe/Andorra",
            "offset": "+0100"
          },
          {
            "cca2": "AE",
            "name": "Asia/Dubai",
            "offset": "+0400"
          },
          {
            "cca2": "AF",
            "name": "Asia/Kabul",
            "offset": "+0430"
          }
        ],
        "iso3166": [
          {
            "cca2": "AD",
            "name": "Andorra"
          },
          {
            "cca2": "AE",
            "name": "United Arab Emirates"
          },
          {
            "cca2": "AF",
            "name": "Afghanistan"
          }
        ]
      }
    },
    "TimezoneZone": {
      "description": "ISO 3166 alpha-2 country code and zone name",
      "type": "object",
      "required": [
        "cca2",
        "name",
        "offset"
      ],
      "properties": {
        "cca2": {
          "description": "ISO 3166 alpha-2 country code",
          "type": "string",
          "pattern": "[A-Z]{2}"
        },
        "name": {
          "description": "zone name",
          "type": "string"
        },
        "offset": {
          "description": "zone offset (format should be \"+0800\", etc)",
          "type": "string"
        }
      }
    },
    "TimezoneIso3166": {
      "description": "ISO 3166 alpha-2 country code and country name",
      "type": "object",
      "required": [
        "cca2",
        "name"
      ],
      "properties": {
        "cca2": {
          "description": "ISO 3166 alpha-2 country code",
          "type": "string",
          "pattern": "[A-Z]{2}"
        },
        "name": {
          "description": "The usual English name for the coded region",
          "type": "string"
        }
      }
    },
    "FirmwareInfo": {
      "description": "Firmware Info",
      "type": "object",
      "required": [
        "file"
      ],
      "properties": {
        "delay": {
          "description": "Delay time in seconds before execute the upgrading process",
          "type": "integer"
        },
        "file": {
          "description": "Remote firmware meta data",
          "type": "object",
          "required": [
            "url",
            "physicalPath"
          ],
          "properties": {
            "url": {
              "description": "URL for downloading firmware",
              "type": "string",
              "minLength": 1,
              "maxLength": 4096
            },
            "physicalPath": {
              "description": "File's physical path on machine",
              "type": "string",
              "minLength": 1,
              "maxLength": 4096
            },
            "headers": {
              "description": "Headers for downloading firmware if necessary",
              "type": "object"
            }
          }
        }
      },
      "example": {
        "delay": 3,
        "file": {
          "url": "http://192.168.31.81:5000/api/v1/download/1234",
          "headers": {
            "accessToken": "MOXAMOXA-TEST-SYSTEM"
          }
        }
      }
    },
    "WiFiIface": {
      "title": "WiFi Interface",
      "required": [
        "id",
        "enable",
        "mode"
      ],
      "properties": {
        "id": {
          "type": "integer",
          "description": "Identifier for an WiFi interface."
        },
        "name": {
          "type": "string",
          "description": "Interface name."
        },
        "product": {
          "type": "string",
          "description": "Product model of the WiFi module."
        },
        "mode": {
          "type": "string",
          "description": "Given WiFi interface mode. Could be one of `\"ap\"`, `\"client\"`."
        },
        "capabilities": {
          "type": "array",
          "description": "Indicate current capability that module supports.",
          "items": {
            "type": "string",
            "enum": [
              "ap",
              "client"
            ]
          }
        },
        "enable": {
          "type": "boolean",
          "description": "Enable WiFi Networking."
        },
        "ap": {
          "type": "object",
          "description": "Configuration of WiFi AP mode.",
          "required": [
            "mode",
            "ssid",
            "channel",
            "security"
          ],
          "properties": {
            "enableBlacklist": {
              "type": "boolean",
              "description": "Using blacklist or not."
            },
            "mode": {
              "type": "string",
              "enum": [
                "bg",
                "bgn",
                "ac"
              ]
            },
            "ssid": {
              "type": "string",
              "description": "SSID of a WiFi AP."
            },
            "channel": {
              "type": "integer"
            },
            "security": {
              "type": "object",
              "required": [
                "mode"
              ],
              "properties": {
                "mode": {
                  "type": "string",
                  "enum": [
                    "none",
                    "wpa",
                    "wpa2",
                    "wpa/wpa2",
                    "eap"
                  ]
                },
                "encryption": {
                  "type": "string",
                  "enum": [
                    "tkip",
                    "aes",
                    "tkip/aes"
                  ]
                },
                "password": {
                  "type": "string",
                  "description": "ASCII passphrase (8 ~ 63) or HEX pre-shared key (64) for WPA-Personal, or password for Radius."
                },
                "radiusServerIp": {
                  "type": "string",
                  "pattern": "^(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)$"
                },
                "radiusServerPort": {
                  "type": "integer",
                  "minimum": 1,
                  "maximum": 65535
                },
                "radiusSharedSecret": {
                  "type": "string"
                }
              }
            },
            "broadcastSsid": {
              "type": "boolean"
            },
            "shortPreamble": {
              "type": "boolean"
            },
            "beacon": {
              "type": "integer"
            },
            "ip": {
              "type": "string",
              "pattern": "^(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)$",
              "description": "IP address."
            },
            "netmask": {
              "type": "string",
              "pattern": "^(254|252|248|240|224|192|128)\\.0\\.0\\.0|255\\.(254|252|248|240|224|192|128|0)\\.0\\.0|255\\.255\\.(254|252|248|240|224|192|128|0)\\.0|255\\.255\\.255\\.(254|252|248|240|224|192|128|0)",
              "description": "Subnet mask."
            }
          }
        },
        "client": {
          "type": "object",
          "description": "Configuration of WiFi client mode",
          "required": [
            "enableDhcp",
            "networks",
            "checkalive"
          ],
          "properties": {
            "enableDhcp": {
              "type": "boolean",
              "description": "Enable (`true`) the dhcp client or using the static IP (`false`).\n"
            },
            "networks": {
              "type": "array",
              "description": "List of networks for WiFi client to connect.",
              "items": {
                "type": "object",
                "description": "A WiFi AP configuration.",
                "required": [
                  "ssid"
                ],
                "properties": {
                  "priority": {
                    "description": "This field can be used to give higher priority for credentials\t(and similarly in struct wpa_ssid for network blocks) to change the\tInterworking automatic networking selection behavior. Default is `0`.",
                    "type": "integer"
                  },
                  "ssid": {
                    "type": "string",
                    "description": "SSID of a WiFi AP."
                  },
                  "bssid": {
                    "type": "string",
                    "description": "BSSID (MAC) of a WiFi AP."
                  },
                  "security": {
                    "description": "Security of the WiFi AP.",
                    "type": "string",
                    "enum": [
                      "none",
                      "wep",
                      "wpa",
                      "wpa2",
                      "wpa/wpa2",
                      "eap"
                    ]
                  },
                  "password": {
                    "type": "string",
                    "description": "Password of access point, Could be one of 1. WEP key. Length 5, 13, 16, 29 for ASCII keys or 10, 26, 32, 58 for HEX keys. 2. WPA-PSK key. ASCII passphrase (8 ~ 63) or HEX pre-shared key (64). 3. EAP key. Max length 64"
                  },
                  "username": {
                    "type": "string",
                    "description": "Username for EAP (Enterprise Access Point).",
                    "maxLength": 64
                  }
                }
              }
            },
            "ip": {
              "type": "string",
              "pattern": "^(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)$",
              "description": "IP address. `\"\"` when not connected."
            },
            "netmask": {
              "type": "string",
              "pattern": "^(254|252|248|240|224|192|128)\\.0\\.0\\.0|255\\.(254|252|248|240|224|192|128|0)\\.0\\.0|255\\.255\\.(254|252|248|240|224|192|128|0)\\.0|255\\.255\\.255\\.(254|252|248|240|224|192|128|0)",
              "description": "Subnet mask. `\"\"` when not connected."
            },
            "gateway": {
              "type": "string",
              "pattern": "^(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)$",
              "description": "Gateway IP address. `\"\"` when not connected."
            },
            "dns": {
              "type": "array",
              "description": "A list of DNS IP addresses. `[]` when not connected.",
              "items": {
                "type": "string",
                "pattern": "^(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)$"
              }
            },
            "usage": {
              "type": "object",
              "description": "Data usage.",
              "required": [
                "txkbyte",
                "rxkbyte"
              ],
              "properties": {
                "txkbyte": {
                  "type": "integer",
                  "description": "Amount of data transmitted, in Kbytes."
                },
                "rxkbyte": {
                  "type": "integer",
                  "description": "Amount of data received, in Kbytes."
                }
              }
            },
            "checkalive": {
              "type": "object",
              "description": "Keep-alive configuration.",
              "required": [
                "enable"
              ],
              "properties": {
                "enable": {
                  "type": "boolean",
                  "description": "Enable/disable WiFi connection keep-alive by ping."
                },
                "targetHost": {
                  "type": "string",
                  "description": "IP address to ping."
                },
                "intervalSec": {
                  "type": "integer",
                  "description": "Check alive interval."
                }
              }
            }
          }
        }
      },
      "example": {
        "id": 1,
        "name": "wlan0",
        "product": "WPEQ-353ACNI",
        "capabilities": [
          "client",
          "ap"
        ],
        "mode": "client",
        "enable": true,
        "status": true,
        "client": {
          "enableDhcp": true,
          "networks": [
            {
              "ssid": "test-none",
              "security": "none"
            },
            {
              "ssid": "test-wpa",
              "security": "wpa",
              "password": "12345678",
              "priority": 5
            },
            {
              "ssid": "test-eap",
              "security": "eap",
              "username": "moxa",
              "password": "moxa",
              "priority": 10
            },
            {
              "ssid": "test-wep",
              "security": "wep",
              "password": "12345",
              "priority": 1
            }
          ],
          "signal": 100,
          "ip": "111.70.146.125",
          "netmask": "255.255.255.252",
          "gateway": "111.70.146.126",
          "dns": [
            "168.95.1.1",
            "168.95.192.1"
          ],
          "usage": {
            "txkbyte": 40023,
            "rxkbyte": 3493
          },
          "checkalive": {
            "enable": true,
            "targetHost": "8.8.8.8",
            "intervalSec": 60
          }
        },
        "ap": {
          "mode": "bg",
          "ssid": "moxa-test",
          "channel": 11,
          "security": {
            "mode": "none"
          }
        }
      }
    },
    "WiFiIfaceBlacklist": {
      "title": "Blacklist Item for WiFi AP Interface",
      "required": [
        "id",
        "mac"
      ],
      "properties": {
        "id": {
          "type": "integer",
          "description": "Identifier for an WiFi AP blacklist MAC."
        },
        "mac": {
          "type": "string",
          "description": "A MAC address."
        },
        "description": {
          "type": "string",
          "description": "Description of the MAC address."
        }
      }
    },
    "WiFiAP": {
      "title": "WiFi AP Information",
      "required": [
        "bssid",
        "ssid"
      ],
      "properties": {
        "bssid": {
          "type": "string",
          "description": "BSSID (MAC) of a WiFi AP",
          "readOnly": true
        },
        "ssid": {
          "type": "string",
          "description": "SSID of a WiFi AP.",
          "readOnly": true
        },
        "frequency": {
          "type": "string",
          "description": "Frequency of a WiFi AP.",
          "readOnly": true
        },
        "signal": {
          "type": "integer",
          "description": "Signal of a WiFi AP (in dBm).",
          "readOnly": true
        },
        "security": {
          "type": "integer",
          "description": "Security mode of a WiFi AP (in dBm).",
          "enum": [
            "none",
            "wpa",
            "wpa2",
            "wpa/wpa2",
            "eap"
          ],
          "readOnly": true
        }
      }
    },
    "EquipmentTemplate": {
      "title": "Equipment Template",
      "type": "object",
      "required": [
        "name",
        "tagList"
      ],
      "properties": {
        "id": {
          "description": "ID of equipment template",
          "type": "integer"
        },
        "name": {
          "description": "Name of equipment template",
          "type": "string",
          "pattern": "[A-Za-z0-9_-]+",
          "minLength": 3,
          "maxLength": 255
        },
        "tagList": {
          "description": "Tag list of equipment template",
          "type": "array",
          "items": {
            "$ref": "#/definitions/EquipmentTag"
          }
        }
      },
      "example": {
        "id": 9,
        "name": "ioLogik-E1260",
        "tagList": [
          {
            "name": "rtdi0",
            "function": "read-input-registers",
            "address": 1536,
            "quantity": 1,
            "dataType": "uint16",
            "enableAutoScaling": 1,
            "autoScalingMode": "intercept",
            "autoScaling": {
              "slope": 0.1,
              "offset": 0
            },
            "description": ""
          },
          {
            "name": "rtdi1",
            "function": "read-input-registers",
            "address": 1537,
            "quantity": 1,
            "dataType": "uint16",
            "enableAutoScaling": 1,
            "autoScalingMode": "intercept",
            "autoScaling": {
              "slope": 0.1,
              "offset": 0
            },
            "description": ""
          },
          {
            "name": "rtdi2",
            "function": "read-input-registers",
            "address": 1538,
            "quantity": 1,
            "dataType": "uint16",
            "enableAutoScaling": 1,
            "autoScalingMode": "intercept",
            "autoScaling": {
              "slope": 0.1,
              "offset": 0
            },
            "description": ""
          },
          {
            "name": "rtdi3",
            "function": "read-input-registers",
            "address": 1539,
            "quantity": 1,
            "dataType": "uint16",
            "enableAutoScaling": 1,
            "autoScalingMode": "intercept",
            "autoScaling": {
              "slope": 0.1,
              "offset": 0
            },
            "description": ""
          },
          {
            "name": "rtdi4",
            "function": "read-input-registers",
            "address": 1540,
            "quantity": 1,
            "dataType": "uint16",
            "enableAutoScaling": 1,
            "autoScalingMode": "intercept",
            "autoScaling": {
              "slope": 0.1,
              "offset": 0
            },
            "description": ""
          },
          {
            "name": "rtdi5",
            "function": "read-input-registers",
            "address": 1541,
            "quantity": 1,
            "dataType": "uint16",
            "enableAutoScaling": 1,
            "autoScalingMode": "intercept",
            "autoScaling": {
              "slope": 0.1,
              "offset": 0
            },
            "description": ""
          }
        ]
      }
    },
    "EquipmentTag": {
      "title": "Equipment Tag",
      "type": "object",
      "required": [
        "name",
        "function",
        "address",
        "quantity",
        "dataType",
        "description"
      ],
      "properties": {
        "name": {
          "description": "Name of tag",
          "type": "string",
          "pattern": "[A-Za-z0-9_-]+",
          "minLength": 2,
          "maxLength": 255
        },
        "unit": {
          "description": "Unit of tag",
          "type": "string"
        },
        "function": {
          "description": "Function to retrieve the tag value",
          "type": "string",
          "enum": [
            "read-coils",
            "read-input-registers",
            "read-discrete-inputs",
            "read-holding-registers",
            "write-single-coil",
            "write-single-register",
            "write-multiple-coils",
            "write-multiple-registers"
          ]
        },
        "address": {
          "description": "Address of the tag 0x0000(0) <= value <= 0xFFFF(65535)",
          "type": "integer",
          "minimum": 0,
          "maximum": 655350
        },
        "quantity": {
          "description": "Quantity of tag",
          "type": "integer",
          "minimum": 1,
          "maximum": 655350
        },
        "dataType": {
          "description": "Data type of tag",
          "type": "string",
          "enum": [
            "uint16",
            "uint32",
            "uint64",
            "int16",
            "int32",
            "int64",
            "float32",
            "float64",
            "string",
            "boolean",
            "bytearray"
          ]
        },
        "enableByteOrder": {
          "description": "Enable byte order function",
          "type": "boolean"
        },
        "byteOrder": {
          "description": "Switch input byte order",
          "type": "string",
          "enum": [
            "BA",
            "CDAB",
            "DCBA",
            "GHEFCDAB",
            "HGFEDCBA"
          ]
        },
        "enableInvalidValue": {
          "description": "Enable invalid value function",
          "type": "boolean"
        },
        "invalidValue": {
          "description": "Array size is equals to quantity (if input == INVALID_VALUE, assume the value is not valid)",
          "type": "array",
          "items": {
            "type": "integer"
          }
        },
        "description": {
          "description": "User edited description of tag",
          "type": "string",
          "minLength": 0,
          "maxLength": 65535
        },
        "enableAutoScaling": {
          "description": "Enable auto scaling function",
          "type": "boolean"
        },
        "autoScalingMode": {
          "description": "Mode of auto scaling function",
          "type": "string",
          "enum": [
            "intercept",
            "point"
          ]
        },
        "autoScaling": {
          "description": "V = input * S + O output = ((input-sourceMin) * (targetMax-targetMin) / (sourceMax-sourceMin)) + targetMin\n",
          "type": "object",
          "properties": {
            "slope": {
              "type": "number"
            },
            "offset": {
              "type": "number"
            },
            "sourceMin": {
              "type": "number"
            },
            "sourceMax": {
              "type": "number"
            },
            "targetMin": {
              "type": "number"
            },
            "targetMax": {
              "type": "number"
            }
          }
        },
        "access": {
          "description": "Access type of tag",
          "type": "string",
          "enum": [
            "ro",
            "wo",
            "wr"
          ]
        },
        "size": {
          "description": "Size of tag in byte",
          "type": "integer"
        }
      }
    },
    "Interface": {
      "title": "Interface",
      "description": "Interface which connects to modbus devices",
      "type": "object",
      "required": [
        "name",
        "type",
        "pollingPeriodMs",
        "requestTimeoutMs",
        "deviceList"
      ],
      "properties": {
        "id": {
          "description": "ID of interface",
          "type": "integer",
          "readOnly": true
        },
        "name": {
          "description": "Name of interface",
          "type": "string",
          "pattern": "",
          "minLength": 2,
          "maxLength": 255
        },
        "type": {
          "description": "Type of modbus device",
          "type": "string",
          "enum": [
            "modbus-rtu",
            "modbus-tcp"
          ]
        },
        "pollingPeriodMs": {
          "description": "Polling period for this interface (ms)",
          "type": "integer",
          "minimum": 100,
          "maximum": 86400000
        },
        "requestTimeoutMs": {
          "description": "Request timeout for each devices (ms)",
          "type": "integer",
          "minimum": 100,
          "maximum": 60000
        },
        "deviceList": {
          "type": "array",
          "items": {
            "$ref": "#/definitions/Device"
          }
        },
        "config": {
          "$ref": "#/definitions/ModbusConfig"
        }
      },
      "example": {
        "id": 1,
        "name": "Modbus_Gateway_1",
        "type": "modbus-rtu",
        "config": {
          "dev": "/dev/ttyM0",
          "devDisplayName": "PORT 1",
          "baudRate": 115200,
          "parity": "none",
          "stopBits": 1,
          "intercharTimeoutMs": 100,
          "interframeDelayMs": 0
        },
        "requestTimeoutMs": 500,
        "pollingPeriodMs": 5000,
        "deviceList": []
      }
    },
    "ModbusConfig": {
      "title": "Modbus Config",
      "allOf": [
        {
          "$ref": "#/definitions/ModbusTCPConfig"
        },
        {
          "$ref": "#/definitions/ModbusRTUConfig"
        }
      ]
    },
    "ModbusTCPConfig": {
      "title": "Modbus TCP config",
      "description": "Modbus TCP interface config",
      "type": "object",
      "required": [
        "host",
        "port"
      ],
      "properties": {
        "host": {
          "description": "HOST of TCP modbus device",
          "type": "string"
        },
        "port": {
          "description": "PORT of TCP modbus device",
          "type": "integer"
        }
      }
    },
    "ModbusRTUConfig": {
      "title": "Modbus RTU config",
      "description": "Modbus RTU interface config",
      "type": "object",
      "properties": {
        "dev": {
          "description": "Physical path of modbus rtu device",
          "type": "string",
          "readOnly": true,
          "minLength": 1,
          "maxLength": 255
        },
        "devDisplayName": {
          "description": "Display name of modbus rtu device",
          "type": "string"
        },
        "baudRate": {
          "description": "Baudrate of modbus rtu device",
          "type": "integer",
          "enum": [
            115200,
            57600,
            38400,
            19200,
            9600,
            4800,
            2400,
            1200
          ]
        },
        "parity": {
          "description": "Partiy of modbus rtu device",
          "type": "string",
          "enum": [
            "odd",
            "even",
            "none"
          ]
        },
        "stopBits": {
          "description": "Stop bits of modbus rtu device",
          "type": "integer",
          "enum": [
            0,
            1,
            2
          ]
        },
        "intercharTimeoutMs": {
          "description": "Inter char timeout (ms)",
          "type": "integer"
        }
      }
    },
    "Device": {
      "title": "Device",
      "description": "Modbus device profile",
      "type": "object",
      "required": [
        "deviceId",
        "equipmentName",
        "equipmentTemplate"
      ],
      "properties": {
        "deviceId": {
          "description": "ID of device",
          "type": "integer",
          "minimum": 0,
          "maximum": 255
        },
        "equipmentTemplate": {
          "description": "Name of modbus template",
          "type": "string",
          "pattern": "^[A-Za-z0-9_-]+$",
          "minLength": 2,
          "maxLength": 255
        },
        "equipmentName": {
          "description": "Name of device",
          "type": "string",
          "pattern": "^[A-Za-z0-9_-]+$",
          "minLength": 3,
          "maxLength": 255
        },
        "status": {
          "$ref": "#/definitions/DeviceStatus"
        }
      }
    },
    "DeviceStatus": {
      "title": "Device Status",
      "description": "Device current status",
      "type": "object",
      "readOnly": true,
      "properties": {
        "connection": {
          "description": "Connection status. If all tag request success, return true, others return false",
          "type": "boolean"
        },
        "totalRequestCount": {
          "description": "Total number of request count",
          "type": "integer"
        },
        "totalRequestSuccess": {
          "description": "Total numver of success request count",
          "type": "integer"
        },
        "totalReadingCount": {
          "description": "Total number of reading count",
          "type": "integer"
        },
        "lastPoll": {
          "description": "Last pulling status",
          "type": "object",
          "properties": {
            "at": {
              "description": "Pulling Timestamp",
              "type": "string"
            },
            "elapsedMs": {
              "description": "Pulling costs how many milliseconds",
              "type": "integer"
            },
            "requestCount": {
              "description": "Number of requests in this pulling",
              "type": "integer"
            },
            "requestSuccess": {
              "description": "Number of success requests in this pulling",
              "type": "integer"
            },
            "readingCount": {
              "description": "Number of reading in this pulling",
              "type": "integer"
            }
          }
        }
      }
    },
    "ModbusListEquipment": {
      "title": "Equipment",
      "description": "Modbus equipment object",
      "type": "object",
      "required": [
        "equipmentName",
        "equipmentTags"
      ],
      "properties": {
        "equipmentName": {
          "description": "Name of equipment",
          "type": "string",
          "minLength": 1,
          "maxLength": 255
        },
        "equipmentTags": {
          "description": "Tag List of equipment",
          "type": "array",
          "items": {
            "$ref": "#/definitions/ModbusListEquipmentTag"
          }
        }
      }
    },
    "ModbusListEquipmentTag": {
      "title": "Tag",
      "description": "Equipment's tag entry",
      "type": "object",
      "required": [
        "name",
        "function",
        "address",
        "quantity",
        "type",
        "description"
      ],
      "properties": {
        "name": {
          "description": "Name of tag",
          "type": "string",
          "pattern": "[A-Za-z0-9_-]+",
          "minLength": 2,
          "maxLength": 255
        },
        "unit": {
          "description": "Unit of tag",
          "type": "string"
        },
        "function": {
          "description": "Function to retrieve the tag value",
          "type": "string",
          "enum": [
            "read-coils",
            "read-input-registers",
            "read-discrete-inputs",
            "read-holding-registers",
            "write-single-coil",
            "write-single-register",
            "write-multiple-coils",
            "write-multiple-registers"
          ]
        },
        "address": {
          "description": "Address of the tag 0x0000(0) <= value <= 0xFFFF(65535)",
          "type": "integer",
          "minimum": 0,
          "maximum": 655350
        },
        "quantity": {
          "description": "Quantity of tag",
          "type": "integer",
          "minimum": 1,
          "maximum": 655350
        },
        "type": {
          "description": "Data type of tag",
          "type": "string",
          "enum": [
            "uint16",
            "uint32",
            "uint64",
            "int16",
            "int32",
            "int64",
            "float32",
            "float64",
            "string",
            "boolean"
          ]
        },
        "enableByteOrder": {
          "description": "Enable byte order function",
          "type": "boolean"
        },
        "byteOrder": {
          "description": "Switch input byte order",
          "type": "string",
          "enum": [
            "BA",
            "CDAB",
            "DCBA",
            "GHEFCDAB",
            "HGFEDCBA"
          ]
        },
        "enableInvalidValue": {
          "description": "Enable invalid value function",
          "type": "boolean"
        },
        "invalidValue": {
          "description": "Array size is equals to quantity (if input == INVALID_VALUE, assume the value is not valid)",
          "type": "array",
          "items": {
            "type": "integer"
          }
        },
        "description": {
          "description": "User edited description of tag",
          "type": "string",
          "minLength": 0,
          "maxLength": 65535
        },
        "enableAutoScaling": {
          "description": "Enable auto scaling function",
          "type": "boolean"
        },
        "autoScalingMode": {
          "description": "Mode of auto scaling function",
          "type": "string",
          "enum": [
            "intercept",
            "point"
          ]
        },
        "autoScaling": {
          "description": "V = input * S + O output = ((input-sourceMin) * (targetMax-targetMin) / (sourceMax-sourceMin)) + targetMin\n",
          "type": "object",
          "properties": {
            "slope": {
              "type": "number"
            },
            "offset": {
              "type": "number"
            },
            "sourceMin": {
              "type": "number"
            },
            "sourceMax": {
              "type": "number"
            },
            "targetMin": {
              "type": "number"
            },
            "targetMax": {
              "type": "number"
            }
          }
        }
      }
    },
    "PortMapping": {
      "title": "PortMapping",
      "required": [
        "enable",
        "extPort",
        "intPort",
        "intIp",
        "protocol"
      ],
      "properties": {
        "id": {
          "type": "integer",
          "description": "Identifier for a Port Mapping rule."
        },
        "enable": {
          "type": "boolean",
          "description": "Indicate to enable (true) or disable (false) the rule."
        },
        "service": {
          "type": "string",
          "description": "The service name for Port Mapping.",
          "pattern": "[A-Za-z0-9_-]+",
          "minLength": 0,
          "maxLength": 255
        },
        "extPort": {
          "type": "object",
          "description": "External port(s) of the rule.",
          "required": [
            "start"
          ],
          "properties": {
            "start": {
              "description": "Start port of the rule.",
              "type": "integer",
              "minimum": 1,
              "maximum": 65535
            },
            "end": {
              "description": "End port of the rule.",
              "type": "integer",
              "minimum": 1,
              "maximum": 65535
            }
          }
        },
        "intPort": {
          "type": "object",
          "description": "Internal port(s) of the rule.",
          "required": [
            "start"
          ],
          "properties": {
            "start": {
              "description": "Start port of the rule.",
              "type": "integer",
              "minimum": 1,
              "maximum": 65535
            },
            "end": {
              "description": "End port of the rule.",
              "type": "integer",
              "minimum": 1,
              "maximum": 65535
            }
          }
        },
        "intIp": {
          "type": "string",
          "pattern": "^(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)$",
          "description": "Destination IP address for the rule."
        },
        "protocol": {
          "type": "string",
          "enum": [
            "tcp",
            "udp",
            "both"
          ],
          "description": "Specify the protocol for the rule."
        }
      },
      "example": {
        "id": 1,
        "enable": true,
        "service": "http",
        "extPort": {
          "start": 8080,
          "end": 8080
        },
        "intPort": {
          "start": 80,
          "end": 80
        },
        "intIp": "192.168.5.123",
        "protocol": "tcp"
      }
    },
    "SSNAT": {
      "title": "SSNAT",
      "required": [
        "enable",
        "portStart",
        "intIp",
        "protocol"
      ],
      "properties": {
        "id": {
          "type": "integer",
          "description": "Identifier for a simple SNAT rule."
        },
        "enable": {
          "type": "boolean",
          "description": "Indicate to enable (true) or disable (false) the rule."
        },
        "service": {
          "type": "string",
          "description": "The service name for simple SNAT. Default to `0`.",
          "pattern": "[A-Za-z0-9_-]+",
          "minLength": 0,
          "maxLength": 255
        },
        "priority": {
          "type": "integer",
          "description": "Rule priority, larger number has the higher priority.",
          "minimum": 0,
          "maximum": 999
        },
        "portStart": {
          "type": "integer",
          "minimum": 1,
          "maximum": 65535,
          "description": "Start port of the rule."
        },
        "portEnd": {
          "type": "integer",
          "minimum": 1,
          "maximum": 65535,
          "description": "End port of the rule."
        },
        "intIp": {
          "type": "string",
          "pattern": "^(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)$",
          "description": "Internal (source) IP address for the source NAT."
        },
        "protocol": {
          "type": "string",
          "enum": [
            "tcp",
            "udp",
            "both"
          ],
          "description": "Specify the protocol for the rule."
        },
        "outInterface": {
          "type": "string",
          "pattern": "[A-Za-z0-9]",
          "minLength": 2,
          "maxLength": 255,
          "description": "Could be the interface name or \"wan\" to indicate a WAN interface.\n"
        }
      },
      "example": {
        "id": 1,
        "enable": true,
        "priority": 0,
        "service": "http",
        "protocol": "both",
        "intIp": "192.168.5.123",
        "portStart": 80,
        "portEnd": 80,
        "outInterface": "wan"
      }
    },
    "FirewallWanHttps": {
      "title": "FirewallWanHttps",
      "required": [
        "enable"
      ],
      "properties": {
        "enable": {
          "type": "boolean",
          "description": "Indicate to enable (true) or disable (false) the rule."
        }
      },
      "example": {
        "enable": false
      }
    }
  }
}
;